@@ -123,18 +123,18 @@ public:
 
   //! Forget where the search was started
   void ResetSearchStart()
-  {
-    m_cellSearchStartedIn = {};
-    m_indexSearchStartedAt = -1;
-  }
+    {
+      m_cellSearchStartedIn = {};
+      m_indexSearchStartedAt = -1;
+    }
 
   //! Forget where the mouse selection was started
   void ResetMouseSelectionStart()
-  { m_cellMouseSelectionStartedIn = {}; }
+    { m_cellMouseSelectionStartedIn = {}; }
 
   //! Forget where the keyboard selection was started
   void ResetKeyboardSelectionStart()
-  { m_cellKeyboardSelectionStartedIn = {}; }
+    { m_cellKeyboardSelectionStartedIn = {}; }
 
   /*! The first cell of the currently selected range of Cells.
 
@@ -170,14 +170,14 @@ public:
   void SetTimerIdForCell(Cell *cell, int timerId);
   int GetTimerIdForCell(Cell *cell) const;
   Cell *GetCellForTimerId(int timerId) const;
-  void RemoveTimerIdForCell(Cell *cell);
+  void RemoveTimerIdForCell(const Cell *const cell);
 
   wxScrolledCanvas *GetWorksheet() { return m_worksheet; }
 
 private:
   struct CellTimerId {
-    Cell *cell;
-    int timerId;
+    Cell *cell = NULL;
+    int timerId = -1;
     CellTimerId() = default;
     CellTimerId(Cell *cell, int timerId) : cell(cell), timerId(timerId) {}
   };
