@@ -32,7 +32,13 @@
 #include "TextStyle.h"
 #include <memory>
 #include <unordered_map>
+#include <list>
 #include <vector>
+#include <wx/wupdlock.h>
+#include <wx/webview.h>
+#ifdef __WXMSW__
+#include <wx/msw/webview_ie.h>
+#endif
 
 #define MC_LINE_SKIP Scale_Px(2)
 #define MC_TEXT_PADDING Scale_Px(1)
@@ -79,7 +85,7 @@ class Cell;
   similar: Configuration::Get() will always return the last Configuration that was 
   created and therefore as long as the new configuration object exist will return
   a pointer to this object if configuration is needed.
- */
+*/
 class Configuration
 {
 public:
@@ -125,43 +131,43 @@ public:
 
   WX_DECLARE_STRING_HASH_MAP(int, StringHash);
   /*! All maxima operator names we know
-  */
+   */
   StringHash m_maximaOperators;
 
-  const wxEnvVariableHashMap& MaximaEnvVars(){return m_maximaEnvVars;}
+  const wxEnvVariableHashMap& MaximaEnvVars() const {return m_maximaEnvVars;}
   wxEnvVariableHashMap m_maximaEnvVars;
 
-  mathDisplayMode DisplayMode(){return m_displayMode;}
-  void DisplayMode(mathDisplayMode mode ){m_displayMode = mode;}
+  mathDisplayMode DisplayMode() const {return m_displayMode;}
+  void DisplayMode(mathDisplayMode mode ) {m_displayMode = mode;}
 
   //! Set maxima's working directory
   void SetWorkingDirectory(wxString dir)
-  { m_workingdir = dir; }
+    { m_workingdir = dir; }
 
   wxString GetWorkingDirectory() const
-  { return m_workingdir; }
+    { return m_workingdir; }
 
   void ReadConfig();
 
   /*! The constructor
     
     \param dc The drawing context that is to be used for drawing objects
-   */
+  */
   explicit Configuration(wxDC *dc = {}, InitOpt options = {});
 
   void ResetAllToDefaults(InitOpt options = {});
 
   //! Set the drawing context that is currently active
   void SetContext(wxDC &dc)
-  {
-    m_dc = &dc;
-    m_antialiassingDC = NULL;
-  }
+    {
+      m_dc = &dc;
+      m_antialiassingDC = NULL;
+    }
   void UnsetContext() {m_dc = NULL;}
 
   void SetBackgroundBrush(wxBrush brush);
-  bool FixedFontInTextControls(){return m_fixedFontTC;}
-  void FixedFontInTextControls(bool fixed){m_fixedFontTC = fixed;}
+  bool FixedFontInTextControls() const {return m_fixedFontTC;}
+  void FixedFontInTextControls(bool fixed) {m_fixedFontTC = fixed;}
   wxBrush GetBackgroundBrush() const {return m_BackgroundBrush;}
   wxBrush GetTooltipBrush() const {return m_tooltipBrush;}
   void SetAntialiassingDC(wxDC &antialiassingDC)
@@ -185,40 +191,40 @@ public:
   static EscCodeIterator EscCodesEnd();
 
   static double GetMinZoomFactor()
-  { return 0.1; }
+    { return 0.1; }
 
   static double GetMaxZoomFactor()
-  { return 32.0; }
+    { return 32.0; }
 
   /*! Extra space to leave between two equations in output cells.
 
     Extra space between equations is useful if we don't display labels that show
     which line begins a new equation and which line merely continues a multi-line
     equation.
-   */
+  */
   double GetInterEquationSkip() const 
-  {
-    if (ShowAutomaticLabels())
-      return 0;
-    else
-      return GetZoomFactor() * m_styles[TS_MATH].GetFontSize() / 2;
-  }
+    {
+      if (ShowAutomaticLabels())
+        return 0;
+      else
+        return GetZoomFactor() * m_styles[TS_MATH].GetFontSize() / 2;
+    }
 
   long GetCellBracketWidth() const
-  {
-    return (int) (GetZoomFactor() * 16);
-  }
+    {
+      return static_cast<int>(GetZoomFactor() * 16);
+    }
 
   //! Hide brackets that are not under the pointer?
   bool HideBrackets() const
-  { return m_hideBrackets; }
+    { return m_hideBrackets; }
 
   //! Define if we want to hide brackets that are not under the pointer.
   void HideBrackets(bool hide){m_hideBrackets = hide;}
 
   //! Hide brackets that are not under the pointer?
   double PrintScale() const
-  { return m_printScale; }
+    { return m_printScale; }
 
   //! Define if we want to hide brackets that are not under the pointer.
   void PrintScale(double scale){m_printScale = scale;}
@@ -234,17 +240,17 @@ public:
   /*! Scales a distance [in pixels] according to the zoom factor
 
     Is used for displaying/printing/exporting of text/maths.
-   */
+  */
   long Scale_Px(double px) const;
   AFontSize Scale_Px(AFontSize size) const;
 
   //! Determines the zoom factor the worksheet is displayed at
   double GetZoomFactor() const
-  { return m_zoomFactor; }
+    { return m_zoomFactor; }
 
   //! Get a drawing context suitable for size calculations
   wxDC *GetDC()
-  { return m_dc; }
+    { return m_dc; }
 
   //! Get a drawing context suitable for size calculations
   wxDC *GetAntialiassingDC()
@@ -268,7 +274,7 @@ public:
   bool IsUnderlined(long st) const {return m_styles[st].IsUnderlined();}
 
   long GetLabelWidth() const
-  { return m_labelWidth * 14; }
+    { return m_labelWidth * 14; }
 
   long LabelWidth() const
     { return m_labelWidth; }
@@ -277,12 +283,12 @@ public:
   
   //! Get the indentation of GroupCells.
   long GetIndent() const
-  {
-    if (m_indent < 0)
-      return 3 * GetCellBracketWidth() / 2;
-    else
-      return m_indent;
-  }
+    {
+      if (m_indent < 0)
+        return 3 * GetCellBracketWidth() / 2;
+      else
+        return m_indent;
+    }
 
   void SetPPI(wxSize ppi){m_ppi = ppi;}
   /*! Get the resolution 
@@ -291,57 +297,57 @@ public:
     so we need to do some additional tricks here.
   */
   wxSize GetPPI() const;
-  int AutosaveMinutes(){return m_autoSaveMinutes;}
+  int AutosaveMinutes() const {return m_autoSaveMinutes;}
   void AutosaveMinutes(int minutes){m_autoSaveMinutes = minutes;}
 
   //! How much vertical space is to be left between two group cells?
   long GetCursorWidth() const
-  {
-    long ppi;
+    {
+      long ppi;
 
-    if(!m_printing)
-      ppi = GetPPI().x;
-    else
-      ppi = 96;
+      if(!m_printing)
+        ppi = GetPPI().x;
+      else
+        ppi = 96;
 
-    if (ppi / 45 < 1)
-      return 1;
-    else
-      return ppi / 45;
-  }
+      if (ppi / 45 < 1)
+        return 1;
+      else
+        return ppi / 45;
+    }
   
   //! The y position the worksheet starts at
   long GetBaseIndent() const
-  {
-    if (GetCursorWidth() < 12)
-      return 12;
-    else
-      return 4 + GetCursorWidth();
-  }
+    {
+      if (GetCursorWidth() < 12)
+        return 12;
+      else
+        return 4 + GetCursorWidth();
+    }
 
   //! The vertical space between GroupCells
   long GetGroupSkip() const
-  {
-    if (GetCursorWidth() < 10)
-      return 20;
-    else
-      return 10 + GetCursorWidth();
-  }
+    {
+      if (GetCursorWidth() < 10)
+        return 20;
+      else
+        return 10 + GetCursorWidth();
+    }
 
   /*! Set the indentation of GroupCells
 
     Normally this parameter is automatically calculated
-   */
+  */
   void SetIndent(long indent)
-  {
-    m_indent = indent;
-  }
+    {
+      m_indent = indent;
+    }
 
   //! Set the width of the visible window for GetClientWidth()
   void SetClientWidth(long width)
-  {
-    m_clientWidth = width;
-  }
+    {
+      m_clientWidth = width;
+    }
 
   bool IncrementalSearch() const {return m_incrementalSearch;}
 
@@ -363,90 +369,90 @@ public:
   
   //! Set the height of the visible window for GetClientHeight()
   void SetClientHeight(long height)
-  { m_clientHeight = height; }
+    { m_clientHeight = height; }
 
   //! Returns the width of the visible portion of the worksheet
   long GetClientWidth() const
-  { return m_clientWidth; }
+    { return m_clientWidth; }
 
   //! Returns the height of the visible portion of the worksheet
   long GetClientHeight() const
-  { return m_clientHeight; }
+    { return m_clientHeight; }
 
   //! Calculates the default line width for the worksheet
   double GetDefaultLineWidth() const
-  {
-    if (GetZoomFactor() < 1.0)
-      return 1.0;
-    else
-      return GetZoomFactor();
-  }
+    {
+      if (GetZoomFactor() < 1.0)
+        return 1.0;
+      else
+        return GetZoomFactor();
+    }
 
   //! The minimum sensible line width in widths of a letter.
   long LineWidth_em() const 
-  {
-    if(!m_printing)
-      return m_lineWidth_em;
-    else
-      return 10000;
-  }
+    {
+      if(!m_printing)
+        return m_lineWidth_em;
+      else
+        return 10000;
+    }
 
   bool AutoSaveAsTempFile() const {return m_autoSaveAsTempFile;}
   void AutoSaveAsTempFile(bool asTempFile){m_autoSaveAsTempFile = asTempFile;}
 
   //! Set the minimum sensible line width in widths of a letter.
   void LineWidth_em(long width)
-  { m_lineWidth_em = width; }
+    { m_lineWidth_em = width; }
 
   //! Returns the maximum sensible width for a text line [in characters]:
   // On big 16:9 screens text tends to get \b very wide before it hits the right margin.
   // But text blocks that are 1 meter wide and 2 cm high feel - weird.
   long GetLineWidth() const;
 
-  bool SaveUntitled(){ return m_saveUntitled;}
-  void SaveUntitled(bool save){m_saveUntitled = save;}
+  bool SaveUntitled() const { return m_saveUntitled;}
+  void SaveUntitled(bool save) {m_saveUntitled = save;}
 
-  bool CursorJump(){ return m_cursorJump;}
+  bool CursorJump() const { return m_cursorJump;}
   void CursorJump(bool save){m_cursorJump = save;}
 
-  bool NumpadEnterEvaluates(){ return m_numpadEnterEvaluates;}
+  bool NumpadEnterEvaluates() const { return m_numpadEnterEvaluates;}
   void NumpadEnterEvaluates(bool eval){m_numpadEnterEvaluates = eval;}
 
-  bool SaveImgFileName() { return m_saveImgFileName;}
+  bool SaveImgFileName() const { return m_saveImgFileName;}
   void SaveImgFileName(bool save) { m_saveImgFileName = save;}
 
   //! Do we want to have automatic line breaks for text cells?
   bool GetAutoWrap() const
-  { return m_autoWrap > 0; }
+    { return m_autoWrap > 0; }
 
   // cppcheck-suppress functionStatic
   //! Do we want to have automatic line breaks for code cells?
-  bool GetAutoWrapCode() const
-  { return false; }
+  static bool GetAutoWrapCode()
+    { return false; }
 
   /*! Sets the auto wrap mode
     \param autoWrap 
-     - 0: No automatic line breaks
-     - 1: Automatic line breaks only for text cells
-     - 2: Automatic line breaks for text and code cells.
+    - 0: No automatic line breaks
+    - 1: Automatic line breaks only for text cells
+    - 2: Automatic line breaks for text and code cells.
   */
   void SetAutoWrap(long autoWrap){m_autoWrap = autoWrap;}
 
   //! Do we want automatic indentation?
   bool GetAutoIndent() const
-  { return m_autoIndent; }
+    { return m_autoIndent; }
 
   void SetAutoIndent(bool autoIndent){m_autoIndent = autoIndent;}
 
   //! Do we want to indent all maths?
   bool IndentMaths() const {return m_indentMaths;}
-  void IndentMaths(bool indent){m_indentMaths=indent;}
+  void IndentMaths(bool indent){m_indentMaths = indent;}
   AFontSize GetFontSize(TextStyle st) const
-  {
-    if (st == TS_TEXT || st == TS_HEADING5 || st == TS_HEADING6 || st == TS_SUBSUBSECTION || st == TS_SUBSECTION || st == TS_SECTION || st == TS_TITLE)
-      return m_styles[st].GetFontSize();
-    return {};
-  }
+    {
+      if (st == TS_TEXT || st == TS_HEADING5 || st == TS_HEADING6 || st == TS_SUBSUBSECTION || st == TS_SUBSECTION || st == TS_SECTION || st == TS_TITLE)
+        return m_styles[st].GetFontSize();
+      return {};
+    }
 
   const wxString &GetStyleName(TextStyle textStyle) const;
 
@@ -466,37 +472,37 @@ public:
   void WriteSettings(const wxString &file = {});
   
   void Outdated(bool outdated)
-  { m_outdated = outdated; }
+    { m_outdated = outdated; }
 
   bool CheckTeXFonts() const
-  { return m_TeXFonts; }
+    { return m_TeXFonts; }
 
   void CheckTeXFonts(bool check)
-  { m_TeXFonts = check; }
+    { m_TeXFonts = check; }
 
   bool CheckKeepPercent() const
-  { return m_keepPercent; }
+    { return m_keepPercent; }
 
   void SetKeepPercent(bool keepPercent)
     { m_keepPercent = keepPercent; }
 
   AFontName GetTeXCMRI() const
-  { return m_fontCMRI; }
+    { return m_fontCMRI; }
 
   AFontName GetTeXCMSY() const
-  { return m_fontCMSY; }
+    { return m_fontCMSY; }
 
   AFontName GetTeXCMEX() const
-  { return m_fontCMEX; }
+    { return m_fontCMEX; }
 
   AFontName GetTeXCMMI() const
-  { return m_fontCMMI; }
+    { return m_fontCMMI; }
 
   AFontName GetTeXCMTI() const
-  { return m_fontCMTI; }
+    { return m_fontCMTI; }
 
   bool ShowCodeCells() const
-  { return m_showCodeCells; }
+    { return m_showCodeCells; }
 
   void ShowCodeCells(bool show);
 
@@ -578,8 +584,30 @@ public:
       wxASSERT_MSG(displayedDigits >= 0, _("Bug: Maximum number of digits that is to be displayed is too low!"));
       m_displayedDigits = displayedDigits;
     }
-  
+
+  //! Stores the information about a file we need to write during the save process
+  class FileToSave
+  {
+  public:
+    FileToSave(const wxString &filename, const wxMemoryBuffer &data):
+      m_data(data),
+      m_filename(filename)
+      {        
+      }
+    const wxString FileName() const{return m_filename;}
+    const wxMemoryBuffer Data() const{return m_data;}
+  private:
+    const wxMemoryBuffer m_data;
+    const wxString m_filename;
+  };
+    
+  std::list<FileToSave> m_filesToSave;
+  FileToSave PopFileToSave();
+  void PushFileToSave(const wxString &filename, const wxMemoryBuffer &data)
+    { m_filesToSave.emplace_front(FileToSave(filename, data)); }
+
   wxRect GetUpdateRegion() const {return m_updateRegion;}
+  const std::list<FileToSave> GetFilesToSave(){return m_filesToSave;}
   void SetUpdateRegion(wxRect rect){m_updateRegion = rect;}
 
   //! Whether any part of the given rectangle is within the current update region,
@@ -623,7 +651,7 @@ public:
   showLabels GetLabelChoice() const
     { return m_showLabelChoice; }
 
-  bool InvertBackground(){return m_invertBackground;}
+  bool InvertBackground() const {return m_invertBackground;}
   void InvertBackground(bool invert){ m_invertBackground = invert; }
 
   long UndoLimit(){return wxMax(m_undoLimit, 0);}
@@ -677,15 +705,27 @@ public:
   //! Sets the location of the maxima binary.
   void MaximaUserLocation(wxString maxima) { m_maximaUserLocation = maxima; }
 
-  //! Autodetect maxima's location? (If false the user-specified location is used)
+  //! Autodetect the web browser? (If false the user-specified location is used)
   bool AutodetectHelpBrowser() const {return m_autodetectHelpBrowser;}
-  //! Autodetect maxima's location?
+  //! Autodetect the web browser?
   void AutodetectHelpBrowser(bool autodetect){m_autodetectHelpBrowser = autodetect;}
 
-  //! Returns the location of the help browser the user has selected.
+  //! Use the internal help browser? If not a external web browser is used.
+  bool InternalHelpBrowser() const {return m_useInternalHelpBrowser && OfferInternalHelpBrowser();}
+  //! Use the internal help browser? If not a external web browser is used.
+  void InternalHelpBrowser(bool useInternalHelpBrowser)
+    {m_useInternalHelpBrowser = useInternalHelpBrowser;}
+
+  //! Prefer the single-page manual?
+  bool SinglePageManual() const {return m_singlePageManual;}
+  //! Prefer the single-page manual?
+  void SinglePageManual(bool singlePageManual)
+    {m_singlePageManual = singlePageManual;}
+
+  //! Returns the location of the web browser the user has selected.
   wxString HelpBrowserUserLocation() const {return m_helpBrowserUserLocation;}
 
-  //! Sets the location of the maxima binary.
+  //! Sets the location of the web browser the user has detected.
   void HelpBrowserUserLocation(wxString helpBrowser) { m_helpBrowserUserLocation = helpBrowser;}
 
   /*! Could a maxima binary be found in the path we expect it to be in?
@@ -703,7 +743,11 @@ public:
   void FixReorderedIndices(bool fix) { m_fixReorderedIndices = fix;}
 
   //! Returns the URL MathJaX can be found at.
-  wxString MathJaXURL() const {if(m_mathJaxURL_UseUser) return m_mathJaxURL; else return MathJaXURL_Auto();}
+  wxString MathJaXURL() const {
+    if(m_mathJaxURL_UseUser)
+      return m_mathJaxURL;
+    else
+      return MathJaXURL_Auto();}
   wxString MathJaXURL_User() const { return m_mathJaxURL;}
   bool MathJaXURL_UseUser() const { return m_mathJaxURL_UseUser;}
   void MathJaXURL_UseUser(bool useUser){m_mathJaxURL_UseUser = useUser;}
@@ -736,7 +780,7 @@ public:
   void CopySVG(bool copySVG) { m_copySVG = copySVG; }
   bool CopyEMF() const {return m_copyEMF;}
   void CopyEMF(bool copyEMF) { m_copyEMF = copyEMF; }
-  bool UseSVG(){return m_useSVG;}
+  bool UseSVG() const {return m_useSVG;}
   void UseSVG(bool useSVG) { m_useSVG = useSVG ;}
   void ShowLength(long length) { m_showLength = length; }
   long ShowLength() const {return m_showLength;}
@@ -791,7 +835,7 @@ public:
   
   wxString Documentclass() const {return m_documentclass;}
   void Documentclass(wxString clss){m_documentclass = clss;}
-wxString DocumentclassOptions() const {return m_documentclassOptions;}
+  wxString DocumentclassOptions() const {return m_documentclassOptions;}
   void DocumentclassOptions(wxString classOptions){m_documentclassOptions = classOptions;}
 
   
@@ -846,9 +890,12 @@ wxString DocumentclassOptions() const {return m_documentclassOptions;}
   void NotifyOfCellRedraw(const Cell *cell);
   void ClearAndEnableRedrawTracing();
   void ReportMultipleRedraws();
-
+  //! If we decide that the HTML browser in the sidebar doesn't work for every platform...
+  bool OfferInternalHelpBrowser() const;
   bool WrapLatexMath() const {return m_wrapLatexMath;}
   void WrapLatexMath(bool wrapLatexMath){m_wrapLatexMath = wrapLatexMath;}
+  bool AllowNetworkHelp() const {return m_allowNetworkHelp;}
+  void AllowNetworkHelp(bool allowNetworkHelp){m_allowNetworkHelp = allowNetworkHelp;}
   bool ShowAllDigits() const {return m_showAllDigits;}
   void ShowAllDigits(bool shw){m_showAllDigits = shw;}
   bool LineBreaksInLongNums() const {return m_lineBreaksInLongNums;}
@@ -857,10 +904,15 @@ wxString DocumentclassOptions() const {return m_documentclassOptions;}
   void MaxClipbrdBitmapMegabytes(int maxClipbrd_BitmapMegabytes)
     {m_maxClipbrd_BitmapMegabytes = maxClipbrd_BitmapMegabytes;}
   
+  void MaximaUsesHtmlBrowser(bool maximaUsesHhtmlBrowser){m_maximaUsesHhtmlBrowser = maximaUsesHhtmlBrowser;}
+  bool MaximaUsesHtmlBrowser() const {return m_maximaUsesHhtmlBrowser;}
+  void MaximaUsesWxmaximaBrowser(bool maximaUsesWxmaximaBrowser){m_maximaUsesWxmaximaBrowser = maximaUsesWxmaximaBrowser;}
+  bool MaximaUsesWxmaximaBrowser() const {return m_maximaUsesWxmaximaBrowser && OfferInternalHelpBrowser();}
   void ExportContainsWXMX(bool exportContainsWXMX){m_exportContainsWXMX = exportContainsWXMX;}
   bool ExportContainsWXMX() const {return m_exportContainsWXMX;}
-  void DockableWizards(bool dockableWizards){m_dockableWizards = dockableWizards;}
-  bool DockableWizards() const {return m_dockableWizards;}
+  void WizardTab(long tab){m_wizardTab = tab;}
+  long WizardTab() const {return m_wizardTab;}
+
   wxString TexPreamble() const {return m_texPreamble;}
   void TexPreamble(wxString texPreamble) {m_texPreamble = texPreamble;}
 
@@ -869,7 +921,8 @@ wxString DocumentclassOptions() const {return m_documentclassOptions;}
   void InitStyles();
   //! True if we are confident that the font renders this char
   bool FontRendersChar(wxChar ch, const wxFont &font = *wxNORMAL_FONT);
-  
+  wxTextCtrl *LastActiveTextCtrl() const { return m_lastActiveTextCtrl; }
+  void LastActiveTextCtrl(wxTextCtrl *last);
 private:
   WX_DECLARE_STRING_HASH_MAP(wxString, RenderablecharsHash);
   RenderablecharsHash m_renderableChars;
@@ -882,8 +935,10 @@ private:
   wxSize m_ppi = wxSize(-1, -1);
   mathDisplayMode m_displayMode = display_2d;
   using CellRedrawTrace = std::vector<const Cell*>;
-  bool m_dockableWizards;
+  long m_wizardTab;
   bool m_usePartialForDiff;
+  bool m_maximaUsesHhtmlBrowser;
+  bool m_maximaUsesWxmaximaBrowser;
   //! true = Autosave doesn't save into the current file.
   bool m_autoSaveAsTempFile;
   //! The number of the language wxMaxima uses.
@@ -892,6 +947,10 @@ private:
   bool m_autodetectMaxima;
   //! Autodetect the help browser?
   bool m_autodetectHelpBrowser;
+  //! Use the internal help browser?
+  bool m_useInternalHelpBrowser;
+  //! Prefer the single-page manual?
+  bool m_singlePageManual;
   //! The worksheet all cells are drawn on
   wxRect m_updateRegion;
   //! Do we want to use incremental search?
@@ -915,6 +974,7 @@ private:
   bool CharsExistInFont(const wxFont &font, const wxString& chars);
   //! Caches the information on how to draw big parenthesis for GetParenthesisDrawMode().
   bool m_wrapLatexMath;
+  bool m_allowNetworkHelp;
   bool m_exportContainsWXMX;
   wxString m_texPreamble;
 
@@ -967,7 +1027,7 @@ private:
   wxDC *m_antialiassingDC;
   wxString m_maximaShareDir;
   bool m_forceUpdate;
-  bool m_clipToDrawRegion;
+  bool m_clipToDrawRegion = true;
   bool m_outdated;
   wxString m_maximaParameters;
   bool m_TeXFonts;
@@ -1039,6 +1099,7 @@ private:
   int m_autoSaveMinutes;
   wxString m_wxMathML_Filename;
   bool m_wxMathML_UseFile;
+  wxTextCtrl *m_lastActiveTextCtrl = NULL;
 };
 
 //! Sets the configuration's "printing" flag until this class is left.
@@ -1049,12 +1110,10 @@ public:
     {
       m_configuration = configuration;
       m_configuration->SetPrinting(true);
-      m_configuration->ClipToDrawRegion(false);
     }
   ~Printing()
     {
       m_configuration->SetPrinting(false);
-      m_configuration->ClipToDrawRegion(true);
     }
 private:
   Configuration * m_configuration;
