@@ -48,11 +48,11 @@
 /*! An object that represents the directory structure wxMaxima is installed in
 
   wxMaxima finds its data in different places on different operating systems:
- - wxStandardPaths::GetExecutablePath() on windows
- - PREFIX+"/share/wxMaxima/" on Linux
- - wxStandardPaths::GetExecutablePath()+"/wxMaxima.app/Contents/Resources" on mac.
+  - wxStandardPaths::GetExecutablePath() on windows
+  - PREFIX+"/share/wxMaxima/" on Linux
+  - wxStandardPaths::GetExecutablePath()+"/wxMaxima.app/Contents/Resources" on mac.
 
-   - on linux in 
+  - on linux in 
 */
 class Dirstructure
 {
@@ -68,12 +68,12 @@ public:
   //! The directory the user stores its data in.
   static wxString UserConfDir() {return m_userConfDir;}
   //! Set the directory the user stores its data in.
-  static void UserConfDir(wxString userConfDir) {m_userConfDir = userConfDir + wxT("/");}
+  static void UserConfDir(wxString userConfDir);
 
   //! The directory general data is stored in
   wxString DataDir() const;
 
-    //! The directory our private fonts are stored in
+  //! The directory our private fonts are stored in
   wxString FontDir() const {return DataDir()+wxT("/../fonts");}
 
   //! The directory the help file is stored in
@@ -84,24 +84,24 @@ public:
   /*! The file private accelerator key information is stored in
 
    */
-  wxString UserAutocompleteFile();
+  static wxString UserAutocompleteFile();
 
   //! The path to wxMaxima's own AutoComplete file
   wxString AutocompleteFile() const
-  { return DataDir() + wxT("/autocomplete.txt"); }
+    { return DataDir() + wxT("/autocomplete.txt"); }
 
   /*! The directory the locale data is to be found in
 
     Is only used on MSW and MAC
-   */
+  */
   wxString LocaleDir() const
-  { return ResourcesDir() + wxT("/locale"); }
+    { return ResourcesDir() + wxT("/locale"); }
 
   //! The executable file path to the maxima executable (or .bat on Windows)
   static wxString MaximaDefaultLocation();
 
   static wxString
-    AnchorsCacheFile()
+  AnchorsCacheFile()
     {
       return UserConfDir() + "/manual_anchors.xml";
     }
