@@ -1,4 +1,5 @@
-// -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
+// -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode:
+// nil -*-
 //
 //  Copyright (C) 2009-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
 //            (C) 2014-2016 Gunter Königsmann <wxMaxima@physikbuch.de>
@@ -25,27 +26,30 @@
   This file defines the class History
 
   History is a side bar that shows all recently issued maxima commands.
- */
+*/
 
 #include "History.h"
 
-#include <wx/sizer.h>
-#include <wx/menu.h>
-#include <wx/filedlg.h>
-#include <wx/wfstream.h>
-#include <wx/txtstrm.h>
-#include <wx/config.h>
+#include "Configuration.h"
 #include <algorithm>
 #include <memory>
+#include <wx/config.h>
+#include <wx/filedlg.h>
+#include <wx/menu.h>
+#include <wx/sizer.h>
+#include <wx/txtstrm.h>
+#include <wx/wfstream.h>
 #include <wx/wupdlock.h>
 
-History::History(wxWindow *parent, int id) : wxPanel(parent, id)
-{
+History::History(wxWindow *parent, int id, Configuration *cfg)
+  : wxPanel(parent, id) {
   wxConfig::Get()->Read(m_showCurrentSessionOnlyKey, &m_showCurrentSessionOnly);
-  // wxLB_MULTIPLE and wxLB_EXTENDED are mutually exclusive and will assert on Windows
-  m_history = new wxListBox(this, history_ctrl_id, wxDefaultPosition, wxDefaultSize, 0, NULL,
-                            wxLB_EXTENDED | wxLB_HSCROLL | wxLB_NEEDED_SB);
-  m_regex = new RegexCtrl(this, wxID_ANY);
+  // wxLB_MULTIPLE and wxLB_EXTENDED are mutually exclusive and will assert on
+  // Windows
+  m_history =
+    new wxListBox(this, history_ctrl_id, wxDefaultPosition, wxDefaultSize, 0,
+		  NULL, wxLB_EXTENDED | wxLB_HSCROLL | wxLB_NEEDED_SB);
+  m_regex = new RegexCtrl(this, wxID_ANY, cfg);
   wxBoxSizer *box = new wxBoxSizer(wxVERTICAL);
 
   box->Add(m_history, wxSizerFlags(1).Expand());
@@ -53,77 +57,74 @@ History::History(wxWindow *parent, int id) : wxPanel(parent, id)
 
   SetSizer(box);
   FitInside();
-  Connect(wxEVT_RIGHT_DOWN, wxMouseEventHandler(History::OnMouseRightDown), NULL, this);
-  m_history->Connect(wxEVT_RIGHT_DOWN, wxMouseEventHandler(History::OnMouseRightDown), NULL, this);
-  Connect(wxEVT_MENU,
-          wxCommandEventHandler(History::OnMenu), NULL, this);
-  m_regex->Connect(REGEX_EVENT,
-          wxCommandEventHandler(History::OnRegExEvent), NULL, this);
+  Connect(wxEVT_RIGHT_DOWN, wxMouseEventHandler(History::OnMouseRightDown),
+          NULL, this);
+  m_history->Connect(wxEVT_RIGHT_DOWN,
+                     wxMouseEventHandler(History::OnMouseRightDown), NULL,
+                     this);
+  Connect(wxEVT_MENU, wxCommandEventHandler(History::OnMenu), NULL, this);
+  m_regex->Connect(REGEX_EVENT, wxCommandEventHandler(History::OnRegExEvent),
+                   NULL, this);
 }
 
-void History::OnMouseRightDown(wxMouseEvent &WXUNUSED(event))
-{
+void History::OnMouseRightDown(wxMouseEvent &WXUNUSED(event)) {
   wxArrayInt selections;
   bool const hasSelections = (m_history->GetSelections(selections) > 0);
   wxString number;
 
   wxMenu popupMenu;
-  if(m_commands.size() > 0)
-  {
+  if (m_commands.size() > 0) {
     popupMenu.Append(export_all, _("Export all history to a .mac file"));
-    popupMenu.Append(export_session, _("Export commands from the current maxima session to a .mac file"));
+    popupMenu.Append(
+		     export_session,
+		     _("Export commands from the current maxima session to a .mac file"));
     if (hasSelections)
-      popupMenu.Append(export_selected, _("Export selected commands to a .mac file"));
-    if(m_history->GetCount() > 0)
-      popupMenu.Append(export_visible, _("Export visible commands to a .mac file"));
-    if(popupMenu.GetMenuItemCount() > 0)
+      popupMenu.Append(export_selected,
+                       _("Export selected commands to a .mac file"));
+    if (m_history->GetCount() > 0)
+      popupMenu.Append(export_visible,
+                       _("Export visible commands to a .mac file"));
+    if (popupMenu.GetMenuItemCount() > 0)
       popupMenu.AppendSeparator();
     if (hasSelections)
       popupMenu.Append(clear_selection, _("Clear the selection"));
-    popupMenu.Append(clear_history, _("Clear all history"));    
+    popupMenu.Append(clear_history, _("Clear all history"));
   }
-  if(popupMenu.GetMenuItemCount() > 0)
+  if (popupMenu.GetMenuItemCount() > 0)
     popupMenu.AppendSeparator();
-  popupMenu.AppendCheckItem(toggle_ShowCurrentSessionOnly, _("Show commands from current session only")); 
+  popupMenu.AppendCheckItem(toggle_ShowCurrentSessionOnly,
+                            _("Show commands from current session only"));
   popupMenu.Check(toggle_ShowCurrentSessionOnly, m_showCurrentSessionOnly);
   PopupMenu(&popupMenu);
 }
 
-void History::MaximaSessionStart()
-{
-  if(m_commands.size() != 0)
+void History::MaximaSessionStart() {
+  if (m_commands.size() != 0)
     AddToHistory(wxT("quit();"));
   m_sessionCommands = 0;
-  if(m_showCurrentSessionOnly)
+  if (m_showCurrentSessionOnly)
     m_history->Clear();
 }
 
-bool History::UpdateDeferred()
-{
-  if (!m_deferredCommands.empty())
-  {
+bool History::UpdateDeferred() {
+  if (!m_deferredCommands.empty()) {
     std::reverse(m_deferredCommands.begin(), m_deferredCommands.end());
     m_history->Insert(m_deferredCommands, 0);
     m_current += m_deferredCommands.size();
     m_deferredCommands.clear();
     SetCurrent(0);
     return true;
-  }
-  else
+  } else
     return false;
 }
 
-void History::UnselectAll() const
-{
+void History::UnselectAll() const {
   // Unselect all, See: https://forums.wxwidgets.org/viewtopic.php?t=29463
   m_history->SetSelection(-1, false);
 }
 
-static wxString AskForFileName(wxPanel *parent)
-{
-  wxFileDialog fileDialog(parent,
-                          _("Export As"), wxEmptyString,
-                          wxEmptyString,
+static wxString AskForFileName(wxPanel *parent) {
+  wxFileDialog fileDialog(parent, _("Export As"), wxEmptyString, wxEmptyString,
                           _("Maxima session (*.mac)|*.mac"),
                           wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
   if (fileDialog.ShowModal() == wxID_OK)
@@ -131,30 +132,25 @@ static wxString AskForFileName(wxPanel *parent)
   return {};
 }
 
-void History::OnMenu(wxCommandEvent &event)
-{
+void History::OnMenu(wxCommandEvent &event) {
   bool indicateError = false;
   int start = 0;
   int const size = m_commands.size();
 
-  switch (event.GetId())
-  {
+  switch (event.GetId()) {
   case toggle_ShowCurrentSessionOnly:
     m_showCurrentSessionOnly = !m_showCurrentSessionOnly;
-    wxConfig::Get()->Write(m_showCurrentSessionOnlyKey, m_showCurrentSessionOnly);
+    wxConfig::Get()->Write(m_showCurrentSessionOnlyKey,
+                           m_showCurrentSessionOnly);
     RebuildDisplay();
     break;
-  case export_selected:
-  {
+  case export_selected: {
     wxArrayInt selections;
-    if (m_history->GetSelections(selections) > 0)
-    {
+    if (m_history->GetSelections(selections) > 0) {
       auto file = AskForFileName(this);
-      if (!file.empty())
-      {
+      if (!file.empty()) {
         wxFileOutputStream output(file);
-        if(output.IsOk())
-        {
+        if (output.IsOk()) {
           wxTextOutputStream text(output);
           for (auto sel = selections.rbegin(); sel != selections.rend(); ++sel)
             text << m_history->GetString(*sel) << "\n";
@@ -166,39 +162,33 @@ void History::OnMenu(wxCommandEvent &event)
   }
   case export_session:
     start = size - m_sessionCommands;
-    //fallthrough
-    
-  case export_all:
-  {
+    // fallthrough
+
+  case export_all: {
     auto file = AskForFileName(this);
-    if (!file.empty())
-    {
+    if (!file.empty()) {
       wxFileOutputStream output(file);
-      if(output.IsOk())
-      {
+      if (output.IsOk()) {
         wxTextOutputStream text(output);
-        for(int i = start; i < size; ++i)
+        for (int i = start; i < size; ++i)
           text << m_commands[i] << "\n";
       }
       indicateError = !output.IsOk() || !output.Close();
     }
-  break;
+    break;
   }
-  case export_visible:
-  {
+  case export_visible: {
     auto file = AskForFileName(this);
-    if (!file.empty())
-    {
+    if (!file.empty()) {
       wxFileOutputStream output(file);
-      if(output.IsOk())
-      {
+      if (output.IsOk()) {
         wxTextOutputStream text(output);
-        for(int i = m_history->GetCount()-1; i >= 0; --i)
+        for (int i = m_history->GetCount() - 1; i >= 0; --i)
           text << m_history->GetString(i) << "\n";
       }
       indicateError = !output.IsOk() || !output.Close();
     }
-  break;
+    break;
   }
   case clear_history:
     m_history->Clear();
@@ -213,54 +203,46 @@ void History::OnMenu(wxCommandEvent &event)
     LoggingMessageBox(_("Exporting to .mac file failed!"), _("Error!"), wxOK);
 }
 
+History::~History() {}
 
-History::~History()
-{
-}
-
-void History::AddToHistory(const wxString &cmd)
-{
+void History::AddToHistory(const wxString &cmd) {
   if (cmd.IsEmpty())
     return;
 
-  m_sessionCommands ++;
+  m_sessionCommands++;
   m_commands.push_back(cmd);
 
   if (m_regex->Matches(cmd))
     m_deferredCommands.Add(cmd);
 }
 
-void History::RebuildDisplay()
-{
+void History::RebuildDisplay() {
   wxWindowUpdateLocker speedUp(this);
   wxArrayString display;
   std::vector<wxString>::reverse_iterator sessionEnd;
-  if(m_showCurrentSessionOnly)
+  if (m_showCurrentSessionOnly)
     sessionEnd = m_commands.rbegin() + m_sessionCommands;
   else
     sessionEnd = m_commands.rend();
-  
+
   display.reserve(m_commands.size());
   display.reserve(m_commands.size());
-  for (auto cmd = m_commands.rbegin(); cmd != sessionEnd; ++cmd)
-  {
+  for (auto cmd = m_commands.rbegin(); cmd != sessionEnd; ++cmd) {
     if (m_regex->Matches(*cmd))
       display.Add(*cmd);
   }
   m_history->Set(display);
   m_current = -1;
-  if(m_history->GetCount()>0)
+  if (m_history->GetCount() > 0)
     SetCurrent(0);
 }
 
-void History::OnRegExEvent(wxCommandEvent &WXUNUSED(ev))
-{
+void History::OnRegExEvent(wxCommandEvent &WXUNUSED(ev)) {
   UnselectAll();
   RebuildDisplay();
 }
 
-wxString History::GetCommand(bool next)
-{
+wxString History::GetCommand(bool next) {
   if (m_commands.size() == 0)
     return {};
 
@@ -269,18 +251,19 @@ wxString History::GetCommand(bool next)
   return m_history->GetString(m_current);
 }
 
-void History::SetCurrent(long current)
-{
+void History::SetCurrent(long current) {
   auto const count = long(m_history->GetCount());
-  if (current < 0) current = count-1;
-  else if (current >= count) current = 0;
-  if (count < 1) current = -1;
+  if (current < 0)
+    current = count - 1;
+  else if (current >= count)
+    current = 0;
+  if (count < 1)
+    current = -1;
 
   if (current == m_current)
     return;
 
-  if(current >= 0)
-  {
+  if (current >= 0) {
     m_current = current;
     m_history->EnsureVisible(m_current);
     UnselectAll();
@@ -288,4 +271,5 @@ void History::SetCurrent(long current)
   }
 }
 
-wxString History::m_showCurrentSessionOnlyKey(wxT("history/ShowCurrentSessionOnly"));
+wxString
+History::m_showCurrentSessionOnlyKey(wxT("history/ShowCurrentSessionOnly"));
