@@ -25,7 +25,7 @@
 
   This file contains the definition of the class History that handles the recently 
   issued commands for the history pane.
- */
+*/
 
 #ifndef HISTORY_H
 #define HISTORY_H
@@ -55,7 +55,7 @@ enum
 class History final : public wxPanel
 {
 public:
-  History(wxWindow *parent, int id);
+  History(wxWindow *parent, int id, Configuration *cfg);
 
   ~History();
 
