@@ -29,6 +29,7 @@
 #ifndef IMAGE_H
 #define IMAGE_H
 
+#include <memory>
 #include "precomp.h"
 #include "Cell.h"
 #include "Version.h"
@@ -45,41 +46,41 @@
 /*! Manages an auto-scaling image
 
   This class keeps two versions of an image:
-    - The image in its original compressed format. This way the image can losslessly
-      be exported later on
-    - A bitmap version of the image that is scaled down to a size that makes sense 
-      with the current viewport.
+  - The image in its original compressed format. This way the image can losslessly
+  be exported later on
+  - A bitmap version of the image that is scaled down to a size that makes sense 
+  with the current viewport.
 
   Storing images this way has many advantages:
-    - It allows us to restrict scaling operations to only once on actually drawing 
-      the image after a resize of the wxMaxima window.
-    - We can keep (and therefore export and save) jpeg photos in their original 
-      format instead of using the .png compression that is superior for line art - 
-      but not for depicting real-live images.
-    - We save time on saving the .wxmx file since image compression, if done good, 
-      might need a good deal of time and this class never needs to compress images
-      itself.
-    - It allows images to keep their metadata, if needed
-    - and if we have big images (big plots or for example photographs) we don't need
-      to store them in their uncompressed form.
-    - One could even delete the cached scaled images for all cells that currently 
-      are off-screen in order to save memory.
- */
+  - It allows us to restrict scaling operations to only once on actually drawing 
+  the image after a resize of the wxMaxima window.
+  - We can keep (and therefore export and save) jpeg photos in their original 
+  format instead of using the .png compression that is superior for line art - 
+  but not for depicting real-live images.
+  - We save time on saving the .wxmx file since image compression, if done good, 
+  might need a good deal of time and this class never needs to compress images
+  itself.
+  - It allows images to keep their metadata, if needed
+  - and if we have big images (big plots or for example photographs) we don't need
+  to store them in their uncompressed form.
+  - One could even delete the cached scaled images for all cells that currently 
+  are off-screen in order to save memory.
+*/
 class Image final
 {
 public:
   //! A constructor that generates an empty image. See LoadImage()
-  explicit Image(Configuration **config);
+  explicit Image(Configuration *config);
 
   //! A constructor that loads the compressed file from a wxMemoryBuffer
-  Image(Configuration **config, wxMemoryBuffer image, wxString type);
+  Image(Configuration *config, wxMemoryBuffer image, wxString type);
 
   /*! A constructor that loads a bitmap
 
     This constructor actually has to do some compression since we got
     the bitmap in an uncompressed form.
-   */
-  Image(Configuration **config, const wxBitmap &bitmap);
+  */
+  Image(Configuration *config, const wxBitmap &bitmap);
 
   /*! A constructor that loads an image
 
@@ -87,15 +88,15 @@ public:
     \param image The name of the file
     \param filesystem The filesystem to load it from
     \param remove true = Delete the file after loading it
-   */
-  Image(Configuration **config, wxString image, std::shared_ptr<wxFileSystem> filesystem, bool remove = true);
+  */
+  Image(Configuration *config, wxString image, std::shared_ptr<wxFileSystem> filesystem, bool remove = true);
 
-  Image(Configuration **config, const Image &image);
+  Image(Configuration *config, const Image &image);
   Image(const Image &image) = delete;
 
   ~Image();
 
-  void SetConfiguration(Configuration **config){ m_configuration = config; }
+  void SetConfiguration(Configuration *config){ m_configuration = config; }
   //! Return the image's resolution
   int GetPPI() const {return m_ppi;}
   //! Set the image's resolution
@@ -109,9 +110,14 @@ public:
     Causes the files to be cached if they are not way too long; As the files
     are text-only they profit from being compressed and are stored in the 
     memory in their compressed form.
-   */
+  */
   void GnuplotSource(wxString gnuplotFilename, wxString dataFilename, std::shared_ptr<wxFileSystem> filesystem);
 
+  /*! Loads the compressed gnuplot source and data file for this image
+
+   */
+  void CompressedGnuplotSource(wxString gnuplotFilename, wxString dataFilename, std::shared_ptr<wxFileSystem> filesystem);
+
   //! Load the gnuplot source file from the system's filesystem
   void GnuplotSource(wxString gnuplotFilename, wxString dataFilename)
     {
@@ -120,13 +126,13 @@ public:
 
 /*! Returns the gnuplot source file name of this image
 
-    If maxima has deleted the temporary file in the meantime or if it comes from 
-    a .wxmx file and has never been created from maxima the file is created by this 
-    function.
+  If maxima has deleted the temporary file in the meantime or if it comes from 
+  a .wxmx file and has never been created from maxima the file is created by this 
+  function.
 
-    If the file cannot be created (for example if no gnuplot source exists/ 
-    is known) this function returns wxEmptyString.
-   */
+  If the file cannot be created (for example if no gnuplot source exists/ 
+  is known) this function returns wxEmptyString.
+*/
   wxString GnuplotSource();
   /*! Returns the gnuplot data file name of this image
 
@@ -136,18 +142,20 @@ public:
 
     If the file cannot be created (for example if no gnuplot source exists/ 
     is known) this function returns wxEmptyString.
-   */
+  */
   wxString GnuplotData();
 
   //! Returns the gnuplot source of this image
-  wxMemoryBuffer GetGnuplotSource();
+  const wxMemoryBuffer GetGnuplotSource() const;
+  const wxMemoryBuffer GetCompressedGnuplotSource() const;
   //! Returns the gnuplot data of this image
-  wxMemoryBuffer GetGnuplotData();
+  const wxMemoryBuffer GetGnuplotData() const;
+  const wxMemoryBuffer GetCompressedGnuplotData() const;
   
   /*! Temporarily forget the scaled image in order to save memory
 
     Will recreate the scaled image as soon as needed.
-   */
+  */
   void ClearCache()
     {
       if ((m_scaledBitmap.GetWidth() > 1) || (m_scaledBitmap.GetHeight() > 1))
@@ -155,7 +163,7 @@ public:
     }
   
   //! Returns the file name extension of the current image
-  wxString GetExtension();
+  wxString GetExtension() const;
   //! The maximum width this image shall be displayed with
   double GetMaxWidth() const {return m_maxWidth;}
   //! The maximum height this image shall be displayed with
@@ -175,7 +183,7 @@ public:
   wxBitmap GetBitmap(double scale = 1.0);
 
   //! Does the image show an actual image or an "broken image" symbol?
-  bool IsOk();
+  bool IsOk() const;
   
   //! Returns the image in its unscaled form
   wxBitmap GetUnscaledBitmap();
@@ -189,13 +197,13 @@ public:
   long m_height;
 
   //! Returns the original image in its compressed form
-  wxMemoryBuffer GetCompressedImage();
+  const wxMemoryBuffer GetCompressedImage() const;
 
   //! Returns the original width
-  size_t GetOriginalWidth();
+  size_t GetOriginalWidth() const;
 
   //! Returns the original height
-  size_t GetOriginalHeight();
+  size_t GetOriginalHeight() const;
 
 
   
@@ -229,15 +237,16 @@ private:
   wxString m_gnuplotData;
   void LoadImage_Backgroundtask(wxString image, std::shared_ptr<wxFileSystem> filesystem, bool remove);
   void LoadGnuplotSource_Backgroundtask(wxString gnuplotFilename, wxString dataFilename, std::shared_ptr<wxFileSystem> filesystem);
+  void LoadCompressedGnuplotSource_Backgroundtask(wxString gnuplotFilename, wxString dataFilename, std::shared_ptr<wxFileSystem> filesystem);
   //! Loads an image from a file
   void LoadImage(wxString image, std::shared_ptr<wxFileSystem> filesystem, bool remove = true);
   //! Reads the compressed image into a memory buffer
   static wxMemoryBuffer ReadCompressedImage(wxInputStream *data);
-  Configuration **m_configuration;
+  Configuration *m_configuration;
   /*! The upper width limit for displaying this image
 
     \todo: Why is this a float and not an integer value?
-   */
+  */
   double m_maxWidth;
   //! The upper height limit for displaying this image
   double m_maxHeight;
