@@ -23,12 +23,13 @@
 
 /*! \file
 
-The header file for the xml cell parser
- */
+  The header file for the xml cell parser
+*/
 
 #ifndef MATHPARSER_H
 #define MATHPARSER_H
 
+#include <memory>
 #include "precomp.h"
 #include <wx/xml/xml.h>
 
@@ -44,18 +45,18 @@ The header file for the xml cell parser
 
 /*! This class handles parsing the xml representation of a cell tree.
 
-The xml representation of a cell tree can be found in the file contents.xml
-inside a wxmx file
- */
+  The xml representation of a cell tree can be found in the file contents.xml
+  inside a wxmx file
+*/
 class MathParser
 {
 public:
   /*! The constructor
 
-     \todo I guess we could increase the performance further by putting the
-     most-frequently-used tags to the front of the list.
-   */
-  explicit MathParser(Configuration **cfg, const wxString &zipfile = {});
+    \todo I guess we could increase the performance further by putting the
+    most-frequently-used tags to the front of the list.
+  */
+  explicit MathParser(Configuration *cfg, const wxString &zipfile = {});
   //! This class doesn't have a copy constructor
   MathParser(const MathParser&) = delete;
   //! This class doesn't have a = operator
@@ -96,7 +97,7 @@ private:
   static void ParseCommonAttrs(wxXmlNode *node, Cell *cell);
   template <typename T>
   static void ParseCommonAttrs(wxXmlNode *node, const std::unique_ptr<T> &cell)
-  { ParseCommonAttrs(node, cell.get()); }
+    { ParseCommonAttrs(node, cell.get()); }
 
   //! Parses attributes that apply to nearly all types of cells
   static void ParseCommonGroupCellAttrs(wxXmlNode *node, const std::unique_ptr<GroupCell> &group);
@@ -107,26 +108,26 @@ private:
   /*! Get the next xml tag
 
     wxXmlNode can operate in two modes:
-     - One mode skips all whitespace between the beginning of the line and the first
-       character if that character was escaped by a & for including it into the XML
-       stream. This obviously is a bad idea in our case.
-     - And the other mode inserts bogus whitespace text nodes if there is whitespace
-       between XML tags. This one is more helpful - but only if we provide a function
-       that skips these whitespace text nodes.
+    - One mode skips all whitespace between the beginning of the line and the first
+    character if that character was escaped by a & for including it into the XML
+    stream. This obviously is a bad idea in our case.
+    - And the other mode inserts bogus whitespace text nodes if there is whitespace
+    between XML tags. This one is more helpful - but only if we provide a function
+    that skips these whitespace text nodes.
     If we encounter a non-whitespace text node where we shouldn't we raise an
     assertion that informs the user that we might want a bug report about this.
-   */
-  wxXmlNode *GetNextTag(wxXmlNode *node);
+  */
+  static wxXmlNode *GetNextTag(wxXmlNode *node);
 
   /*! Counts the number of non-whitespace children of a node */
-  int CountChildren(wxXmlNode *node);
+  static int CountChildren(wxXmlNode *node);
 
   /*! Returns node - or (if node is a whitespace-only text node) the next one.
 
     If we encounter a non-whitespace text node where we shouldn't we raise an
     assertion that informs the user that we might want a bug report about this.
-   */
-  wxXmlNode *SkipWhitespaceNode(wxXmlNode *node);
+  */
+  static wxXmlNode *SkipWhitespaceNode(wxXmlNode *node);
 
   /*! \defgroup GroupCellParsing Methods that generate GroupCells from XML
     @{
@@ -192,7 +193,7 @@ private:
   /*! Parse a math-in-maths tag to a Cell.
 
     \todo Does such a thing actually exist?
-   */
+  */
   std::unique_ptr<Cell> ParseMthTag(wxXmlNode *node);
   //! Parse an output label tag to a Cell.
   std::unique_ptr<Cell> ParseOutputLabelTag(wxXmlNode *node);
@@ -253,7 +254,7 @@ private:
   CellType m_ParserStyle;
   FracCell::FracType m_FracStyle;
   CellPtr<GroupCell> m_group;
-  Configuration **m_configuration;
+  Configuration *m_configuration;
   bool m_highlight;
   std::shared_ptr<wxFileSystem> m_fileSystem; // used for loading pictures in <img> and <slide>
   static wxString m_unknownXMLTagToolTip;
