@@ -24,7 +24,7 @@
 
   This file contains the definition of the class History that handles the recently 
   issued commands for the history pane.
- */
+*/
 #include "precomp.h"
 #include <wx/wx.h>
 #include <wx/bitmap.h>
@@ -32,8 +32,12 @@
 #include <wx/timer.h>
 #include <wx/statbmp.h>
 #include <wx/statusbr.h>
+#include <wx/stattext.h>
 #include <memory>
 
+extern unsigned char GO_NEXT_SVG_GZ[];
+extern size_t GO_NEXT_SVG_GZ_SIZE;
+
 #ifndef STATUSBAR_H
 #define STATUSBAR_H
 
@@ -60,8 +64,14 @@ public:
   //! Informs the status bar about networking events.
   void NetworkStatus(networkState status);
 
-  wxStaticBitmap *GetNetworkStatusElement()
-  { return m_networkStatus; }
+  wxWindow *GetNetworkStatusElement()
+    { return m_networkStatus; }
+
+  wxWindow *GetStatusTextElement()
+    { return m_statusTextPanel; }
+
+  wxWindow *GetMaximaStatusElement()
+    { return m_maximaStatus; }
 
   //! Inform the status bar how many percents of the available CPU power maxima uses
   void SetMaximaCPUPercentage(float percentage)
@@ -69,7 +79,26 @@ public:
       m_maximaPercentage = percentage;
       NetworkStatus(m_oldNetworkState);
     }
+
+  enum MaximaStatus
+  {
+    wait_for_start,
+    process_wont_start,
+    sending,
+    waiting,
+    waitingForPrompt,
+    waitingForAuth,
+    calculating,
+    parsing,
+    transferring,
+    userinput,
+    disconnected
+  };
+
+  void UpdateStatusMaximaBusy(MaximaStatus status, long bytesFromMaxima);
+  void SetStatusText(wxString statusText){m_statusText->SetLabel(statusText);}
 protected:
+  void StatusMsgDClick(wxCommandEvent &ev);
   void OnSize(wxSizeEvent &event);
   void OnTimerEvent(wxTimerEvent &event);
 
@@ -82,12 +111,12 @@ private:
   /*! How many percents of the available CPU power does maxima use?
 
     See m_maximaPercentage and SetMaximaCPUPercentage()
-   */
+  */
   float m_maximaPercentage;
   /*! How many percents of the available CPU power did maxima use when updating the network icon last?
 
     See m_maximaPercentage and SetMaximaCPUPercentage()
-   */
+  */
   float m_oldmaximaPercentage;
   networkState m_oldNetworkState;
   wxString m_stdToolTip;
@@ -101,11 +130,17 @@ private:
   bool m_icon_shows_transmit;
 
   wxBitmap GetImage(wxString name,
-                    unsigned char *data_128, size_t len_128
+                    unsigned char *data, size_t len
     );
-  
+
+  //! The background for m_statusText;
+  wxPanel *m_statusTextPanel;
+  //! The currently shown network status bitmap
+  wxStaticText *m_statusText;
   //! The currently shown network status bitmap
   wxStaticBitmap *m_networkStatus;
+  //! The currently shown network status bitmap
+  wxStaticBitmap *m_maximaStatus;
   //! The bitmap shown on network errors
   wxBitmap m_network_error;
   //! The bitmap shown while not connected to the network
@@ -124,6 +159,18 @@ private:
   wxTimer SendTimer;
   //! The timer that prolongs the showing of the "receiving" bitmap a bit.
   wxTimer ReceiveTimer;
+  
+  wxBitmap m_bitmap_waitForStart;
+  wxBitmap m_bitmap_process_wont_start;
+  wxBitmap m_bitmap_sending;
+  wxBitmap m_bitmap_waiting;
+  wxBitmap m_bitmap_waitingForPrompt;
+  wxBitmap m_bitmap_waitingForAuth;
+  wxBitmap m_bitmap_calculating;
+  wxBitmap m_bitmap_parsing;
+  wxBitmap m_bitmap_transferring;
+  wxBitmap m_bitmap_userinput;
+  wxBitmap m_bitmap_disconnected;
 };
 
 #endif
