@@ -28,13 +28,13 @@
 #ifndef SVGBITMAP_H
 #define SVGBITMAP_H
 
-#include "Cell.h"
-
+#include <memory>
 #include "precomp.h"
 #include <wx/bitmap.h>
-#define NANOSVG_ALL_COLOR_KEYWORDS
 #include "nanoSVG/nanosvg.h"
 #include "nanoSVG/nanosvgrast.h"
+#include "Cell.h"
+#define NANOSVG_ALL_COLOR_KEYWORDS
 
 /*! A wxBitmap with a constructor that generates the image from SVG.
  */
@@ -49,14 +49,16 @@ public:
   SvgBitmap &operator=(SvgBitmap &&o);
 
   //! Converts rgba data to a wxBitmap
-  static wxBitmap RGBA2wxBitmap(const unsigned char imgdata[],const int &width, const int &height, const int &scaleFactor = 1);
+  static wxBitmap RGBA2wxBitmap(const unsigned char imgdata[],
+                                const int &width, const int &height,
+                                const int &scaleFactor = 1);
   //! Sets the bitmap to a new size and renders the svg image at this size.
   const SvgBitmap& SetSize(int width, int height);
   //! Sets the bitmap to a new size and renders the svg image at this size.
   const SvgBitmap& SetSize(wxSize siz){return SetSize(siz.x, siz.y);}
   //! Gets the original size of the svg image
   wxSize GetOriginalSize() const
-  { return m_svgImage ? wxSize(m_svgImage->width, m_svgImage->height) : wxDefaultSize; }
+    { return m_svgImage ? wxSize(m_svgImage->width, m_svgImage->height) : wxDefaultSize; }
   /*! An "invalid bitmap" sign */
   wxBitmap GetInvalidBitmap(int targetSize);
 private:
@@ -67,7 +69,7 @@ private:
   //! The renderable svg image after we have read it in
   std::unique_ptr<NSVGimage, decltype(std::free)*> m_svgImage{nullptr, std::free};
   //! The window this bitmap will be drawn on
-  wxWindow *m_window;
+  wxWindow *m_window = NULL;
 };
 
 #endif // SVGBITMAP_H
