@@ -24,15 +24,16 @@
 
   This file contains the definition of the class TableOfContents that handles the 
   table of contents pane.
- */
-#include "precomp.h"
-#include "Configuration.h"
-#include "RegexCtrl.h"
+*/
+#include <memory>
 #include <wx/wx.h>
 #include <wx/timer.h>
 #include <wx/listctrl.h>
 #include <wx/dragimag.h>
 #include <vector>
+#include "precomp.h"
+#include "Configuration.h"
+#include "RegexCtrl.h"
 #include "GroupCell.h"
 
 #ifndef TABLEOFCONTENTS_H
@@ -50,25 +51,7 @@ enum
 class TableOfContents : public wxPanel
 {
 public:
-  enum PopIds
-  {
-    popid_Fold = wxID_HIGHEST + 1500,
-    popid_Unfold,
-    popid_SelectTocChapter,
-    popid_EvalTocChapter,
-    popid_ToggleTOCshowsSectionNumbers,
-    popid_tocLevel1,
-    popid_tocLevel2,
-    popid_tocLevel3,
-    popid_tocLevel4,
-    popid_tocLevel5,
-    popid_tocLevel6,
-    popid_tocdnd,
-    popid_tocMoveIn,
-    popid_tocMoveOut
-  };
-
-  TableOfContents(wxWindow *parent, int id, Configuration **config, std::unique_ptr<GroupCell> *tree);
+  TableOfContents(wxWindow *parent, int id, Configuration *config, std::unique_ptr<GroupCell> *tree);
 
   /* The destructor
    */
@@ -83,9 +66,9 @@ public:
 
     Since this function traverses the tree and we don't want it 
     to impact the performance too much
-      - we call it only on creation of a cell and on leaving it again
-      - and we only traverse the tree if the pane is actually shown.
-   */
+    - we call it only on creation of a cell and on leaving it again
+    - and we only traverse the tree if the pane is actually shown.
+  */
   void UpdateTableOfContents(GroupCell *pos);
 
   //! Get the nth Cell in the table of contents.
@@ -93,7 +76,7 @@ public:
 
   //! Returns the cell that was last right-clicked on.
   GroupCell *RightClickedOn()
-  { return m_cellRightClickedOn; }
+    { return m_cellRightClickedOn; }
 
   GroupCell *DNDStart() {return m_dndStartCell;}
   GroupCell *DNDEnd() {return m_dndEndCell;}
@@ -116,12 +99,12 @@ private:
   wxDragImage *m_dragImage = NULL;
   std::vector<GroupCell *> m_displayedGroupCells;
   //! How many toc items did the user drag at the same time?
-  int m_numberOfCaptionsDragged;
+  unsigned int m_numberOfCaptionsDragged;
   GroupCell *m_cellRightClickedOn;
   //! The item that was dragged away at the start of the current drag-and-drop
-  int m_dragStart = -1;
-  int m_dragStop = -1;
-  long m_dragCurrentPos = -1;
+  long m_dragStart = -1;
+  long m_dragStop = -1;
+  signed long m_dragCurrentPos = -1;
   //! The position the dragged item was when we last displayed the reordered toc
   int m_dragFeedback_Last = -1;
   //! The last selected item
@@ -134,7 +117,7 @@ private:
   RegexCtrl *m_regex;
   //! The items we displayed the last time update() was called
   wxArrayString m_items_old;
-  Configuration **m_configuration;
+  Configuration *m_configuration;
 
   std::vector<GroupCell *> m_structure;
 };
