@@ -24,12 +24,13 @@
 
 /*! \file
   This file declares the class ToolBar that represents wxMaxima's main tool bar.
- */
+*/
 
-#include "precomp.h"
+#include <memory>
 #include <wx/wx.h>
 #include <wx/aui/aui.h>
 #include <wx/choice.h>
+#include "precomp.h"
 #include "AnimationCell.h"
 #include "GroupCell.h"
 
@@ -63,29 +64,29 @@ public:
   };
 
   wxBitmap GetBitmap(wxString name,
-                     unsigned char *data, size_t len, wxSize siz = wxSize(-1,-1));
+                     unsigned char *data, size_t len, wxSize siz = wxSize(-1, -1));
 
   virtual ~ToolBar();
 
   //! Show that user input is needed for maxima to continue
   void ShowUserInputBitmap()
-  {
-    if (!m_needsInformation)
     {
-      SetToolBitmap(tb_follow, m_needsInformationIcon);
-      m_needsInformation = true;
+      if (!m_needsInformation)
+      {
+        SetToolBitmap(tb_follow, m_needsInformationIcon);
+        m_needsInformation = true;
+      }
     }
-  }
 
   //! Stop showing that user input is needed for maxima to continue
   void ShowFollowBitmap()
-  {
-    if (m_needsInformation)
     {
-      SetToolBitmap(tb_follow, m_followIcon);
-      m_needsInformation = false;
+      if (m_needsInformation)
+      {
+        SetToolBitmap(tb_follow, m_followIcon);
+        m_needsInformation = false;
+      }
     }
-  }
 
   void AnimationButtonState(AnimationStartStopState state);
 
@@ -119,68 +120,68 @@ public:
   wxBitmap  m_StopButton;
   
   void CanUndo(bool value)
-  {
-    if (value != m_canUndo_old)
     {
-      EnableTool(wxID_UNDO, value);
-      m_canUndo_old = value;
+      if (value != m_canUndo_old)
+      {
+        EnableTool(wxID_UNDO, value);
+        m_canUndo_old = value;
+      }
     }
-  }
 
   void CanRedo(bool value)
-  {
-    if (value != m_canRedo_old)
     {
-      EnableTool(wxID_UNDO, value);
-      m_canRedo_old = value;
+      if (value != m_canRedo_old)
+      {
+        EnableTool(wxID_UNDO, value);
+        m_canRedo_old = value;
+      }
     }
-  }
 
   void CanCopy(bool value)
-  {
-    if (value != m_canCopy_old)
     {
-      EnableTool(wxID_COPY, value);
-      m_canCopy_old = value;
+      if (value != m_canCopy_old)
+      {
+        EnableTool(wxID_COPY, value);
+        m_canCopy_old = value;
+      }
     }
-  }
 
   void CanCut(bool value)
-  {
-    if (value != m_canCut_old)
     {
-      EnableTool(wxID_CUT, value);
-      m_canCut_old = value;
+      if (value != m_canCut_old)
+      {
+        EnableTool(wxID_CUT, value);
+        m_canCut_old = value;
+      }
     }
-  }
 
   void CanSave(bool value)
-  {
-    if (value != m_canSave_old)
     {
-      EnableTool(wxID_SAVE, value);
-      m_canSave_old = value;
+      if (value != m_canSave_old)
+      {
+        EnableTool(wxID_SAVE, value);
+        m_canSave_old = value;
+      }
     }
-  }
 
   void CanPrint(bool value)
-  {
-    if (value != m_canPrint_old)
     {
-      EnableTool(wxID_PRINT, value);
-      m_canPrint_old = value;
+      if (value != m_canPrint_old)
+      {
+        EnableTool(wxID_PRINT, value);
+        m_canPrint_old = value;
+      }
     }
-  }
 
   void CanEvalTillHere(bool value)
     {
-    if (value != m_canEvalTillHere_old)
-    {
-      EnableTool(tb_evaltillhere, value);
-      EnableTool(tb_evaluate_rest, value);
-      m_canEvalTillHere_old = value;
+      if (value != m_canEvalTillHere_old)
+      {
+        EnableTool(tb_evaltillhere, value);
+        EnableTool(tb_evaluate_rest, value);
+        m_canEvalTillHere_old = value;
+      }
     }
-  }
 
   void CanEvalThisCell(bool value)
     {
@@ -245,42 +246,44 @@ public:
   wxBitmap GetEvalRestBitmap(wxSize siz = wxSize(-1, -1));
   wxBitmap GetHideCodeBitmap(wxSize siz = wxSize(-1, -1));
 
-  bool ShowUndoRedo(){bool show = false;wxConfig::Get()->Read("Toolbar/showUndoRedo",&show);
+  wxSize GetOptimalBitmapSize();
+  wxSize GetPPI();
+  bool ShowUndoRedo(){bool show = false; wxConfig::Get()->Read("Toolbar/showUndoRedo", &show);
     return show;}
-  void ShowUndoRedo(bool show){wxConfig::Get()->Write("Toolbar/showUndoRedo",show);}
+  void ShowUndoRedo(bool show){wxConfig::Get()->Write("Toolbar/showUndoRedo", show);}
 
-  bool ShowCopyPaste(){bool show = true;wxConfig::Get()->Read("Toolbar/showCopyPaste",&show);
+  bool ShowCopyPaste(){bool show = true; wxConfig::Get()->Read("Toolbar/showCopyPaste", &show);
     return show;}
-  void ShowCopyPaste(bool show){wxConfig::Get()->Write("Toolbar/showCopyPaste",show);}
+  void ShowCopyPaste(bool show){wxConfig::Get()->Write("Toolbar/showCopyPaste", show);}
 
-  bool ShowOpenSave(){bool show = true;wxConfig::Get()->Read("Toolbar/showOpenSave",&show);
+  bool ShowOpenSave(){bool show = true; wxConfig::Get()->Read("Toolbar/showOpenSave", &show);
     return show;}
-  void ShowOpenSave(bool show){wxConfig::Get()->Write("Toolbar/showOpenSave",show);}
+  void ShowOpenSave(bool show){wxConfig::Get()->Write("Toolbar/showOpenSave", show);}
   
-  bool ShowNew(){bool show = true;wxConfig::Get()->Read("Toolbar/showNew",&show);
+  bool ShowNew(){bool show = true; wxConfig::Get()->Read("Toolbar/showNew", &show);
     return show;}
-  void ShowNew(bool show){wxConfig::Get()->Write("Toolbar/showNew",show);}
+  void ShowNew(bool show){wxConfig::Get()->Write("Toolbar/showNew", show);}
 
-  bool ShowSearch(){bool show = true;wxConfig::Get()->Read("Toolbar/showSearch",&show);
+  bool ShowSearch(){bool show = true; wxConfig::Get()->Read("Toolbar/showSearch", &show);
     return show;}
-  void ShowSearch(bool show){wxConfig::Get()->Write("Toolbar/showSearch",show);}
+  void ShowSearch(bool show){wxConfig::Get()->Write("Toolbar/showSearch", show);}
 
-  bool ShowHelp(){bool show = true;wxConfig::Get()->Read("Toolbar/showHelp",&show);
+  bool ShowHelp(){bool show = true; wxConfig::Get()->Read("Toolbar/showHelp", &show);
     return show;}
-  void ShowHelp(bool show){wxConfig::Get()->Write("Toolbar/showHelp",show);}
+  void ShowHelp(bool show){wxConfig::Get()->Write("Toolbar/showHelp", show);}
 
-  bool ShowPrint(){bool show = true;wxConfig::Get()->Read("Toolbar/showPrint",&show);
+  bool ShowPrint(){bool show = true; wxConfig::Get()->Read("Toolbar/showPrint", &show);
     return show;}
-  void ShowPrint(bool show){wxConfig::Get()->Write("Toolbar/showPrint",show);}
+  void ShowPrint(bool show){wxConfig::Get()->Write("Toolbar/showPrint", show);}
 
-  bool ShowOptions(){bool show = true;wxConfig::Get()->Read("Toolbar/showOptions",&show);
+  bool ShowOptions(){bool show = true; wxConfig::Get()->Read("Toolbar/showOptions", &show);
     return show;}
-  void ShowOptions(bool show){wxConfig::Get()->Write("Toolbar/showOptions",show);}
+  void ShowOptions(bool show){wxConfig::Get()->Write("Toolbar/showOptions", show);}
 
-  bool ShowSelectAll(){bool show = true;wxConfig::Get()->Read("Toolbar/showSelectAll",&show);
+  bool ShowSelectAll(){bool show = true; wxConfig::Get()->Read("Toolbar/showSelectAll", &show);
     return show;}
-  void ShowSelectAll(bool show){wxConfig::Get()->Write("Toolbar/showSelectAll",show);}
-
+  void ShowSelectAll(bool show){wxConfig::Get()->Write("Toolbar/showSelectAll", show);}
+  
 protected:
   void OnSize(wxSizeEvent &event);
   void OnMouseRightDown(wxMouseEvent &event);
@@ -296,16 +299,16 @@ private:
   int m_animationDisplayedIndex;
   //! The length of the current animation at the last call of UpdateSlider()
   int m_animationMaxIndex;
-  bool m_canRedo_old;
-  bool m_canUndo_old;
-  bool m_canCopy_old;
-  bool m_canCut_old;
-  bool m_canSave_old;
-  bool m_canPrint_old;
-  bool m_canEvalTillHere_old;
-  bool m_canEvalThisCell_old;
+  bool m_canRedo_old = true;
+  bool m_canUndo_old = true;
+  bool m_canCopy_old = true;
+  bool m_canCut_old  = true;
+  bool m_canSave_old = true;
+  bool m_canPrint_old = true;
+  bool m_canEvalTillHere_old = true;
+  bool m_canEvalThisCell_old = true;
   std::unique_ptr<struct NSVGrasterizer, decltype(std::free)*> m_svgRast{nullptr, std::free};
-  bool m_worksheetEmpty_old;
+  bool m_worksheetEmpty_old  = false ;
   AnimationStartStopState m_AnimationStartStopState;
   //! True if we show the "needs information" button.
   bool m_needsInformation;
