@@ -25,13 +25,15 @@
   This file defines the class Worksheet
 
   Worksheet represents the worksheet.
- */
+*/
 
 #ifndef WORKSHEET_H
 #define WORKSHEET_H
 
 #include "stx/optional.hpp"
 #include "precomp.h"
+#include "MaximaManual.h"
+#include "EventIDs.h"
 #include <wx/wx.h>
 #include <wx/xml/xml.h>
 #include <wx/aui/aui.h>
@@ -39,6 +41,9 @@
 #include <wx/fdrepdlg.h>
 #include <wx/dc.h>
 #include <thread>
+#include <vector>
+#include <utility>
+#include <memory>
 #include <list>
 #include "CellPointers.h"
 #include "VariablesPane.h"
@@ -57,36 +62,35 @@
 
 /*! The canvas that contains the spreadsheet the whole program is about.
 
-This canvas contains all the math-, title-, image- input- ("editor-")- etc.-
-cells of the current session.
+  This canvas contains all the math-, title-, image- input- ("editor-")- etc.-
+  cells of the current session.
 
-Most of the logic that handles that this canvas might be larger than the screen
-(and could even be larger than the computer's RAM would it have been handled as
-a big bitmap) is provided by wxWidgets:
- - If part of the screen needs to be drawn it calls the OnPaint() method.
- - If the canvas is scrolled wxWidgets the parts that are already decides how much
-   of the off-screen part of the canvas is cached in a backing store
- - Also if the canvas is scrolled wxWidgets is intelligent enough to only request
-   the parts of the new view that aren't available on the screen or in the backing
-   store
- - If we call the Refresh() method wxWidgets requests us to draw the entire visible
-   part of the worksheet anew and invalidates all cached areas it might have.
- - and the RefreshRect() method notifies wxWidgets that a rectangular region
-   contains changes that need to be redrawn.
+  Most of the logic that handles that this canvas might be larger than the screen
+  (and could even be larger than the computer's RAM would it have been handled as
+  a big bitmap) is provided by wxWidgets:
+  - If part of the screen needs to be drawn it calls the OnPaint() method.
+  - If the canvas is scrolled wxWidgets the parts that are already decides how much
+  of the off-screen part of the canvas is cached in a backing store
+  - Also if the canvas is scrolled wxWidgets is intelligent enough to only request
+  the parts of the new view that aren't available on the screen or in the backing
+  store
+  - If we call the Refresh() method wxWidgets requests us to draw the entire visible
+  part of the worksheet anew and invalidates all cached areas it might have.
+  - and the RefreshRect() method notifies wxWidgets that a rectangular region
+  contains changes that need to be redrawn.
 
-The worksheet isn't immediately redrawn on a key press, a mouse click or on
-maxima outputting new data. Instead all such events are processed in order until
-wxMaxima has caught up with all the events (which causes wxWidgets to send a Idle
-event to the wxMaxima object) or until we reach a timeout. If the user manages
-to type faster than wxMaxima redraws the screen this allows us to skip
-a few redraws in order to process the keypresses as fast as the user types.
-Also this keeps us responsive even if maxima outputs data faster than
-wxMaxima can display it.
+  The worksheet isn't immediately redrawn on a key press, a mouse click or on
+  maxima outputting new data. Instead all such events are processed in order until
+  wxMaxima has caught up with all the events (which causes wxWidgets to send a Idle
+  event to the wxMaxima object) or until we reach a timeout. If the user manages
+  to type faster than wxMaxima redraws the screen this allows us to skip
+  a few redraws in order to process the keypresses as fast as the user types.
+  Also this keeps us responsive even if maxima outputs data faster than
+  wxMaxima can display it.
 */
 class Worksheet : public wxScrolled<wxWindow>
 {
 public:
-  WX_DECLARE_STRING_HASH_MAP(wxString, HelpFileAnchors);
   //! Is an update of the worksheet controls needed?
   bool UpdateControlsNeeded(){bool result = m_updateControls; m_updateControls = false; return result;}
 private:
@@ -111,8 +115,6 @@ private:
   bool m_scrollToTopOfCell;
   //! Is our window currently active?
   bool m_windowActive;
-  //! The configuration storage
-  Configuration m_configurationTopInstance;
   //! The rectangle we need to refresh.
   wxRegion m_rectToRefresh;
   /*! The size of a scroll step
@@ -130,7 +132,7 @@ private:
   //! Where do we need to start the repainting of the worksheet?
   GroupCell *m_redrawStart;
   //! Do we need to redraw the worksheet?
-  bool m_redrawRequested;
+  bool m_fullRedrawRequested;
   //! The clipboard format "mathML"
 
   //! A class that publishes wxm data to the clipboard
@@ -215,48 +217,48 @@ private:
     Each EditorCell has its own private undo buffer Additionally wxMaxima
     maintains an undo buffer for worksheet changes. It works the following way:
 
-     - Cells normally aren't deleted. They are moved into an undo buffer instead.
-     - The undo buffer is also notified when Cells that are added
-     - If the cursor enters a cell the contents of this cell is saved
-     - And if the cell is left and the contents has changed this information
-       is kept in the undo buffer, as well.
+    - Cells normally aren't deleted. They are moved into an undo buffer instead.
+    - The undo buffer is also notified when Cells that are added
+    - If the cursor enters a cell the contents of this cell is saved
+    - And if the cell is left and the contents has changed this information
+    is kept in the undo buffer, as well.
 
     The add and delete actions offer to choose which undo buffer to use since
     there are two of them:
-     - The normal undo buffer and
-     - The buffer that is used instead if a cell change has been issued by the
-       undo command so the undo action can be reverted.\n
-       This approach allows the undo functionality to use the regular add and
-       delete operations keeping the codebase small.
+    - The normal undo buffer and
+    - The buffer that is used instead if a cell change has been issued by the
+    undo command so the undo action can be reverted.\n
+    This approach allows the undo functionality to use the regular add and
+    delete operations keeping the codebase small.
     @{
   */
 
   /*! The description of one action for the undo (or redo) command.
     This object is immutable - the undo/redo buffer cannot be modified.
-   */
+  */
   class TreeUndoAction
   {
   public:
     TreeUndoAction(GroupCell *start, const wxString &oldText) :
-        m_start(start), m_oldText(oldText)
-    {
-      wxASSERT_MSG(start, _("Bug: Trying to record a cell contents change for undo without a cell."));
-    }
+      m_start(start), m_oldText(oldText)
+      {
+        wxASSERT_MSG(start, _("Bug: Trying to record a cell contents change for undo without a cell."));
+      }
     TreeUndoAction(GroupCell *start, GroupCell *end) :
-        m_start(start), m_newCellsEnd(end)
-    {
-      wxASSERT_MSG(start, _("Bug: Trying to record a cell contents change for undo without a cell."));
-    }
+      m_start(start), m_newCellsEnd(end)
+      {
+        wxASSERT_MSG(start, _("Bug: Trying to record a cell contents change for undo without a cell."));
+      }
     TreeUndoAction(GroupCell *start, GroupCell *end, GroupCell *oldCells) :
-        m_start(start), m_newCellsEnd(end), m_oldCells(oldCells)
-    {
-    }
+      m_start(start), m_newCellsEnd(end), m_oldCells(oldCells)
+      {
+      }
 
     /*! True = This undo action is only part of an atomic undo action.
 
       This is the only mutable part of this action: is is used to indicate its relation to
       other actions in the undo list.
-     */
+    */
     bool m_partOfAtomicAction = false;
 
     /*! The position this action started at.
@@ -324,7 +326,7 @@ private:
   /*! The last cell we have entered.
 
     This pointer is needed for keeping track of cell contents changes.
-   */
+  */
   GroupCell *TreeUndo_ActiveCell;
 
   //! Drop actions from the back of the undo list until itis within the undo limit.
@@ -352,11 +354,11 @@ private:
 
   //! Undo a tree operation.
   bool TreeUndo()
-  { return TreeUndo(&treeUndoActions, &treeRedoActions); }
+    { return TreeUndo(&treeUndoActions, &treeRedoActions); }
 
   //! Redo an undone tree operation.
   bool TreeRedo()
-  { return TreeUndo(&treeRedoActions, &treeUndoActions); }
+    { return TreeUndo(&treeRedoActions, &treeUndoActions); }
 
   //! Can we undo a tree operation?
   bool CanTreeUndo() const;
@@ -365,7 +367,7 @@ private:
   bool CanTreeRedo() const;
 
   /*! The cursor has entered one cell => save the value to see if it has changed.
-  */
+   */
   void TreeUndo_CellEntered();
 
   /*! The cursor is about to leave the current cell => Store the change if the value has changed.
@@ -377,8 +379,8 @@ private:
     \param start      The first cell that has been added
     \param end        The last cell that has been added
     \param undoBuffer Where to store the undo information. This normally is
-      - treeUedoActions for the normal undo buffer or
-      - treeRedoActions for the buffer that allows reverting undos
+    - treeUedoActions for the normal undo buffer or
+    - treeRedoActions for the buffer that allows reverting undos
   */
   void TreeUndo_MarkCellsAsAdded(GroupCell *start, GroupCell *end, UndoActions *undoBuffer);
 
@@ -399,7 +401,7 @@ private:
   /*! Escape all chars that aren't allowed in html.
 
     Also converts \n to <br/>
-   */
+  */
   wxString EscapeHTMLChars(wxString input);
 
   //! Allow indentation by spaces for html by replacing them by non-breakable spaces
@@ -433,8 +435,8 @@ private:
     \param start The cell to start copying at
     \param end   The cell the copy has to end with
     \param asData
-      - true:  The cells are copied in the cell list order.
-      - false: The cells are copied in the draw list order
+    - true:  The cells are copied in the cell list order.
+    - false: The cells are copied in the draw list order
   */
   std::unique_ptr<Cell> CopySelection(Cell *start, Cell *end, bool asData = false) const;
 
@@ -447,13 +449,13 @@ private:
   /*! Has the autosave interval expired?
 
     True means: A save will be issued after the user stops typing.
-   */
+  */
   bool m_autoSaveIntervalExpired;
 
-  #if wxCHECK_VERSION(3,1,1)
+#if wxCHECK_VERSION(3, 1, 1)
   //! Handle pinch-to-zoom-events using the gesture interface
   void OnZoom(wxZoomGestureEvent &event);
-  #endif
+#endif
 
   void OnMouseExit(wxMouseEvent &event);
 
@@ -463,7 +465,7 @@ private:
 
     The canonical way to schedule triggering this function is calling the Refresh()
     function of this class.
-   */
+  */
   void OnPaint(wxPaintEvent &event);
 
   void OnSize(wxSizeEvent &event);
@@ -500,11 +502,11 @@ private:
   void SelectEditable(EditorCell *editor, bool up);
 
   /*! Handle selecting text using the keyboard
- Is called when the all of the following is true:
-  - We have a wxKeyEvent with no active editor,
-  - shift is down and
-  - keycode (ccode) is WXK_UP/WXK_DOWN
- */
+    Is called when the all of the following is true:
+    - We have a wxKeyEvent with no active editor,
+    - shift is down and
+    - keycode (ccode) is WXK_UP/WXK_DOWN
+  */
   void SelectWithChar(int ccode);
 
   /*!
@@ -529,7 +531,7 @@ private:
   void AdjustSize();
 
   void OnEraseBackground(wxEraseEvent& WXUNUSED(event))
-  {}
+    {}
 
   void CheckUnixCopy();
 
@@ -549,7 +551,7 @@ private:
   /*! Is called if wxWidgets wants to erase the worksheet's background
 
     We don't want to erase the worksheet's background.
-   */
+  */
   void EraseBackground(wxEraseEvent &event);
 
   //! The position the left mouse key was pressed at.
@@ -561,24 +563,24 @@ private:
 
     See m_hCaretPosition and EditorCell::GetActiveCell() for the position of the two
     types of cursors.
-   */
+  */
   bool m_hCaretActive;
   /*! The group above the hcaret, NULL for the top of the document
     See EditorCell::GetActiveCell() for the position if the cursor that is drawn as a
     vertical line.
-   */
+  */
   GroupCell *m_hCaretPosition;
   /*! The start for the selection when selecting group with the horizontally drawn cursor
 
     This cell does define were the selection was actually started and therefore does not need
     to be above m_hCaretPositionEnd in the worksheet. See also m_cellPointers.m_selectionStart.
-   */
+  */
   GroupCell *m_hCaretPositionStart;
   /*! The end of the selection when selecting group with the horizontally drawn cursor
 
     This cell does define where the selection was actually ended and therefore does not need
     to be below m_hCaretPositionEnd in the worksheet. See also m_cellPointers.m_selectionEnd.
-   */
+  */
   GroupCell *m_hCaretPositionEnd;
   bool m_leftDown;
   //! Do we want to automatically scroll to a cell as soon as it is being evaluated?
@@ -600,18 +602,17 @@ private:
   //! The cursor blink rate. Also the timeout for redrawing the worksheet
   wxTimer m_caretTimer;
   //! True if no changes have to be saved.
-  bool m_saved;
+  bool m_saved = true;
   wxArrayString m_completions;
   bool m_autocompleteTemplates;
   AutocompletePopup *m_autocompletePopup;
 
 public:
-  wxString GetMaximaHelpFile();
   void SetMaximaVersion(wxString version){m_maximaVersion = version;}
   wxString GetMaximaVersion(){return m_maximaVersion;}
   //! Is this worksheet empty?
   bool IsEmpty() const
-  { return !m_tree || (!m_tree->GetNext() && m_tree->GetEditable()->GetValue().Length()<=1); }
+    { return !m_tree || (!m_tree->GetNext() && m_tree->GetEditable()->GetValue().Length() <= 1); }
   //! Close the autocompletion pop-up if it is currently open.
   void CloseAutoCompletePopup()
     {
@@ -623,13 +624,13 @@ public:
 
     Can call OnCharInActive or OnCharNoActive, if appropriate. See OnKeyDown for
     non-printable characters like "up" or "right".
-   */
+  */
   void OnChar(wxKeyEvent &event);
 
   /*! A special key has been pressed
 
     Printable characters are handled by OnChar instead.
-   */
+  */
   void OnKeyDown(wxKeyEvent &event);
   //! Change the style of a cell
   void SetCellStyle(GroupCell *group, GroupType style);
@@ -650,17 +651,16 @@ public:
   /*! Inform the user that something happened in a non-active window
 
     This command will be ignored if the wxMaxima window is currently active
-   */
+  */
   void SetNotification(const wxString &message, int flags = wxICON_INFORMATION);
 
   //! Is called if this element looses or gets the focus
   void OnActivate(wxActivateEvent &event);
-  /*! The pointer to the currently active central settings storage
-
-    Whilst printing or exporting the worksheet a settings storage
-    with the print settings might be active.
+private:
+  /*! The pointer to thesettings storage
    */
   Configuration *m_configuration;
+public:
   //! The storage for the autocompletion feature
   AutoComplete m_autocomplete;
 
@@ -669,16 +669,16 @@ public:
 
   //! Tells us which cell the keyboard selection has started in
   EditorCell *KeyboardSelectionStart() const
-  { return m_cellPointers.m_cellKeyboardSelectionStartedIn; }
+    { return m_cellPointers.m_cellKeyboardSelectionStartedIn; }
 
   EditorCell *MouseSelectionStart() const
-  { return m_cellPointers.m_cellMouseSelectionStartedIn; }
+    { return m_cellPointers.m_cellMouseSelectionStartedIn; }
 
   EditorCell *SearchStart() const
-  { return m_cellPointers.m_cellSearchStartedIn; }
+    { return m_cellPointers.m_cellSearchStartedIn; }
 
   int IndexSearchStartedAt()
-  { return m_cellPointers.m_indexSearchStartedAt; }
+    { return m_cellPointers.m_indexSearchStartedAt; }
 
   CellPointers &GetCellPointers() { return m_cellPointers; }
 
@@ -694,7 +694,7 @@ public:
 
     This function actually only schedules the update of the table-of-contents-tab.
     The actual update is done when wxMaxima is idle.
-   */
+  */
   void UpdateTableOfContents() { m_scheduleUpdateToc = true; }
 
   /*! Handle redrawing the worksheet or of parts of it
@@ -714,15 +714,15 @@ public:
   */
   //! Request the worksheet to be redrawn
   void MarkRefreshAsDone()
-  {
-    m_redrawStart = NULL;
-    m_redrawRequested = false;
-  }
+    {
+      m_redrawStart = NULL;
+      m_fullRedrawRequested = false;
+    }
 
   /*! Redraw the worksheet if RequestRedraw() has been called.
 
     Also handles setting tooltips and redrawing the brackets on mouse movements.
-   */
+  */
   bool RedrawIfRequested();
 
   /*! Request the worksheet to be redrawn
@@ -736,7 +736,7 @@ public:
     real time.
 
     \return true, if we did redraw a workscreet portion.
-   */
+  */
   void RequestRedraw(GroupCell *start = NULL);
   /*! Request a part of the worksheet to be redrawn
 
@@ -746,19 +746,15 @@ public:
     The actual redraw is done in the idle loop which means that as many redraw
     actions are merged as is necessary to allow wxMaxima to process things in
     real time.
-   */
+  */
   void RequestRedraw(wxRect rect);
 
   //! Redraw the window now and mark any pending redraw request as "handled".
   void ForceRedraw()
-  {
-    RequestRedraw();
-    RedrawIfRequested();
-  }
-
-  //! Is a Redraw requested?
-  bool RedrawRequested() const
-    { return m_redrawRequested || m_mouseMotionWas || m_rectToRefresh.IsEmpty(); }
+    {
+      RequestRedraw();
+      RedrawIfRequested();
+    }
 
   //! To be called after enabling or disabling the visibility of code cells
   void CodeCellVisibilityChanged();
@@ -766,16 +762,13 @@ public:
   //! Re-read the configuration
   void UpdateConfig() { m_configuration->ReadConfig(); }
 
-  //! The thread the help file anchors are compiled in
-  std::unique_ptr<std::thread> m_helpfileanchorsThread;
-
   //! The name of the currently-opened file
   wxString m_currentFile;
 
   /*! Make a few unicode characters interpretable by maxima.
 
     Does convert the not equal sign to a '#' and similar.
-   */
+  */
   wxString UnicodeToMaxima(wxString s);
 
   //! Scroll to the start of the worksheet.
@@ -800,7 +793,7 @@ public:
 
     \todo Does it make sense to make to allow the text of sections and image cells
     with math cells?
-   */
+  */
   bool CanMergeSelection() const;
 
   bool CanUndo() const { return CanTreeUndo() || CanUndoInsideCell(); }
@@ -814,143 +807,11 @@ public:
   /*! Clear the undo and the redo buffer
 
     \addtogroup UndoBufferFill
-   */
+  */
   void TreeUndo_ClearBuffers();
 
-  /*! The ids for all popup menu items.
-  */
-  enum PopIds
-  {
-    /*!
-      This first item of the enum and is assigned a high enough number
-      that it won't collide with the numbers to be found in wxFrame::Event
-     */
-    popid_comment_selection = wxID_HIGHEST + 500,
-    popid_divide_cell,
-    popid_copy_image,
-    popid_copy_animation,
-    popid_copy_svg,
-    popid_copy_emf,
-    popid_copy_rtf,
-    popid_add_watch,
-    popid_add_watch_label,
-    popid_special_constant_percent,
-    popid_changeasterisk,
-    popid_hideasterisk,
-    popid_delete,
-    popid_simplify,
-    popid_expand,
-    popid_factor,
-    popid_solve,
-    popid_solve_num,
-    popid_integrate,
-    popid_diff,
-    popid_subst,
-    popid_plot2d,
-    popid_plot3d,
-    popid_float,
-    popid_edit,
-    popid_add_comment,
-    popid_insert_input,
-    popid_copy_matlab,
-    popid_copy_tex,
-    popid_copy_text,
-    popid_copy_mathml,
-    popid_labels_disable,
-    popid_labels_user,
-    popid_labels_useronly,
-    popid_labels_autogenerated,
-    popid_labelwidth,
-    popid_labelwidth3,
-    popid_labelwidth4,
-    popid_labelwidth5,
-    popid_labelwidth6,
-    popid_labelwidth7,
-    popid_labelwidth8,
-    popid_labelwidth9,
-    popid_labelwidth10,
-    popid_digits_20,
-    popid_digits_50,
-    popid_digits_100,
-    popid_digits_all,
-    popid_digits_all_linebreak,
-    popid_image,
-    popid_change_image,
-    popid_svg,
-    popid_emf,
-    popid_animation_save,
-    popid_animation_start,
-    popid_evaluate,
-    popid_evaluate_section,
-    popid_merge_cells,
-    popid_insert_text,
-    popid_insert_title,
-    popid_insert_section,
-    popid_insert_subsection,
-    popid_insert_subsubsection,
-    popid_insert_heading5,
-    popid_insert_heading6,
-    popid_auto_answer,
-    popid_never_autoanswer,
-    popid_popup_gnuplot,
-    popid_fold,
-    popid_unfold,
-    popid_maxsizechooser,
-    popid_resolutionchooser,
-    popid_reloadimage,
-    popid_suggestion1,
-    popid_suggestion2,
-    popid_suggestion3,
-    popid_suggestion4,
-    popid_suggestion5,
-    popid_suggestion6,
-    popid_suggestion7,
-    popid_suggestion8,
-    popid_suggestion9,
-    popid_suggestion10,
-    popid_hide_tooltipMarker,
-    popid_hide_tooltipMarkerForThisMessage,
-    popid_property_real,
-    popid_property_imaginary,
-    popid_property_complex,
-    popid_property_additive,
-    popid_property_alphabetic,
-    popid_property_bindtest,
-    popid_property_antisymmetric,
-    popid_property_commutative,
-    popid_property_symmetric,
-    popid_property_constant,
-    popid_property_even,
-    popid_property_odd,
-    popid_property_evenfun,
-    popid_property_oddfun,
-    popid_property_increasing,
-    popid_property_decreasing,
-    popid_property_integer,
-    popid_property_noninteger,
-    popid_property_integervalued,
-    popid_property_lassociative,
-    popid_property_rassociative,
-    popid_property_linear,
-    popid_property_mainvar,
-    popid_property_multiplicative,
-    popid_property_nary,
-    popid_property_nonarray,
-    popid_property_nonscalar,
-    popid_property_scalar,
-    popid_property_noun,
-    popid_property_outative,
-    popid_property_posfun,
-    popid_property_rational,
-    popid_property_irrational,
-    popid_property_greaterThan,
-    popid_property_evfun,
-    popid_property_evflag,
-    popid_property_atvalue
-  };
-
   //! The constructor
-  Worksheet(wxWindow *parent, int id, Worksheet *&observer,
+  Worksheet(wxWindow *parent, int id, Worksheet *&observer, Configuration *config,
             wxPoint pos = wxDefaultPosition, wxSize size = wxDefaultSize);
 
   //! The destructor
@@ -969,13 +830,13 @@ public:
 
     \param cells The list of cells that has to be inserted
     \param where The cell the cells have to be inserted after. NULL means:
-           Insert the cells at the beginning of the worksheet.
+    Insert the cells at the beginning of the worksheet.
     \param undoBuffer The buffer the undo information for this action has
-           to be kept in. Might be
-            - treeUndoActions for normal deletes,
-            - treeRedoActions for deletions while executing an undo or
-            - NULL for: Don't keep any copy of the cells.
-   */
+    to be kept in. Might be
+    - treeUndoActions for normal deletes,
+    - treeRedoActions for deletions while executing an undo or
+    - NULL for: Don't keep any copy of the cells.
+  */
   GroupCell *InsertGroupCells(std::unique_ptr<GroupCell> &&cells, GroupCell *where,
                               UndoActions *undoBuffer);
 
@@ -1016,20 +877,20 @@ public:
   void ResetInputPrompts();
 
   bool CanCopy(bool fromActive = false)
-  {
-    return m_cellPointers.m_selectionStart ||
-           (fromActive && m_cellPointers.m_activeCell &&
-            m_cellPointers.m_activeCell->CanCopy());
-  }
+    {
+      return m_cellPointers.m_selectionStart ||
+        (fromActive && m_cellPointers.m_activeCell &&
+         m_cellPointers.m_activeCell->CanCopy());
+    }
 
   bool CanPaste()
-  { return m_cellPointers.m_activeCell || m_hCaretActive; }
+    { return m_cellPointers.m_activeCell || m_hCaretActive; }
 
   bool CanCut()
-  {
-    return (m_cellPointers.m_activeCell && m_cellPointers.m_activeCell->CanCopy()) ||
-           (m_cellPointers.m_selectionStart && m_cellPointers.m_selectionStart->GetType() == MC_TYPE_GROUP);
-  }
+    {
+      return (m_cellPointers.m_activeCell && m_cellPointers.m_activeCell->CanCopy()) ||
+        (m_cellPointers.m_selectionStart && m_cellPointers.m_selectionStart->GetType() == MC_TYPE_GROUP);
+    }
 
   //! Select the whole document
   void SelectAll();
@@ -1042,16 +903,16 @@ public:
     \param start The first cell to delete
     \param end The last cell to delete
     \param undoBuffer The buffer the undo information has to be kept in. Might be
-      - treeUndoActions for normal deletes,
-      - treeRedoActions for deletions while executing an undo or
-      - NULL for: Don't keep any copy of the cells.
+    - treeUndoActions for normal deletes,
+    - treeRedoActions for deletions while executing an undo or
+    - NULL for: Don't keep any copy of the cells.
     \addtogroup UndoBufferFill
   */
   void DeleteRegion(
-          GroupCell *start,
-          GroupCell *end,
-          UndoActions *undoBuffer
-  );
+    GroupCell *start,
+    GroupCell *end,
+    UndoActions *undoBuffer
+    );
 
   /*! Move a range of cells from the document to the undo buffer
 
@@ -1060,9 +921,9 @@ public:
     \addtogroup UndoBufferFill
   */
   void DeleteRegion(
-          GroupCell *start,
-          GroupCell *end
-  );
+    GroupCell *start,
+    GroupCell *end
+    );
 
   /*! Delete the currently selected cells
 
@@ -1082,21 +943,21 @@ public:
   /*! Delete the currently active cell - or the cell above this one.
 
     Used for the "delete current cell" shortcut.
-   */
+  */
   void DeleteCurrentCell();
 
   //! Does it make sense to enable the "Play" button and the slider now?
   bool CanAnimate()
-  {
-    return m_cellPointers.m_selectionStart && m_cellPointers.m_selectionStart == m_cellPointers.m_selectionEnd &&
-           m_cellPointers.m_selectionStart->GetType() == MC_TYPE_SLIDE;
-  }
+    {
+      return m_cellPointers.m_selectionStart && m_cellPointers.m_selectionStart == m_cellPointers.m_selectionEnd &&
+        m_cellPointers.m_selectionStart->GetType() == MC_TYPE_SLIDE;
+    }
 
   /*! Animate the current slide show
 
     \param run
-      - false: Stop the animation
-      - true: Run the animation
+    - false: Stop the animation
+    - true: Run the animation
   */
   void Animate(bool run = true);
 
@@ -1115,9 +976,9 @@ public:
   /*! Copy the current selection to the clipboard
 
     \param astext
-     - true:  Copy the current selection as text
-     - false: Copy the current selection as they would appear in a .wxm file
-   */
+    - true:  Copy the current selection as text
+    - false: Copy the current selection as they would appear in a .wxm file
+  */
   bool Copy(bool astext = false);
 
   //! Copy the selection to the clipboard as it would appear in a .wxm file
@@ -1147,7 +1008,7 @@ public:
   //! Copy the current animation to the clipboard
   bool CopyAnimation();
 
-    //! Copy a svg of the current selection to the clipboard
+  //! Copy a svg of the current selection to the clipboard
   bool CopySVG();
 
 #if wxUSE_ENH_METAFILE
@@ -1167,13 +1028,13 @@ public:
   /*! Export the file to an html document
 
     \todo Worksheet and text cell background work fine, but their names might be interchanged.
-   */
+  */
   bool ExportToHTML(const wxString &file);
 
   /*! Export a region of the file to a .wxm or .mac file maxima's load command can read
 
     \todo Slow: Iterates through a string using [] instead of using an iterator.
-   */
+  */
   void
   ExportToMAC(wxTextFile &output, GroupCell *tree, bool wxm, const std::vector<int> &cellMap, bool fixReorderedIndices);
 
@@ -1183,7 +1044,7 @@ public:
   /*! export to xml compatible file
     \param file The file name
     \param markAsSaved false means that this action doesn't clear the
-                             worksheet's "modified" status.
+    worksheet's "modified" status.
   */
   bool ExportToWXMX(const wxString &file, bool markAsSaved = true);
 
@@ -1198,9 +1059,9 @@ public:
 
   /*! Convert the current selection to a string
     \param lb
-     - true:  Include linebreaks
-     - false: Remove linebreaks from the converted string
-   */
+    - true:  Include linebreaks
+    - false: Remove linebreaks from the converted string
+  */
   wxString GetString(bool lb = false);
 
   GroupCell *GetTree() const { return m_tree.get(); }
@@ -1211,14 +1072,14 @@ public:
     NULL means: No cell is selected.
   */
   Cell *GetSelectionStart() const
-  { return m_cellPointers.m_selectionStart; }
+    { return m_cellPointers.m_selectionStart; }
 
   /*! Return the last of the currently selected cells.
 
     NULL means: No cell is selected.
   */
   Cell *GetSelectionEnd() const
-  { return m_cellPointers.m_selectionEnd; }
+    { return m_cellPointers.m_selectionEnd; }
 
   //! Clear the selection - make it empty, i.e. no selection
   void ClearSelection() { SetSelection(nullptr, nullptr); }
@@ -1259,17 +1120,17 @@ private:
   wxString m_statusText_old;
   bool m_statusTextHas = false;
   bool m_statusTextHas_old = false;
-  void StatusText(wxString text){m_statusText = text;m_statusTextHas = true;}
+  void StatusText(wxString text){m_statusText = text; m_statusTextHas = true;}
   void UnsetStatusText(){m_statusTextHas = false;}
   bool ActivateInput(int direction);
 
 public:
   //! Request to scroll to the cursor as soon as wxMaxima is idle
   void ScrollToCaret()
-  {
-    m_cellPointers.m_scrollToCell = false;
-    m_scrollToCaret = true;
-  }
+    {
+      m_cellPointers.m_scrollToCell = false;
+      m_scrollToCaret = true;
+    }
 
   //! Scrolls to the cursor, if requested.
   bool ScrollToCaretIfNeeded();
@@ -1303,12 +1164,12 @@ public:
     out why it is triggered.
 
     Test case:
-      - Create a code cell
-      - Press the "hide all code cells" button.
-      - click between 2 worksheet cells which makes the cursor appear as a horizontal
-        line
-      - press any letter.
-   */
+    - Create a code cell
+    - Press the "hide all code cells" button.
+    - click between 2 worksheet cells which makes the cursor appear as a horizontal
+    line
+    - press any letter.
+  */
   void ShowPoint(wxPoint point);
 
   //! What to do if the worksheet is in the input focus
@@ -1323,20 +1184,20 @@ public:
   /*! Set the slide of the currently selected animation or advance it by one step
 
     \param change
-      - >=0: The slide the animation has to be set to
-      - <0:  Advance the animation by one step.
-   */
+    - >=0: The slide the animation has to be set to
+    - <0:  Advance the animation by one step.
+  */
   void StepAnimation(int change = 1);
 
   //! Is the editor active in the last cell of the worksheet?
   bool IsActiveInLast()
-  { return m_cellPointers.m_activeCell && m_cellPointers.m_activeCell->GetGroup() == m_last; }
+    { return m_cellPointers.m_activeCell && m_cellPointers.m_activeCell->GetGroup() == m_last; }
 
   //! Returns the last cell of the worksheet
   GroupCell *GetLastCell()
-  {
-    return m_last;
-  }
+    {
+      return m_last;
+    }
 
   //! Is the selection in the current working group?
   bool IsSelectionInWorkingGroup();
@@ -1345,7 +1206,7 @@ public:
 
 /*!
   Set the HCaret to its default location, at the end of the document.
- */
+*/
   void SetDefaultHCaret();
 
   /*! Set the HCaret at the location of the given Cell.
@@ -1374,7 +1235,7 @@ public:
   /*! Is it possible to issue an undo in the currently selected cell?
 
     \return false if no cell is selected or there is no further undo information
-   */
+  */
   bool CanUndoInsideCell() const;
 
   void UndoInsideCell();
@@ -1382,7 +1243,7 @@ public:
   /*! Is it possible to issue an undo in the currently selected cell?
 
     \return false if no cell is selected or no redo can be executed.
-   */
+  */
   bool CanRedoInsideCell() const;
 
   void RedoInsideCell();
@@ -1395,30 +1256,30 @@ public:
     cell being evaluated and now clearly wants the cursor to stay where
     it is) can be achieved by FollowEvaluation(true) or
     FollowEvaluation(false).
-   */
+  */
   void FollowEvaluation(bool followEvaluation);
 
   //! Query if we want to automatically scroll to the cell that is currently evaluated
   bool FollowEvaluation() const
-  { return m_followEvaluation; }
+    { return m_followEvaluation; }
 
   /*! Set or get the "Scrolled away from evaluation" status
 
     Sets FollowEvaluation() to false and enables the toolbar button to follow the
     evaluation process again.
-   */
+  */
   void ScrolledAwayFromEvaluation(bool ScrolledAway);
 
   bool ScrolledAwayFromEvaluation()
-  { return m_scrolledAwayFromEvaluation; }
+    { return m_scrolledAwayFromEvaluation; }
 
   void SaveValue();
 
   bool IsSaved()
-  { return m_saved; }
+    { return m_saved; }
 
   void SetSaved(bool saved)
-    { if(m_saved != saved) m_updateControls = true;m_saved = saved;}
+    { if(m_saved != saved) m_updateControls = true; m_saved = saved;}
 
   void OutputChanged()
     {
@@ -1435,7 +1296,7 @@ public:
 
     Internally this function simulates a click on the "Cell/Evaluate Cell(s)"
     button.
-   */
+  */
   void Evaluate();
 
   //! Adds a group cell to the evaluation queue marking its contents as "outdated".
@@ -1489,7 +1350,7 @@ public:
   /*! Called if the user is using the scrollbar for scrolling through the document
 
     See also OnThumbtrack and OnMouseWheel
-   */
+  */
   void OnScrollChanged(wxScrollEvent &ev);
   /*! Called if the user uses the touchpad for scrolling
 
@@ -1510,59 +1371,50 @@ public:
   /*! Called if the mouse wheel sents events
 
     The virtual mouse wheel touchpads provide are handled by OnThumbtrack instead.
-   */
+  */
   void OnMouseWheel(wxMouseEvent &event);
 
   /*! Do an incremental search from the cursor or the point the last search started at
 
     Used by the find dialog.
     \todo Keep a list of positions the last few letters were found at?
-   */
+  */
   bool FindIncremental(const wxString &str, bool down, bool ignoreCase);
 
   /*! Find the next occurrence of a string
 
     Used by the find dialog.
-   */
+  */
   bool FindNext(const wxString &str, bool down, bool ignoreCase, bool warn = true);
 
   /*! Replace the current occurrence of a string
 
     Used by the find dialog.
-   */
+  */
   void Replace(const wxString &oldString, const wxString &newString, bool ignoreCase);
 
   /*! Replace all occurrences of a string
 
     Used by the find dialog.
-   */
+  */
   int ReplaceAll(const wxString &oldString, const wxString &newString, bool ignoreCase);
 
   wxString GetInputAboveCaret();
 
   wxString GetOutputAboveCaret();
 
+  //! Compile a list of known autocompletion symbols
   void LoadSymbols();
-  //! Collect all keyword anchors in the help file
-  void CompileHelpFileAnchors();
-  //! Load the result from the last CompileHelpFileAnchors from the disk cache
-  bool LoadManualAnchorsFromCache();
-  //! Load the help file anchors from an wxXmlDocument
-  bool LoadManualAnchorsFromXML(wxXmlDocument xmlDocument, bool checkManualVersion = true);
-  //! Load the help file anchors from the built-in list
-  bool LoadBuiltInManualAnchors();
-  //! Save the list of help file anchors to the cache.
-  void SaveManualAnchorsToCache();
 
   bool Autocomplete(AutoComplete::autoCompletionType type = AutoComplete::command);
 
   //! Add a symbol to the autocompletion list
   void AddSymbol(const wxString &fun, AutoComplete::autoCompletionType type = AutoComplete::command)
-  { m_autocomplete.AddSymbol(fun, type); }
+    { m_autocomplete.AddSymbol(fun, type); }
 
   //! Add a xml-encoded list of symbols to the autocompletion list
   void AddSymbols(wxString xml)
-  { m_autocomplete.AddSymbols(xml); }
+    { m_autocomplete.AddSymbols(xml); }
 
   void SetActiveCellText(const wxString &text);
 
@@ -1583,7 +1435,7 @@ public:
   void SelectGroupCell(GroupCell *cell);
 
   /*! Handling questions from and answers for maxima
-  @{
+    @{
   */
   //! Remember the answer to the LastQuestion().
   void SetAnswer(const wxString &answer);
@@ -1598,14 +1450,14 @@ public:
     \retval true = maxima waits for the answer of a question.
   */
   bool QuestionPending()
-  { return m_questionPrompt; }
+    { return m_questionPrompt; }
   //!@}
 
   /*! Does maxima wait for the answer of a question?
 
-*/
+   */
   void QuestionPending(bool pending)
-  { m_questionPrompt = pending; }
+    { m_questionPrompt = pending; }
 
   void SetMaximaDocDir(wxString dir)
     {
@@ -1627,15 +1479,19 @@ public:
     use the last cell maxima was known to work on.
   */
   GroupCell *GetWorkingGroup(bool resortToLast = false) const;
-
+  //! Tries to parse maxima's manual in order to find out which anchors it contains
+  void LoadHelpFileAnchors(wxString docdir, wxString maximaVersion)
+    {m_maximaManual.LoadHelpFileAnchors(docdir, maximaVersion);}
+  wxString GetHelpfileAnchorName(wxString keyword)
+    {return m_maximaManual.GetHelpfileAnchorName(keyword);}
+  wxString GetHelpfileURL(wxString keyword)
+    {return m_maximaManual.GetHelpfileURL(keyword);}
   //! The panel the user can display variable contents in
   Variablespane *m_variablesPane;
 
   //! Returns the index in (%i...) or (%o...)
   int GetCellIndex(Cell *cell) const;
 
-  //! All anchors for keywords maxima's helpfile contains
-  HelpFileAnchors m_helpFileAnchors;
   //! Suggestions for how the word that was right-clicked on could continue
   wxArrayString m_replacementsForCurrentWord;
   //Simple iterator over a Maxima input string, skipping comments and strings
@@ -1658,7 +1514,7 @@ public:
     /*! reference to input string (must be a reference, so it can be modified)
 
       \todo: It is const, so it cannot be modified!?!
-     */
+    */
     const wxString &input;
   };
 
@@ -1673,15 +1529,18 @@ public:
     wxAccStatus GetParent (wxAccessible ** parent);
 //    wxAccStatus GetFocus (int *childId, wxAccessible **child);
     wxAccStatus GetLocation (wxRect &rect, int elementId);
-    wxAccStatus HitTest 	(const wxPoint &pt,
-	                         int *childId, wxAccessible **childObject);
+    wxAccStatus HitTest         (const wxPoint &pt,
+                                 int *childId, wxAccessible **childObject);
     wxAccStatus GetDescription(int childId, wxString *description);
-   private:
+  private:
     wxWindow *m_parent;
     Worksheet *m_worksheet;
   };
 #endif
+  MaximaManual m_maximaManual;
+  MaximaManual *GetMaximaManual() {return &m_maximaManual;}
 protected:
+  void FocusTextControl();
   wxString m_lastQuestion;
   int m_virtualWidth_Last;
   int m_virtualHeight_Last;
@@ -1706,7 +1565,7 @@ protected:
 
 inline Worksheet *Cell::GetWorksheet() const
 {
-  wxWindow *worksheet = (*m_configuration)->GetWorkSheet();
+  wxWindow *worksheet = m_configuration->GetWorkSheet();
   wxASSERT(worksheet != NULL);
   return static_cast<Worksheet*>(worksheet);
 }
