@@ -1,4 +1,5 @@
-// -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
+// -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode:
+// nil -*-
 //
 //  Copyright (C) 2020      Gunter Königsmann <wxMaxima@physikbuch.de>
 //
@@ -21,40 +22,34 @@
 
 /*! \file
   This file contains code to create a wxPanel containing image data.
- */
+*/
 
 #include "WrappingStaticText.h"
-#include <wx/wupdlock.h>
 #include <wx/sizer.h>
+#include <wx/wupdlock.h>
 
-WrappingStaticText::WrappingStaticText(wxWindow* parent, int id, wxString text):
-  wxPanel(parent, -1),
-  m_label(text)
-{
+WrappingStaticText::WrappingStaticText(wxWindow *parent, int id, wxString text)
+  : wxPanel(parent, -1), m_label(text) {
   wxWindowUpdateLocker SpeedUp(this);
   m_textCtrl = new wxStaticText(this, id, text);
-  m_textCtrl->Wrap(GetContentScaleFactor()*600);
+  m_textCtrl->Wrap(GetContentScaleFactor() * 50);
+  //  m_textCtrl->SetMinSize(wxSize(50,10));
   wxSizer *sizer = new wxBoxSizer(wxHORIZONTAL);
-  sizer->Add(m_textCtrl,
-             wxSizerFlags().
-             Expand()
-    );
-  Connect(wxEVT_SIZE, wxSizeEventHandler(WrappingStaticText::OnSize), NULL, this);
-  SetSizerAndFit(sizer);
+  sizer->Add(m_textCtrl, wxSizerFlags().Expand());
+  Connect(wxEVT_SIZE, wxSizeEventHandler(WrappingStaticText::OnSize), NULL,
+          this);
+  SetSizer(sizer);
+  FitInside();
 }
 
-void WrappingStaticText::SetLabel(wxString const &value)
-{
+void WrappingStaticText::SetLabel(wxString const &value) {
   m_textCtrl->SetLabel(m_label = value);
-  m_textCtrl->Wrap(GetSize().GetWidth());
+  //  m_textCtrl->Wrap(GetSize().GetWidth());
 }
 
-void WrappingStaticText::OnSize(wxSizeEvent &event)
-{
-  wxWindowUpdateLocker SpeedUp(this);
+void WrappingStaticText::OnSize(wxSizeEvent &event) {
   m_textCtrl->SetLabel(m_label);
-  m_textCtrl->Wrap(event.GetSize().GetWidth());
-  Layout();
+  m_textCtrl->Wrap(
+		   wxMax(event.GetSize().GetWidth(), 50 * GetContentScaleFactor()));
   event.Skip();
 }
-
