@@ -23,13 +23,15 @@
 #ifndef CONJUGATECELL_H
 #define CONJUGATECELL_H
 
+#include <memory>
+#include <utility>
 #include "Cell.h"
 #include "TextCell.h"
 
 /*! \file
 
   This file defines the class for the cell type that represents a conjugate(x) block.
- */
+*/
 
 /*! A cell that represents a conjugate(x) block
 
@@ -37,18 +39,18 @@
   m_nextToDraw this cell is represented by the following individual 
   cells:
   
-   - The ConjugateCell itself
-   - The opening "conjugate("
-   - The contents
-   - The closing ")".
+  - The ConjugateCell itself
+  - The opening "conjugate("
+  - The contents
+  - The closing ")".
    
   If it isn't broken into multiple cells m_nextToDraw points to the 
   cell that follows this Cell.
- */
+*/
 class ConjugateCell final : public Cell
 {
 public:
-  ConjugateCell(GroupCell *group, Configuration **config, std::unique_ptr<Cell> &&inner);
+  ConjugateCell(GroupCell *group, Configuration *config, std::unique_ptr<Cell> &&inner);
   ConjugateCell(GroupCell *group, const ConjugateCell &cell);
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
@@ -75,9 +77,9 @@ private:
 //** Bitfield objects (0 bytes)
 //**
   void InitBitFields()
-  { // Keep the initialization order below same as the order
-    // of bit fields in this class!
-  }
+    { // Keep the initialization order below same as the order
+      // of bit fields in this class!
+    }
 
   void Recalculate(AFontSize fontsize) override;
 
