@@ -24,11 +24,12 @@
 #define DIFFCELL_H
 
 #include "Cell.h"
+#include <memory>
 
 class DiffCell final : public Cell
 {
 public:
-  DiffCell(GroupCell *group, Configuration **config, std::unique_ptr<Cell> &&base,
+  DiffCell(GroupCell *group, Configuration *config, std::unique_ptr<Cell> &&base,
            std::unique_ptr<Cell> &&diff);
   DiffCell(GroupCell *group, const DiffCell &cell);
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
@@ -69,9 +70,9 @@ private:
 //** Bitfield objects (0 bytes)
 //**
   void InitBitFields()
-  { // Keep the initialization order below same as the order
-    // of bit fields in this class!
-  }
+    { // Keep the initialization order below same as the order
+      // of bit fields in this class!
+    }
 };
 
 #endif // DIFFCELL_H
