@@ -25,11 +25,13 @@
 
 #include "Cell.h"
 #include "TextCell.h"
+#include <memory>
+#include <utility>
 
 /*!\file
 
   This file declares the class ExptCell which represents a exp() or %e^x-construct.
- */
+*/
 
 /*! This cell represents a exp() or %e^x-construct.
 
@@ -37,18 +39,18 @@
   m_nextToDraw this cell is represented by the following individual 
   cells:
   
-   - The ExptCell itself
-   - The opening "exp("
-   - The contents
-   - The closing ")".
+  - The ExptCell itself
+  - The opening "exp("
+  - The contents
+  - The closing ")".
    
   If it isn't broken into multiple cells m_nextToDraw points to the 
   cell that follows this Cell. 
- */
+*/
 class ExptCell final : public Cell
 {
 public:
-  ExptCell(GroupCell *group, Configuration **config, std::unique_ptr<Cell> &&base, std::unique_ptr<Cell> &&expt);
+  ExptCell(GroupCell *group, Configuration *config, std::unique_ptr<Cell> &&base, std::unique_ptr<Cell> &&expt);
   ExptCell(GroupCell *group, const ExptCell &cell);
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
@@ -101,10 +103,10 @@ private:
 //** Bitfield objects (1 bytes)
 //**
   void InitBitFields()
-  { // Keep the initialization order below same as the order
-    // of bit fields in this class!
-    m_isMatrix = false;
-  }
+    { // Keep the initialization order below same as the order
+      // of bit fields in this class!
+      m_isMatrix = false;
+    }
   bool m_isMatrix : 1 /* InitBitFields */;
 };
 
