@@ -24,27 +24,28 @@
 #define FUNCELL_H
 
 #include "Cell.h"
+#include <memory>
 /*! \file
 
   This file declares the class FunCell() that represents a maxima function.
- */
+*/
 
 /*! FunCell represents a maxima function no special visual representation exists for
 
   Examples of functions with special visual representation would be:
-   - SqrtCell
-   - ExptCell
-   - AbsCell
-   - ConjugateCell
+  - SqrtCell
+  - ExptCell
+  - AbsCell
+  - ConjugateCell
 
   In the case that this cell is broken into two lines in the order of
   m_nextToDraw this cell is represented by the following individual 
   cells:
   
-   - The FunCell itself
-   - The function name"
-   - The ParenCell containing its contents
-   - The closing ")".
+  - The FunCell itself
+  - The function name"
+  - The ParenCell containing its contents
+  - The closing ")".
    
   If it isn't broken into multiple cells m_nextToDraw points to the 
   cell that follows this Cell. 
@@ -52,7 +53,7 @@
 class FunCell final : public Cell
 {
 public:
-  FunCell(GroupCell *group, Configuration **config,
+  FunCell(GroupCell *group, Configuration *config,
           std::unique_ptr<Cell> &&name, std::unique_ptr<Cell> &&arg);
   FunCell(GroupCell *group, const FunCell &cell);
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
@@ -94,9 +95,9 @@ private:
 //** Bitfield objects (0 bytes)
 //**
   void InitBitFields()
-  { // Keep the initialization order below same as the order
-    // of bit fields in this class!
-  }
+    { // Keep the initialization order below same as the order
+      // of bit fields in this class!
+    }
 };
 
 #endif // FUNCELL_H
