@@ -27,6 +27,7 @@
 #include <wx/image.h>
 #include "Image.h"
 #include "ImgCellBase.h"
+#include <memory>
 
 #include <wx/filesys.h>
 #include <wx/fs_arc.h>
@@ -34,11 +35,11 @@
 class ImgCell final : public ImgCellBase
 {
 public:
-  ImgCell(GroupCell *group, Configuration **config);
-  ImgCell(GroupCell *group, Configuration **config, const wxMemoryBuffer &image, const wxString &type);
-  ImgCell(GroupCell *group, Configuration **config, const wxString &image, std::shared_ptr<wxFileSystem> filesystem, bool remove = true);
+  ImgCell(GroupCell *group, Configuration *config);
+  ImgCell(GroupCell *group, Configuration *config, const wxMemoryBuffer &image, const wxString &type);
+  ImgCell(GroupCell *group, Configuration *config, const wxString &image, std::shared_ptr<wxFileSystem> filesystem, bool remove = true);
 
-  ImgCell(GroupCell *group, Configuration **config, const wxBitmap &bitmap);
+  ImgCell(GroupCell *group, Configuration *config, const wxBitmap &bitmap);
   ImgCell(GroupCell *group, const ImgCell &cell);
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
@@ -49,11 +50,13 @@ public:
 
   //! Tell the image which gnuplot files it was made from
   void GnuplotSource(wxString sourcefile, wxString datafile, std::shared_ptr<wxFileSystem> filesystem)
-  { if (m_image) m_image->GnuplotSource(sourcefile,datafile, filesystem); }
+    { if (m_image) m_image->GnuplotSource(sourcefile, datafile, filesystem); }
+  void CompressedGnuplotSource(wxString sourcefile, wxString datafile, std::shared_ptr<wxFileSystem> filesystem)
+    { if (m_image) m_image->CompressedGnuplotSource(sourcefile, datafile, filesystem); }
 
   //! The name of the file with gnuplot commands that created this file
   wxString GnuplotSource() const override
-  { return m_image ? m_image->GnuplotSource() : wxString(); }
+    { return m_image ? m_image->GnuplotSource() : wxString(); }
 
   void LoadImage(wxString image, bool remove = true);
 
@@ -77,14 +80,14 @@ public:
     a losslessly compressed png version of the bitmap.
 
     See also GetExtension().
-   */
+  */
   wxSize ToImageFile(wxString filename) override;
 
   /*! Removes the cached scaled image from memory
 
     The scaled version of the image will be recreated automatically once it is 
     needed.
-   */
+  */
   void ClearCache() override { if (m_image) m_image->ClearCache(); }
 
   const wxString &GetToolTip(wxPoint point) const override;
@@ -99,15 +102,15 @@ public:
 
   //! Returns the file name extension that matches the image type
   wxString GetExtension() const override
-  { if (m_image)return m_image->GetExtension(); else return wxEmptyString; }
+    { if (m_image)return m_image->GetExtension(); else return wxEmptyString; }
 
   //! Returns the name of the file the image was originally created from
   wxString GetOrigImageFile() const
-  { return m_origImageFile; }
+    { return m_origImageFile; }
   
   //! Sets the name of the file the image was originally created from
   void SetOrigImageFile(wxString file)
-  { m_origImageFile = file; }
+    { m_origImageFile = file; }
 
   //! Returns the original compressed version of the image
   wxMemoryBuffer GetCompressedImage() const { return m_image->m_compressedImage; }
@@ -130,7 +133,7 @@ public:
   bool CanPopOut() const override { return !m_image->GnuplotSource().empty(); }
 
 private:
-  void SetConfiguration(Configuration **config) override;
+  void SetConfiguration(Configuration *config) override;
   void DrawBoundingBox(wxDC &WXUNUSED(dc), bool WXUNUSED(all) = false) override;
   int GetImageBorderWidth() const override { return m_imageBorderWidth; }
 
@@ -143,11 +146,11 @@ private:
 //** Bitfield objects (1 bytes)
 //**
   void InitBitFields()
-  { // Keep the initialization order below same as the order
-    // of bit fields in this class!
-    m_drawRectangle = true;
-    m_drawBoundingBox = false;
-  }
+    { // Keep the initialization order below same as the order
+      // of bit fields in this class!
+      m_drawRectangle = true;
+      m_drawBoundingBox = false;
+    }
   bool m_drawRectangle : 1 /* InitBitFields */;
   bool m_drawBoundingBox : 1 /* InitBitFields */;
 
