@@ -29,15 +29,15 @@
 
   Labels are TextCells that scale down automatically if they need more space 
   than we got.
- */
+*/
 class LabelCell final : public TextCell
 {
 public:
   //! The constructor for cell that, if displayed, means that something is amiss
-  LabelCell(GroupCell *parent,
-            Configuration **config, wxString automaticLabel, TextStyle style = TS_MAIN_PROMPT);
-  LabelCell(const LabelCell &cell);
-  std::unique_ptr<Cell> Copy() const override;
+  LabelCell(GroupCell *group,
+            Configuration *config, wxString automaticLabel, TextStyle style = TS_MAIN_PROMPT);
+  LabelCell(GroupCell *group, const LabelCell &cell);
+  std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
 
   void Recalculate(AFontSize fontsize) override;
@@ -71,9 +71,9 @@ private:
 //** Bitfield objects (0 bytes)
 //**
   void InitBitFields()
-  { // Keep the initailization order below same as the order
-    // of bit fields in this class!
-  }
+    { // Keep the initialization order below same as the order
+      // of bit fields in this class!
+    }
 
   TextIndex GetLabelIndex() const;
 };
