@@ -1,4 +1,5 @@
-// -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
+// -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode:
+// nil -*-
 //
 //  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
 //            (C) 2014-2018 Gunter Königsmann <wxMaxima@physikbuch.de>
@@ -23,22 +24,22 @@
 /*! \file
   This file defines the class LimitCell
 
-  LimitCell is the Cell type that represents maxima's <code>limit()</code> command.
+  LimitCell is the Cell type that represents maxima's <code>limit()</code>
+  command.
 */
 
 #include "LimitCell.h"
 #include "CellImpl.h"
 
-static constexpr AFontSize MIN_LIMIT_FONT_SIZE{ 8.0f };
-static constexpr float LIMIT_FONT_SIZE_DECREASE{ 1.0f };
+static constexpr AFontSize MIN_LIMIT_FONT_SIZE{8.0f};
+static constexpr float LIMIT_FONT_SIZE_DECREASE{1.0f};
 
-LimitCell::LimitCell(GroupCell *group, Configuration **config,
+LimitCell::LimitCell(GroupCell *group, Configuration *config,
                      std::unique_ptr<Cell> &&base,
                      std::unique_ptr<Cell> &&under,
                      std::unique_ptr<Cell> &&name)
-    : Cell(group, config), m_name(std::move(name)), m_base(std::move(base)),
-      m_under(std::move(under))
-{
+  : Cell(group, config), m_name(std::move(name)), m_base(std::move(base)),
+    m_under(std::move(under)) {
   InitBitFields();
   SetStyle(TS_VARIABLE);
 }
@@ -48,16 +49,16 @@ LimitCell::LimitCell(GroupCell *group, Configuration **config,
 // cppcheck-suppress uninitMemberVar symbolName=LimitCell::m_close
 LimitCell::LimitCell(GroupCell *group, const LimitCell &cell)
   : LimitCell(group, cell.m_configuration, CopyList(group, cell.m_base.get()),
-              CopyList(group, cell.m_under.get()), CopyList(group, cell.m_name.get()))
-{
+	      CopyList(group, cell.m_under.get()),
+	      CopyList(group, cell.m_name.get())) {
   CopyCommonData(cell);
 }
 
 DEFINE_CELL(LimitCell)
 
-void LimitCell::MakeBreakUpCells()
-{
-  if (m_open) return;
+void LimitCell::MakeBreakUpCells() {
+  if (m_open)
+    return;
   m_open = std::make_unique<TextCell>(m_group, m_configuration, "(");
   m_open->SetStyle(TS_FUNCTION);
   m_comma = std::make_unique<TextCell>(m_group, m_configuration, ",");
@@ -66,81 +67,55 @@ void LimitCell::MakeBreakUpCells()
   m_close->SetStyle(TS_FUNCTION);
 }
 
-
-void LimitCell::Recalculate(AFontSize fontsize)
-{
+void LimitCell::Recalculate(AFontSize fontsize) {
   m_base->RecalculateList(fontsize);
-  m_under->RecalculateList({ MIN_LIMIT_FONT_SIZE, fontsize - LIMIT_FONT_SIZE_DECREASE });
+  m_under->RecalculateList(
+			   {MIN_LIMIT_FONT_SIZE, fontsize - LIMIT_FONT_SIZE_DECREASE});
   m_name->RecalculateList(fontsize);
-  if(!IsBrokenIntoLines())
-  {
-    m_width = wxMax(m_name->GetFullWidth(), m_under->GetFullWidth())
-      + m_base->GetFullWidth();
+  if (!IsBrokenIntoLines()) {
+    m_width = wxMax(m_name->GetFullWidth(), m_under->GetFullWidth()) +
+      m_base->GetFullWidth();
     m_center = wxMax(m_base->GetCenterList(), m_name->GetCenterList());
     m_height = m_center + wxMax(m_name->GetMaxDrop() + m_under->GetHeightList(),
                                 m_base->GetMaxDrop());
-  }
-  else
-  {
+  } else {
     m_width = m_height = m_center = 0;
     m_open->RecalculateList(fontsize);
     m_comma->RecalculateList(fontsize);
     m_close->RecalculateList(fontsize);
   }
-  
+
   Cell::Recalculate(fontsize);
 }
 
-void LimitCell::Draw(wxPoint point)
-{
+void LimitCell::Draw(wxPoint point) {
   Cell::Draw(point);
-  if (DrawThisCell(point))
-  {   
+  if (DrawThisCell(point)) {
     wxPoint base(point), under(point), name(point);
 
-    name.x = point.x + wxMax(m_name->GetFullWidth(),
-                           m_under->GetFullWidth()) / 2 -
-             m_name->GetFullWidth() / 2;
+    name.x = point.x +
+      wxMax(m_name->GetFullWidth(), m_under->GetFullWidth()) / 2 -
+      m_name->GetFullWidth() / 2;
     m_name->DrawList(name);
 
-    under.x = point.x + wxMax(m_name->GetFullWidth(),
-                            m_under->GetFullWidth()) / 2 -
-              m_under->GetFullWidth() / 2;
-      
+    under.x = point.x +
+      wxMax(m_name->GetFullWidth(), m_under->GetFullWidth()) / 2 -
+      m_under->GetFullWidth() / 2;
+
     under.y = point.y + m_name->GetMaxDrop() + m_under->GetCenterList();
     m_under->DrawList(under);
 
-    base.x += wxMax(m_name->GetFullWidth(),
-                  m_under->GetFullWidth());
+    base.x += wxMax(m_name->GetFullWidth(), m_under->GetFullWidth());
     m_base->DrawList(base);
   }
 }
 
-wxString LimitCell::ToString() const
-{
+wxString LimitCell::ToString() const {
   wxString s(wxT("limit"));
   wxString under = m_under->ListToString();
   wxString base = m_base->ListToString();
   wxString var = under.SubString(0, under.Find(wxT("->")) - 1);
-  wxString to = under.SubString(under.Find(wxT("->")) + 2,
-								under.Length() - 1);
-  if (to.Right(1) == wxT("+"))
-	to = to.Left(to.Length() - 1) + wxT(",plus");
-  if (to.Right(1) == wxT("-"))
-	to = to.Left(to.Length() - 1) + wxT(",minus");
-
-  s += wxT("(") + base + wxT(",") + var + wxT(",") + to + wxT(")");
-  return s;
-}
-
-wxString LimitCell::ToMatlab() const
-{
-  wxString s(wxT("limit"));
-  wxString under = m_under->ListToMatlab();
-  wxString base = m_base->ListToMatlab();
-  wxString var = under.SubString(0, under.Find(wxT("->")) - 1);
-  wxString to = under.SubString(under.Find(wxT("->")) + 2,
-                                under.Length() - 1);
+  wxString to = under.SubString(under.Find(wxT("->")) + 2, under.Length() - 1);
   if (to.Right(1) == wxT("+"))
     to = to.Left(to.Length() - 1) + wxT(",plus");
   if (to.Right(1) == wxT("-"))
@@ -150,40 +125,50 @@ wxString LimitCell::ToMatlab() const
   return s;
 }
 
-wxString LimitCell::ToTeX() const
-{
+wxString LimitCell::ToMatlab() const {
+  wxString s(wxT("limit"));
+  wxString under = m_under->ListToMatlab();
+  wxString base = m_base->ListToMatlab();
+  wxString var = under.SubString(0, under.Find(wxT("->")) - 1);
+  wxString to = under.SubString(under.Find(wxT("->")) + 2, under.Length() - 1);
+  if (to.Right(1) == wxT("+"))
+    to = to.Left(to.Length() - 1) + wxT(",plus");
+  if (to.Right(1) == wxT("-"))
+    to = to.Left(to.Length() - 1) + wxT(",minus");
+
+  s += wxT("(") + base + wxT(",") + var + wxT(",") + to + wxT(")");
+  return s;
+}
+
+wxString LimitCell::ToTeX() const {
   wxString under = m_under->ListToTeX();
   wxString base = m_base->ListToTeX();
   int varEnd = under.Find(wxT("->"));
   int toStart = 0;
-  if(varEnd == wxNOT_FOUND)
-  {
+  if (varEnd == wxNOT_FOUND) {
     varEnd = under.Find(wxT("\\mbox{\\rightarrow }"));
-    if(varEnd != wxNOT_FOUND)
-    {
+    if (varEnd != wxNOT_FOUND) {
       toStart = varEnd + 19;
       varEnd -= 1;
     }
-  }
-  else
-  {
+  } else {
     toStart = varEnd + 2;
     varEnd -= 1;
   }
-                          
+
   wxString var = under.SubString(0, varEnd);
-  wxString to = under.SubString(toStart,
-                                under.Length() - 1);
-  wxString s = wxT("\\lim_{") + var + wxT("\\to ") + to + wxT("}{") + base + wxT("}");
+  wxString to = under.SubString(toStart, under.Length() - 1);
+  wxString s =
+    wxT("\\lim_{") + var + wxT("\\to ") + to + wxT("}{") + base + wxT("}");
   return s;
 }
 
-wxString LimitCell::ToMathML() const
-{
+wxString LimitCell::ToMathML() const {
   wxString base = m_base->ListToMathML();
 
   wxString from;
-  if (m_under) from = m_under->ListToMathML();
+  if (m_under)
+    from = m_under->ListToMathML();
 
   wxString retval;
   if (from.IsEmpty())
@@ -193,29 +178,26 @@ wxString LimitCell::ToMathML() const
   return (retval);
 }
 
-wxString LimitCell::ToXML() const
-{
+wxString LimitCell::ToXML() const {
   wxString flags;
   if (HasHardLineBreak())
     flags += wxT(" breakline=\"true\"");
 
   return _T("<lm") + flags + wxT("><r>") + m_name->ListToXML() + _T("</r><r>") +
-         m_under->ListToXML() + _T("</r><r>") +
-         m_base->ListToXML() + _T("</r></lm>");
+    m_under->ListToXML() + _T("</r><r>") + m_base->ListToXML() +
+    _T("</r></lm>");
 }
 
-wxString LimitCell::ToOMML() const
-{
+wxString LimitCell::ToOMML() const {
   wxString under = m_under->ListToOMML();
   under.Replace(wxT("->"), wxT("\u2192"));
 
   return _T("<m:func><m:fName><m:limLow><m:e><m:r>lim</m:r></m:e><m:lim>") +
-         under + _T("</m:lim></m:limLow></m:fName><m:e>") +
-         m_base->ListToOMML() + _T("</m:e></m:func>");
+    under + _T("</m:lim></m:limLow></m:fName><m:e>") +
+    m_base->ListToOMML() + _T("</m:e></m:func>");
 }
 
-bool LimitCell::BreakUp()
-{
+bool LimitCell::BreakUp() {
   if (IsBrokenIntoLines())
     return false;
 
@@ -234,9 +216,8 @@ bool LimitCell::BreakUp()
   return true;
 }
 
-void LimitCell::SetNextToDraw(Cell *next)
-{
-  if(IsBrokenIntoLines())
+void LimitCell::SetNextToDraw(Cell *next) {
+  if (IsBrokenIntoLines())
     m_close->SetNextToDraw(next);
   else
     m_nextToDraw = next;
