@@ -36,11 +36,11 @@
 
    \todo If the limit text is very short we should add more space
    between the "lim" and the following text.
- */
+*/
 class LimitCell final : public Cell
 {
 public:
-  LimitCell(GroupCell *group, Configuration **config,
+  LimitCell(GroupCell *group, Configuration *config,
             std::unique_ptr<Cell> &&base, std::unique_ptr<Cell> &&under,
             std::unique_ptr<Cell> &&name);
   LimitCell(GroupCell *group, const LimitCell &cell);
@@ -83,9 +83,9 @@ private:
 //** Bitfield objects (0 bytes)
 //**
   void InitBitFields()
-  { // Keep the initialization order below same as the order
-    // of bit fields in this class!
-  }
+    { // Keep the initialization order below same as the order
+      // of bit fields in this class!
+    }
 };
 
 #endif // LIMITCELL_H
