@@ -1,4 +1,5 @@
-// -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
+// -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode:
+// nil -*-
 //
 //  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
 //            (C) 2014-2018 Gunter Königsmann <wxMaxima@physikbuch.de>
@@ -24,17 +25,17 @@
   This file defines the class ListCell
 
   ListCell is the Cell type that represents a list of math elements.
- */
+*/
 
 #include "ListCell.h"
 #include "CellImpl.h"
 
-ListCell::ListCell(GroupCell *group, Configuration **config, std::unique_ptr<Cell> &&inner) :
-    Cell(group, config),
+ListCell::ListCell(GroupCell *group, Configuration *config,
+                   std::unique_ptr<Cell> &&inner)
+  : Cell(group, config),
     m_open(std::make_unique<TextCell>(group, config, wxT("["))),
     m_innerCell(std::move(inner)),
-    m_close(std::make_unique<TextCell>(group, config, wxT("]")))
-{
+    m_close(std::make_unique<TextCell>(group, config, wxT("]"))) {
   InitBitFields();
   SetStyle(TS_VARIABLE);
 
@@ -62,68 +63,57 @@ ListCell::ListCell(GroupCell *group, Configuration **config, std::unique_ptr<Cel
 // cppcheck-suppress uninitMemberVar symbolName=ListCell::m_signTopHeight
 // cppcheck-suppress uninitMemberVar symbolName=ListCell::m_signBotHeight
 // cppcheck-suppress uninitMemberVar symbolName=ListCell::m_extendHeight
-ListCell::ListCell(GroupCell *group, const ListCell &cell):
-  ListCell(group, cell.m_configuration, CopyList(group, cell.m_innerCell.get()))
-{
+ListCell::ListCell(GroupCell *group, const ListCell &cell)
+  : ListCell(group, cell.m_configuration,
+	     CopyList(group, cell.m_innerCell.get())) {
   CopyCommonData(cell);
 }
 
 DEFINE_CELL(ListCell)
 
-void ListCell::Recalculate(AFontSize fontsize)
-{
+void ListCell::Recalculate(AFontSize fontsize) {
   m_innerCell->RecalculateList(fontsize);
   m_open->RecalculateList(fontsize);
   m_close->RecalculateList(fontsize);
-  
-  m_signWidth  = m_open->GetWidth();
+
+  m_signWidth = m_open->GetWidth();
 
   // If our font provides all the unicode chars we need we don't need
   // to bother which exotic method we need to use for drawing nice parenthesis.
-  if (1.2 * m_open->GetHeight() >= m_innerCell->GetHeightList())
-  {
+  if (1.2 * m_open->GetHeight() >= m_innerCell->GetHeightList()) {
     m_drawAsAscii = true;
     m_signHeight = m_open->GetHeight();
-  }
-  else
-  {
+  } else {
     m_drawAsAscii = false;
     m_signHeight = m_innerCell->GetHeightList();
   }
-  
-  if (IsBrokenIntoLines())
-  {
+
+  if (IsBrokenIntoLines()) {
     m_width = 0;
     m_height = 0;
     m_center = 0;
-  }
-  else
-  {
-    m_width = m_innerCell->GetFullWidth() + m_signWidth * 2;      
-    m_height = wxMax(m_signHeight,m_innerCell->GetHeightList()) + Scale_Px(4);
-    m_center = m_height / 2;   
+  } else {
+    m_width = m_innerCell->GetFullWidth() + m_signWidth * 2;
+    m_height = wxMax(m_signHeight, m_innerCell->GetHeightList()) + Scale_Px(4);
+    m_center = m_height / 2;
   }
   Cell::Recalculate(fontsize);
 }
 
-void ListCell::Draw(wxPoint point)
-{
+void ListCell::Draw(wxPoint point) {
   Cell::Draw(point);
-  if (DrawThisCell(point))
-  { 
-    Configuration *configuration = (*m_configuration);
+  if (DrawThisCell(point)) {
     wxPoint innerCellPos(point);
-    
-    if(m_drawAsAscii)
-    {            
+
+    if (m_drawAsAscii) {
       innerCellPos.x += m_open->GetWidth();
       m_open->DrawList(point);
-      m_close->DrawList(wxPoint(point.x + m_open->GetWidth() + m_innerCell->GetFullWidth(),point.y));
-    }
-    else
-    {
-      wxDC *adc = configuration->GetAntialiassingDC();
-      innerCellPos.y += (m_innerCell->GetCenterList() - m_innerCell->GetHeightList() /2);
+      m_close->DrawList(wxPoint(
+				point.x + m_open->GetWidth() + m_innerCell->GetFullWidth(), point.y));
+    } else {
+      wxDC *adc = m_configuration->GetAntialiassingDC();
+      innerCellPos.y +=
+	(m_innerCell->GetCenterList() - m_innerCell->GetHeightList() / 2);
       SetPen(1.5);
 
       int signWidth = m_signWidth - Scale_Px(2);
@@ -131,71 +121,59 @@ void ListCell::Draw(wxPoint point)
 
       // Left bracket
       const wxPoint pointsL[4] = {
-        {point.x - Scale_Px(1) + signWidth,
-         point.y - m_center + Scale_Px(4)},
-        {point.x + Scale_Px(1),
-         point.y - m_center + Scale_Px(4)},
-        {point.x + Scale_Px(1),
-         point.y + m_center - Scale_Px(4)},
-        {point.x - Scale_Px(1) + signWidth,
-         point.y + m_center - Scale_Px(4)}
-      };
+	{point.x - Scale_Px(1) + signWidth, point.y - m_center + Scale_Px(4)},
+	{point.x + Scale_Px(1), point.y - m_center + Scale_Px(4)},
+	{point.x + Scale_Px(1), point.y + m_center - Scale_Px(4)},
+	{point.x - Scale_Px(1) + signWidth,
+	 point.y + m_center - Scale_Px(4)}};
       adc->DrawLines(4, pointsL);
 
       // Right bracket
       const wxPoint pointsR[4] = {
-        {point.x + m_width + Scale_Px(1) - signWidth,
-         point.y - m_center + Scale_Px(4)},
-        {point.x + m_width - Scale_Px(1),
-         point.y - m_center + Scale_Px(4)},
-        {point.x + m_width - Scale_Px(1),
-         point.y + m_center - Scale_Px(4)},
-        {point.x + m_width + Scale_Px(1) - signWidth,
-         point.y + m_center - Scale_Px(4)}
-      };
+	{point.x + m_width + Scale_Px(1) - signWidth,
+	 point.y - m_center + Scale_Px(4)},
+	{point.x + m_width - Scale_Px(1), point.y - m_center + Scale_Px(4)},
+	{point.x + m_width - Scale_Px(1), point.y + m_center - Scale_Px(4)},
+	{point.x + m_width + Scale_Px(1) - signWidth,
+	 point.y + m_center - Scale_Px(4)}};
       adc->DrawLines(4, pointsR);
     }
-    
+
     m_innerCell->DrawList(innerCellPos);
   }
 }
 
-wxString ListCell::ToString() const
-{
+wxString ListCell::ToString() const {
   wxString s;
-  if(!m_innerCell)
+  if (!m_innerCell)
     return "[]";
-  
+
   if (!IsBrokenIntoLines())
-      s = wxT("[") + m_innerCell->ListToString() + wxT("]");
+    s = wxT("[") + m_innerCell->ListToString() + wxT("]");
   return s;
 }
 
-wxString ListCell::ToMatlab() const
-{
+wxString ListCell::ToMatlab() const {
   wxString s;
   if (!IsBrokenIntoLines())
-	  s = wxT("[") + m_innerCell->ListToMatlab() + wxT("]");
+    s = wxT("[") + m_innerCell->ListToMatlab() + wxT("]");
   return s;
 }
 
-wxString ListCell::ToTeX() const
-{
+wxString ListCell::ToTeX() const {
   wxString s;
-  if (!IsBrokenIntoLines())
-  {
+  if (!IsBrokenIntoLines()) {
     wxString innerCell = m_innerCell->ListToTeX();
 
     // Let's see if the cell contains anything potentially higher than a normal
     // character.
     bool needsLeftRight = false;
     for (size_t i = 0; i < innerCell.Length(); i++)
-      if (!wxIsalnum(innerCell[i]))
-      {
+      if (!wxIsalnum(innerCell[i])) {
         needsLeftRight = true;
         break;
       }
-    
+
     if (needsLeftRight)
       s = wxT("\\left[ ") + m_innerCell->ListToTeX() + wxT("\\right] ");
     else
@@ -204,35 +182,32 @@ wxString ListCell::ToTeX() const
   return s;
 }
 
-wxString ListCell::ToOMML() const
-{
-  return wxT("<m:d><m:dPr m:begChr=\"") + XMLescape(m_open->ToString()) + wxT("\" m:endChr=\"") +
-         XMLescape(m_close->ToString()) + wxT("\" m:grow=\"1\"></m:dPr><m:e>") +
-         m_innerCell->ListToOMML() + wxT("</m:e></m:d>");
+wxString ListCell::ToOMML() const {
+  return wxT("<m:d><m:dPr m:begChr=\"") + XMLescape(m_open->ToString()) +
+    wxT("\" m:endChr=\"") + XMLescape(m_close->ToString()) +
+    wxT("\" m:grow=\"1\"></m:dPr><m:e>") + m_innerCell->ListToOMML() +
+    wxT("</m:e></m:d>");
 }
 
-wxString ListCell::ToMathML() const
-{
+wxString ListCell::ToMathML() const {
   wxString open = m_open->ToString();
   wxString close = m_close->ToString();
-  return (
-          wxT("<mrow><mo>") + XMLescape(open) + wxT("</mo>") +
-          m_innerCell->ListToMathML() +
-          wxT("<mo>") + XMLescape(close) + wxT("</mo></mrow>\n")
-  );
+  return (wxT("<mrow><mo>") + XMLescape(open) + wxT("</mo>") +
+          m_innerCell->ListToMathML() + wxT("<mo>") + XMLescape(close) +
+          wxT("</mo></mrow>\n"));
 }
 
-wxString ListCell::ToXML() const
-{
+wxString ListCell::ToXML() const {
   wxString s = m_innerCell->ListToXML();
   wxString flags;
   if (HasHardLineBreak())
     flags += wxT(" breakline=\"true\"");
-  return (wxT("<r list=\"true\"") + flags + wxT("><t listdelim=\"true\">[</t>") + s + wxT("<t listdelim=\"true\">]</t></r>"));
+  return (wxT("<r list=\"true\"") + flags +
+          wxT("><t listdelim=\"true\">[</t>") + s +
+          wxT("<t listdelim=\"true\">]</t></r>"));
 }
 
-bool ListCell::BreakUp()
-{
+bool ListCell::BreakUp() {
   if (IsBrokenIntoLines())
     return false;
 
@@ -248,9 +223,8 @@ bool ListCell::BreakUp()
   return true;
 }
 
-void ListCell::SetNextToDraw(Cell *next)
-{
-  if(IsBrokenIntoLines())
+void ListCell::SetNextToDraw(Cell *next) {
+  if (IsBrokenIntoLines())
     m_close->SetNextToDraw(next);
   else
     m_nextToDraw = next;
