@@ -28,12 +28,12 @@
 /*! A cell containing a long number
 
   A specialised TextCell, that can display a long number, or shorten it using an ellipsis.
- */
+*/
 class LongNumberCell final : public TextCell
 {
 public:
   //! The constructor for cell that, if displayed, means that something is amiss
-  LongNumberCell(GroupCell *group, Configuration **config, const wxString &number);
+  LongNumberCell(GroupCell *group, Configuration *config, const wxString &number);
   LongNumberCell(GroupCell *group, const LongNumberCell &cell);
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
@@ -74,9 +74,9 @@ private:
   //** Bitfield objects (0 bytes)
   //**
   void InitBitFields()
-  { // Keep the initialization order below same as the order
-    // of bit fields in this class!
-  }
+    { // Keep the initialization order below same as the order
+      // of bit fields in this class!
+    }
 };
 
 #endif // LONGNUMBERCELL_H
