@@ -29,7 +29,7 @@
 /*! \file
 
   This file defines the class for the cell type that represents a square root.
- */
+*/
 
 /*! This class represents a square root
   
@@ -37,18 +37,18 @@
   m_nextToDraw this cell is represented by the following individual 
   cells:
   
-   - The SqrtCell itself
-   - The opening "sqrt("
-   - The contents
-   - The closing ")".
+  - The SqrtCell itself
+  - The opening "sqrt("
+  - The contents
+  - The closing ")".
    
   If it isn't broken into multiple cells m_nextToDraw points to the 
   cell that follows this Cell.
- */
+*/
 class SqrtCell final : public Cell
 {
 public:
-  SqrtCell(GroupCell *group, Configuration **config, std::unique_ptr<Cell> &&inner);
+  SqrtCell(GroupCell *group, Configuration *config, std::unique_ptr<Cell> &&inner);
   SqrtCell(GroupCell *group, const SqrtCell &cell);
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
@@ -92,9 +92,9 @@ private:
 //** Bitfield objects (0 bytes)
 //**
   void InitBitFields()
-  { // Keep the initialization order below same as the order
-    // of bit fields in this class!
-  }
+    { // Keep the initialization order below same as the order
+      // of bit fields in this class!
+    }
 };
 
 #endif // SQRTCELL_H
