@@ -28,7 +28,7 @@
 class SubCell final : public Cell
 {
 public:
-  SubCell(GroupCell *group, Configuration **config,
+  SubCell(GroupCell *group, Configuration *config,
           std::unique_ptr<Cell> &&base, std::unique_ptr<Cell> &&index);
   SubCell(GroupCell *group, const SubCell &cell);
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
@@ -65,9 +65,9 @@ private:
 //** Bitfield objects (0 bytes)
 //**
   void InitBitFields()
-  { // Keep the initialization order below same as the order
-    // of bit fields in this class!
-  }
+    { // Keep the initialization order below same as the order
+      // of bit fields in this class!
+    }
 };
 
 #endif // SUBCELL_H
