@@ -30,7 +30,7 @@
 class SubSupCell final : public Cell
 {
 public:
-  SubSupCell(GroupCell *group, Configuration **config, std::unique_ptr<Cell> &&base);
+  SubSupCell(GroupCell *group, Configuration *config, std::unique_ptr<Cell> &&base);
   SubSupCell(GroupCell *group, const SubSupCell &cell);
   const CellTypeInfo &GetInfo() override;
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
@@ -83,9 +83,9 @@ private:
 //** Bitfield objects (0 bytes)
 //**
   void InitBitFields()
-  { // Keep the initialization order below same as the order
-    // of bit fields in this class!
-  }
+    { // Keep the initialization order below same as the order
+      // of bit fields in this class!
+    }
 };
 
 #endif // SUBSUPCELL_H
