@@ -46,7 +46,7 @@ enum sumStyle : int8_t
 class SumCell final : public Cell
 {
 public:
-  SumCell(GroupCell *group, Configuration **config, sumStyle style,
+  SumCell(GroupCell *group, Configuration *config, sumStyle style,
           std::unique_ptr<Cell> &&under, std::unique_ptr<Cell> &&over,
           std::unique_ptr<Cell> &&base);
   SumCell(GroupCell *group, const SumCell &cell);
@@ -111,10 +111,10 @@ private:
 //** Bitfield objects (1 bytes)
 //**
   void InitBitFields()
-  { // Keep the initialization order below same as the order
-    // of bit fields in this class!
-    m_displayParen = true;
-  }
+    { // Keep the initialization order below same as the order
+      // of bit fields in this class!
+      m_displayParen = true;
+    }
 
   //! Display m_paren if true, or Base() if false
   bool m_displayParen : 1 /* InitBitFields */;
