@@ -28,15 +28,15 @@
 /*! A visibly invalid cell
 
   A placeholder that, if everything works as it should, is overridden, before it is displayed.
- */
+*/
 class VisiblyInvalidCell final : public TextCell
 {
 public:
   //! The constructor for cell that, if displayed, means that something is amiss
-  VisiblyInvalidCell(GroupCell *group, Configuration **config);
+  VisiblyInvalidCell(GroupCell *group, Configuration *config);
   //! Constructor for a cell that shows that something is amiss using a custom tooltip
-  VisiblyInvalidCell(GroupCell *group, Configuration **config, wxString &&toolTip);
-  VisiblyInvalidCell(GroupCell *group, Configuration **config, const wxString *toolTip);
+  VisiblyInvalidCell(GroupCell *group, Configuration *config, wxString &&toolTip);
+  VisiblyInvalidCell(GroupCell *group, Configuration *config, const wxString *toolTip);
   VisiblyInvalidCell(GroupCell *group, const VisiblyInvalidCell &cell);
 //  std::unique_ptr<Cell> Copy(GroupCell *cell) const override;
   const CellTypeInfo &GetInfo() override;
@@ -45,9 +45,9 @@ private:
 //** Bitfield objects (0 bytes)
 //**
   void InitBitFields()
-  { // Keep the initialization order below same as the order
-    // of bit fields in this class!
-  }
+    { // Keep the initialization order below same as the order
+      // of bit fields in this class!
+    }
 };
 
 #endif // VISIBLYINVALIDCELL_H
