@@ -1,4 +1,5 @@
-// -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
+// -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode:
+// nil -*-
 //
 //  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
 //  Copyright (C) 2015-2018 Gunter Königsmann <wxMaxima@physikbuch.de>
@@ -22,7 +23,7 @@
 
 /*! \file
   This file defines the class BitMap that renders math as bitmap.
- */
+*/
 
 #include "BitmapOut.h"
 #include "Cell.h"
@@ -30,9 +31,8 @@
 
 #define BM_FULL_WIDTH 1000
 
-BitmapOut::BitmapOut(Configuration **configuration, double scale) :
-    m_cmn(configuration, BM_FULL_WIDTH, scale)
-{
+BitmapOut::BitmapOut(Configuration **configuration, double scale)
+  : m_cmn(configuration, BM_FULL_WIDTH, scale) {
   m_cmn.SetSize({10, 10});
   m_bmp.CreateScaled(10, 10, 24, scale);
   m_dc.SelectObject(m_bmp);
@@ -46,38 +46,32 @@ BitmapOut::BitmapOut(Configuration **configuration, double scale) :
   config.SetClientHeight(BM_FULL_WIDTH);
 }
 
-BitmapOut::BitmapOut(Configuration **configuration, std::unique_ptr<Cell> &&tree, double scale, long maxSize) :
-    BitmapOut(configuration, scale)
-{
+BitmapOut::BitmapOut(Configuration **configuration,
+                     std::unique_ptr<Cell> &&tree, double scale, long maxSize)
+  : BitmapOut(configuration, scale) {
   Render(std::move(tree), maxSize);
 }
 
-BitmapOut::~BitmapOut()
-{}
+BitmapOut::~BitmapOut() {}
 
-bool BitmapOut::Render(std::unique_ptr<Cell> &&tree, long int maxSize)
-{
+bool BitmapOut::Render(std::unique_ptr<Cell> &&tree, long int maxSize) {
   m_tree = std::move(tree);
   m_isOk = m_tree && Layout(maxSize);
   return m_isOk;
 }
 
-bool BitmapOut::Layout(long int maxSize)
-{
+bool BitmapOut::Layout(long int maxSize) {
   if (!m_cmn.PrepareLayout(m_tree.get()))
     return false;
 
   auto scale = m_cmn.GetScale();
   auto size = m_cmn.GetScaledSize();
   auto rawSize = m_cmn.GetSize();
-  
+
   // Too big bitmaps or bitmaps that are too wide or high can crash windows
   // or the X server.
-  if (maxSize >= 0 && (
-        ((long)size.x * size.y >= maxSize) ||
-        (size.x >= 20000) ||
-        (size.y >= 20000)
-        ))
+  if (maxSize >= 0 && (((long)size.x * size.y >= maxSize) ||
+                       (size.x >= 20000) || (size.y >= 20000)))
     goto failed;
 
   // The depth 24 hinders wxWidgets from creating rgb0 bitmaps that some
@@ -97,25 +91,24 @@ bool BitmapOut::Layout(long int maxSize)
   Draw();
   return true;
 
-failed:
+ failed:
   m_bmp = wxNullBitmap;
   return false;
 }
 
-void BitmapOut::Draw()
-{
+void BitmapOut::Draw() {
   auto &config = m_cmn.GetConfiguration();
   config.ClipToDrawRegion(false);
 
   auto bgColor = config.m_styles[TS_TEXT_BACKGROUND].GetColor();
-  m_dc.SetBackground(*(wxTheBrushList->FindOrCreateBrush(bgColor, wxBRUSHSTYLE_SOLID)));
+  m_dc.SetBackground(
+		     *(wxTheBrushList->FindOrCreateBrush(bgColor, wxBRUSHSTYLE_SOLID)));
   m_dc.Clear();
 
   m_cmn.Draw(m_tree.get());
 }
 
-wxSize BitmapOut::ToFile(const wxString &file)
-{
+wxSize BitmapOut::ToFile(const wxString &file) {
   // Assign a resolution to the bitmap.
   wxImage img = m_bmp.ConvertToImage();
   int resolution = m_cmn.GetScreenConfig().GetDC()->GetPPI().x;
@@ -128,8 +121,7 @@ wxSize BitmapOut::ToFile(const wxString &file)
     success = img.SaveFile(file, wxBITMAP_TYPE_XPM);
   else if (file.EndsWith(wxT(".jpg")))
     success = img.SaveFile(file, wxBITMAP_TYPE_JPEG);
-  else
-  {
+  else {
     if (file.EndsWith(wxT(".png")))
       success = img.SaveFile(file, wxBITMAP_TYPE_PNG);
     else
@@ -142,18 +134,16 @@ wxSize BitmapOut::ToFile(const wxString &file)
     return wxDefaultSize;
 }
 
-std::unique_ptr<wxBitmapDataObject> BitmapOut::GetDataObject() const
-{
+std::unique_ptr<wxBitmapDataObject> BitmapOut::GetDataObject() const {
   return m_isOk ? std::make_unique<wxBitmapDataObject>(GetBitmap()) : nullptr;
 }
 
-bool BitmapOut::ToClipboard() const
-{
+bool BitmapOut::ToClipboard() const {
   if (!m_isOk)
     return false;
-  wxASSERT_MSG(!wxTheClipboard->IsOpened(),_("Bug: The clipboard is already opened"));
-  if (wxTheClipboard->Open())
-  {
+  wxASSERT_MSG(!wxTheClipboard->IsOpened(),
+               _("Bug: The clipboard is already opened"));
+  if (wxTheClipboard->Open()) {
     bool res = wxTheClipboard->SetData(GetDataObject().release());
     wxTheClipboard->Close();
     return res;
