@@ -17,7 +17,6 @@
 #include <wx/radiobut.h>
 #include <wx/spinctrl.h>
 #include <wx/hashmap.h>
-#include <wx/string.h>
 #include <wx/tokenzr.h>
 #include <wx/colour.h>
 #include <wx/font.h>
@@ -28,4 +27,8 @@
 #include <wx/panel.h>
 #include <wx/textctrl.h>
 #include <wx/checkbox.h>
+#include <wx/webview.h>
+#ifdef __WXMSW__
+#include <wx/msw/webview_ie.h>
+#endif
 #endif
