@@ -1,4 +1,5 @@
-// -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
+// -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode:
+// nil -*-
 //
 //  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
 //
@@ -23,27 +24,26 @@
 
 #include <wx/artprov.h>
 #include <wx/config.h>
+#include <wx/windowptr.h>
 
-Plot2DWiz::Plot2DWiz(wxWindow *parent, int id,
-                     Configuration *cfg,
-                     const wxString &title,
-                     const wxPoint &pos, const wxSize &size, long style) :
-        wxDialog(parent, id, title, pos, size, style)
-{
+Plot2DWiz::Plot2DWiz(wxWindow *parent, int id, Configuration *cfg,
+                     const wxString &title, const wxPoint &pos,
+                     const wxSize &size, long style)
+  : wxDialog(parent, id, title, pos, size, style) {
   m_configuration = cfg;
   label_2 = new wxStaticText(this, -1, _("Expression(s):"));
   text_ctrl_1 = new BTextCtrl(this, -1, cfg, wxEmptyString, wxDefaultPosition,
                               wxSize(300, -1));
   button_3 = new wxButton(this, special, _("&Special"));
   label_3 = new wxStaticText(this, -1, _("Variable:"));
-  text_ctrl_2 = new BTextCtrl(this, -1, cfg, wxT("x"), wxDefaultPosition,
-                              wxSize(40, -1));
+  text_ctrl_2 =
+    new BTextCtrl(this, -1, cfg, wxT("x"), wxDefaultPosition, wxSize(40, -1));
   label_4 = new wxStaticText(this, -1, _("From:"));
   text_ctrl_3 = new BTextCtrl(this, -1, cfg, wxT("-5"), wxDefaultPosition,
                               wxSize(70, -1));
   label_5 = new wxStaticText(this, -1, _("To:"));
-  text_ctrl_4 = new BTextCtrl(this, -1, cfg, wxT("5"), wxDefaultPosition,
-                              wxSize(70, -1));
+  text_ctrl_4 =
+    new BTextCtrl(this, -1, cfg, wxT("5"), wxDefaultPosition, wxSize(70, -1));
   check_box_1 = new wxCheckBox(this, -1, _("logscale"));
   label_6 = new wxStaticText(this, -1, _("Variable:"));
   text_ctrl_5 = new BTextCtrl(this, -1, cfg, wxT("y"), wxDefaultPosition,
@@ -52,41 +52,32 @@ Plot2DWiz::Plot2DWiz(wxWindow *parent, int id,
   text_ctrl_6 = new BTextCtrl(this, -1, cfg, wxT("-5"), wxDefaultPosition,
                               wxSize(70, -1));
   label_8 = new wxStaticText(this, -1, _("To:"));
-  text_ctrl_7 = new BTextCtrl(this, -1, cfg, wxT("5"), wxDefaultPosition,
-                              wxSize(70, -1));
+  text_ctrl_7 =
+    new BTextCtrl(this, -1, cfg, wxT("5"), wxDefaultPosition, wxSize(70, -1));
   check_box_2 = new wxCheckBox(this, -1, _("logscale"));
   label_9 = new wxStaticText(this, -1, _("Ticks:"));
   text_ctrl_8 = new wxSpinCtrl(this, -1, wxEmptyString, wxDefaultPosition,
                                wxSize(70, -1), wxSP_ARROW_KEYS, 0, 1000, 10);
   text_ctrl_8->SetValue(10);
   label_10 = new wxStaticText(this, -1, _("Format:"));
-  const wxString combo_box_1_choices[] =
-          {
-                  _("default"),
-                  _("inline"),
-                  wxT("gnuplot"),
-                  wxT("xmaxima")
-          };
-  combo_box_1 = new wxComboBox(this, -1, wxEmptyString, wxDefaultPosition,
-                               wxSize(150, -1), 4,
-                               combo_box_1_choices, wxCB_DROPDOWN);
+  const wxString combo_box_1_choices[] = {_("default"), _("inline"),
+    wxT("gnuplot"), wxT("xmaxima")};
+  combo_box_1 =
+    new wxComboBox(this, -1, wxEmptyString, wxDefaultPosition,
+		   wxSize(150, -1), 4, combo_box_1_choices, wxCB_DROPDOWN);
   label_11 = new wxStaticText(this, -1, _("Options:"));
-  const wxString combo_box_2_choices[] =
-          {
-                  wxT("set zeroaxis;"),
-                  wxT("set size ratio 1; set zeroaxis;"),
-                  wxT("set grid;"),
-                  wxT("set polar; set zeroaxis;")
-          };
-  combo_box_2 = new wxComboBox(this, combobox, wxEmptyString, wxDefaultPosition,
-                               wxSize(280, -1), 4,
-                               combo_box_2_choices, wxCB_DROPDOWN);
+  const wxString combo_box_2_choices[] = {
+    wxT("set zeroaxis;"), wxT("set size ratio 1; set zeroaxis;"),
+    wxT("set grid;"), wxT("set polar; set zeroaxis;")};
+  combo_box_2 =
+    new wxComboBox(this, combobox, wxEmptyString, wxDefaultPosition,
+		   wxSize(280, -1), 4, combo_box_2_choices, wxCB_DROPDOWN);
   label_12 = new wxStaticText(this, -1, _("File:"));
   text_ctrl_9 = new BTextCtrl(this, -1, cfg, wxEmptyString, wxDefaultPosition,
                               wxSize(280, -1));
-  button_4 = new wxBitmapButton(this, file_browse_2d,
-                                wxArtProvider::GetBitmap(wxART_FILE_OPEN,
-                                                         wxART_HELP_BROWSER));
+  button_4 = new wxBitmapButton(
+				this, file_browse_2d,
+				wxArtProvider::GetBitmap(wxART_FILE_OPEN, wxART_HELP_BROWSER));
   static_line_1 = new wxStaticLine(this, -1);
 #if defined __WXMSW__
   button_1 = new wxButton(this, wxID_OK, _("OK"));
@@ -102,9 +93,7 @@ Plot2DWiz::Plot2DWiz(wxWindow *parent, int id,
   do_layout();
 }
 
-
-void Plot2DWiz::set_properties()
-{
+void Plot2DWiz::set_properties() {
   SetTitle(_("Plot 2D"));
   text_ctrl_3->SetValue(wxT("-5"));
   text_ctrl_4->SetValue(wxT("5"));
@@ -135,9 +124,7 @@ void Plot2DWiz::set_properties()
   text_ctrl_1->SetFocus();
 }
 
-
-void Plot2DWiz::do_layout()
-{
+void Plot2DWiz::do_layout() {
   wxFlexGridSizer *grid_sizer_1 = new wxFlexGridSizer(4, 1, 0, 0);
   wxBoxSizer *sizer_1 = new wxBoxSizer(wxHORIZONTAL);
   wxFlexGridSizer *grid_sizer_2 = new wxFlexGridSizer(7, 2, 0, 0);
@@ -145,11 +132,13 @@ void Plot2DWiz::do_layout()
   wxBoxSizer *sizer_3 = new wxBoxSizer(wxHORIZONTAL);
   wxBoxSizer *sizer_4 = new wxBoxSizer(wxHORIZONTAL);
   wxBoxSizer *sizer_5 = new wxBoxSizer(wxHORIZONTAL);
-  grid_sizer_2->Add(label_2, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL, 5);
+  grid_sizer_2->Add(label_2, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL,
+                    5);
   sizer_2->Add(text_ctrl_1, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
   sizer_2->Add(button_3, 0, wxALL, 5);
   grid_sizer_2->Add(sizer_2, 1, wxEXPAND, 0);
-  grid_sizer_2->Add(label_3, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL, 5);
+  grid_sizer_2->Add(label_3, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL,
+                    5);
   sizer_3->Add(text_ctrl_2, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
   sizer_3->Add(label_4, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
   sizer_3->Add(text_ctrl_3, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
@@ -157,7 +146,8 @@ void Plot2DWiz::do_layout()
   sizer_3->Add(text_ctrl_4, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
   sizer_3->Add(check_box_1, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
   grid_sizer_2->Add(sizer_3, 1, 0, 0);
-  grid_sizer_2->Add(label_6, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL, 5);
+  grid_sizer_2->Add(label_6, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL,
+                    5);
   sizer_4->Add(text_ctrl_5, 0, wxALL, 5);
   sizer_4->Add(label_7, 0, wxALIGN_CENTER_VERTICAL | wxALL, 5);
   sizer_4->Add(text_ctrl_6, 0, wxALL, 5);
@@ -165,15 +155,19 @@ void Plot2DWiz::do_layout()
   sizer_4->Add(text_ctrl_7, 0, wxALL, 5);
   sizer_4->Add(check_box_2, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
   grid_sizer_2->Add(sizer_4, 1, wxEXPAND, 0);
-  grid_sizer_2->Add(label_9, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL, 5);
+  grid_sizer_2->Add(label_9, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL,
+                    5);
   grid_sizer_2->Add(text_ctrl_8, 0, wxALL, 5);
-  grid_sizer_2->Add(label_10, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL, 5);
+  grid_sizer_2->Add(label_10, 0,
+                    wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL, 5);
   grid_sizer_2->Add(combo_box_1, 0, wxALL, 5);
-  grid_sizer_2->Add(label_11, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL, 5);
+  grid_sizer_2->Add(label_11, 0,
+                    wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL, 5);
   grid_sizer_2->Add(combo_box_2, 0, wxALL, 5);
   sizer_5->Add(text_ctrl_9, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
   sizer_5->Add(button_4, 0, wxALL, 5);
-  grid_sizer_2->Add(label_12, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL, 5);
+  grid_sizer_2->Add(label_12, 0,
+                    wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL, 5);
   grid_sizer_2->Add(sizer_5, 1, wxEXPAND, 0);
   grid_sizer_1->Add(grid_sizer_2, 1, wxEXPAND, 0);
   grid_sizer_1->Add(static_line_1, 0, wxEXPAND | wxLEFT | wxRIGHT, 2);
@@ -187,23 +181,19 @@ void Plot2DWiz::do_layout()
   Layout();
 }
 
-void Plot2DWiz::SetValue(wxString s)
-{
+void Plot2DWiz::SetValue(wxString s) {
   if (s.StartsWith(wxT("plot2d")))
     Parse(s);
-  else if (s.StartsWith(wxT("wxplot2d")))
-  {
+  else if (s.StartsWith(wxT("wxplot2d"))) {
     Parse(s.SubString(2, s.Length()));
     combo_box_1->SetValue(_("inline"));
-  }
-  else
+  } else
     text_ctrl_1->SetValue(s);
 
   text_ctrl_1->SetSelection(-1, -1);
 }
 
-void Plot2DWiz::Parse(wxString s)
-{
+void Plot2DWiz::Parse(wxString s) {
   int depth = 0;
   unsigned int i = 0;
   wxString curr;
@@ -213,21 +203,16 @@ void Plot2DWiz::Parse(wxString s)
 
   s = s.SubString(7, s.Length());
   // Function to plot
-  do
-  {
-    if (s.GetChar(i) == '[')
-    {
+  do {
+    if (s.GetChar(i) == '[') {
       depth++;
       if (depth > 1)
         curr += s.GetChar(i);
-    }
-    else if (s.GetChar(i) == ']')
-    {
+    } else if (s.GetChar(i) == ']') {
       depth--;
       if (depth > 0)
         curr += s.GetChar(i);
-    }
-    else
+    } else
       curr += s.GetChar(i);
     i++;
   } while (depth > 0);
@@ -237,110 +222,88 @@ void Plot2DWiz::Parse(wxString s)
     i++;
   i++;
   curr = wxEmptyString;
-  while (i < s.Length() && s.GetChar(i) != ',')
-  {
+  while (i < s.Length() && s.GetChar(i) != ',') {
     curr += s.GetChar(i);
     i++;
   }
   text_ctrl_2->SetValue(curr);
   i++;
   curr = wxEmptyString;
-  while (i < s.Length() && s.GetChar(i) != ',')
-  {
+  while (i < s.Length() && s.GetChar(i) != ',') {
     curr += s.GetChar(i);
     i++;
   }
   text_ctrl_3->SetValue(curr);
   i++;
   curr = wxEmptyString;
-  while (i < s.Length() && s.GetChar(i) != ']')
-  {
+  while (i < s.Length() && s.GetChar(i) != ']') {
     curr += s.GetChar(i);
     i++;
   }
   text_ctrl_4->SetValue(curr);
   i++;
   // Optional parameters
-  while (i < s.Length())
-  {
-    if (s.GetChar(i) == '[')
-    {
+  while (i < s.Length()) {
+    if (s.GetChar(i) == '[') {
       i++;
       curr = wxEmptyString;
-      while (i < s.Length() && s.GetChar(i) != ',' && s.GetChar(i) != ']')
-      {
+      while (i < s.Length() && s.GetChar(i) != ',' && s.GetChar(i) != ']') {
         curr += s.GetChar(i);
         i++;
       }
       curr.Trim();
       curr.Trim(false);
-      if (curr == wxT("y"))
-      {
+      if (curr == wxT("y")) {
         curr = wxEmptyString;
         i++;
-        while (i < s.Length() && s.GetChar(i) != ',')
-        {
+        while (i < s.Length() && s.GetChar(i) != ',') {
           curr += s.GetChar(i);
           i++;
         }
         text_ctrl_6->SetValue(curr);
         i++;
         curr = wxEmptyString;
-        while (i < s.Length() && s.GetChar(i) != ']')
-        {
+        while (i < s.Length() && s.GetChar(i) != ']') {
           curr += s.GetChar(i);
           i++;
         }
         text_ctrl_7->SetValue(curr);
         i++;
-      }
-      else if (curr == wxT("gnuplot_postamble"))
-      {
+      } else if (curr == wxT("gnuplot_postamble")) {
         while (i < s.Length() && s.GetChar(i) != '"')
           i++;
         i++;
         curr = wxEmptyString;
-        while (i < s.Length() && s.GetChar(i) != '"')
-        {
+        while (i < s.Length() && s.GetChar(i) != '"') {
           curr += s.GetChar(i);
           i++;
         }
         combo_box_2->SetValue(curr);
-      }
-      else if (curr == wxT("gnuplot_out_file"))
-      {
+      } else if (curr == wxT("gnuplot_out_file")) {
         while (i < s.Length() && s.GetChar(i) != '"')
           i++;
         i++;
         curr = wxEmptyString;
-        while (i < s.Length() && s.GetChar(i) != '"')
-        {
+        while (i < s.Length() && s.GetChar(i) != '"') {
           curr += s.GetChar(i);
           i++;
         }
         text_ctrl_9->SetValue(curr);
-      }
-      else if (curr == wxT("nticks"))
-      {
+      } else if (curr == wxT("nticks")) {
         curr = wxEmptyString;
         while (i < s.Length() && s.GetChar(i) != ',')
           i++;
         i++;
-        while (i < s.Length() && s.GetChar(i) != ']')
-        {
+        while (i < s.Length() && s.GetChar(i) != ']') {
           curr += s.GetChar(i);
           i++;
         }
         text_ctrl_8->SetValue(curr);
-      }
-      else if (curr == wxT("logx"))
-      {
+      } else if (curr == wxT("logx")) {
         check_box_1->SetValue(true);
         while (i < s.Length() && s.GetChar(i) != ']')
           i++;
-      }
-      else if (curr == wxT("logy"))
-      {
+      } else if (curr == wxT("logy")) {
         check_box_2->SetValue(true);
         while (i < s.Length() && s.GetChar(i) != ']')
           i++;
@@ -350,17 +313,16 @@ void Plot2DWiz::Parse(wxString s)
   }
 }
 
-wxString Plot2DWiz::GetValue()
-{
-  wxString f = combo_box_1->GetValue();     // format
-  wxString p = combo_box_2->GetValue();     // preamble
-  wxString s;                               // result
+wxString Plot2DWiz::GetValue() {
+  wxString f = combo_box_1->GetValue(); // format
+  wxString p = combo_box_2->GetValue(); // preamble
+  wxString s;                           // result
   wxString x1 = text_ctrl_3->GetValue();
   wxString x2 = text_ctrl_4->GetValue();
   wxString y1 = text_ctrl_6->GetValue();
   wxString y2 = text_ctrl_7->GetValue();
-  int t = text_ctrl_8->GetValue();          // Number of ticks
-  wxString file = text_ctrl_9->GetValue();  // plot to file
+  int t = text_ctrl_8->GetValue();         // Number of ticks
+  wxString file = text_ctrl_9->GetValue(); // plot to file
 
   // Expression
   s = wxT("plot2d([") + text_ctrl_1->GetValue();
@@ -378,8 +340,7 @@ wxString Plot2DWiz::GetValue()
   s += wxT("]");
 
   // y-range
-  if (y1 != wxT("0") || y2 != wxT("0"))
-  {
+  if (y1 != wxT("0") || y2 != wxT("0")) {
     s += wxT(", [");
     s += text_ctrl_5->GetValue();
     s += wxT(",") + y1 + wxT(",") + y2 + wxT("]");
@@ -389,12 +350,10 @@ wxString Plot2DWiz::GetValue()
   if (f != _("default") && f != _("inline"))
     s += wxT(",\n [plot_format, ") + f + wxT("]");
 
-
   // gnuplot_postamble
   if (p.Length() > 0)
     s += wxT(",\n [gnuplot_postamble, \"") + p + wxT("\"]");
-  if (t != 10)
-  {
+  if (t != 10) {
     s += wxT(",\n [nticks,");
     s += wxString::Format(wxT("%d"), t);
     s += wxT("]");
@@ -407,10 +366,9 @@ wxString Plot2DWiz::GetValue()
     s += wxT(", [logy]");
 
   // plot to file
-  if (file.Length())
-  {
+  if (file.Length()) {
     s += wxT(", [gnuplot_term, ps]");
-#if defined (__WXMSW__)
+#if defined(__WXMSW__)
     file.Replace(wxT("\\"), wxT("/"));
 #endif
 
@@ -418,7 +376,7 @@ wxString Plot2DWiz::GetValue()
       file = file + wxT(".eps");
     s += wxT(",\n [gnuplot_out_file, \"") + file + wxT("\"]");
   }
-    // inline?
+  // inline?
   else if (f == _("inline"))
     s = wxT("wx") + s;
 
@@ -431,8 +389,7 @@ wxString Plot2DWiz::GetValue()
   return s;
 }
 
-void Plot2DWiz::OnButton(wxCommandEvent &WXUNUSED(event))
-{
+void Plot2DWiz::OnButton(wxCommandEvent &WXUNUSED(event)) {
   wxMenu *popupMenu = new wxMenu();
 
   popupMenu->Append(parametric_plot, _("Parametric plot"));
@@ -444,77 +401,70 @@ void Plot2DWiz::OnButton(wxCommandEvent &WXUNUSED(event))
   PopupMenu(popupMenu, pos);
 }
 
-void Plot2DWiz::OnPopupMenu(wxCommandEvent &event)
-{
-  switch (event.GetId())
-  {
-    case parametric_plot:
-    {
-      Plot2DPar *wiz = new Plot2DPar(this, -1, m_configuration, _("Plot 2D"));
-      wiz->Centre(wxBOTH);
-      if (wiz->ShowModal() == wxID_OK)
-      {
+void Plot2DWiz::OnPopupMenu(wxCommandEvent &event) {
+  switch (event.GetId()) {
+  case parametric_plot: {
+    wxWindowPtr<Plot2DPar> wiz(new Plot2DPar(this, -1, m_configuration, _("Plot 2D")));
+    wiz->Centre(wxBOTH);
+    wiz->ShowWindowModalThenDo([this,wiz](int retcode) {
+      if (retcode == wxID_OK) {
         if (text_ctrl_1->GetValue() == wxT("%"))
           text_ctrl_1->SetValue(wxEmptyString);
         if (((text_ctrl_1->GetValue()).Strip()).Length())
           text_ctrl_1->AppendText(wxT(", "));
         text_ctrl_1->AppendText(wiz->GetValue());
       }
-    } //-V773
-      break;
-    case discrete_plot:
-    {
-      Plot2DDiscrete *wiz = new Plot2DDiscrete(this, -1, m_configuration, _("Plot 2D"));
-      wiz->Centre(wxBOTH);
-      if (wiz->ShowModal() == wxID_OK)
-      {
+    });
+  } //-V773
+    break;
+  case discrete_plot: {
+    wxWindowPtr<Plot2DDiscrete> wiz(new Plot2DDiscrete(this, -1, m_configuration, _("Plot 2D")));
+    wiz->Centre(wxBOTH);
+    wiz->ShowWindowModalThenDo([this,wiz](int retcode) {
+      if (retcode == wxID_OK) {
         if (text_ctrl_1->GetValue() == wxT("%"))
           text_ctrl_1->SetValue(wxEmptyString);
         if (((text_ctrl_1->GetValue()).Strip()).Length())
           text_ctrl_1->AppendText(wxT(", "));
         text_ctrl_1->AppendText(wiz->GetValue());
       }
-    } //-V773
-      break;
+    });
+  } //-V773
+    break;
   }
 }
 
-void Plot2DWiz::OnCombobox(wxCommandEvent &WXUNUSED(event))
-{
+void Plot2DWiz::OnCombobox(wxCommandEvent &WXUNUSED(event)) {
   wxString selection = combo_box_2->GetStringSelection();
-  if (selection.StartsWith(wxT("set polar")))
-  {
+  if (selection.StartsWith(wxT("set polar"))) {
     text_ctrl_2->SetValue(wxT("ph"));
     text_ctrl_3->SetValue(wxT("0"));
     text_ctrl_4->SetValue(wxT("2*%pi"));
     type = polar;
-  }
-  else
+  } else
     type = cartesian;
 
-  if (selection.StartsWith(wxT("set logscale x")))
-  {
+  if (selection.StartsWith(wxT("set logscale x"))) {
     text_ctrl_3->SetValue(wxT("0"));
     text_ctrl_4->SetValue(wxT("100"));
   }
 }
 
-void Plot2DWiz::OnFileBrowse(wxCommandEvent &WXUNUSED(event))
-{
-  wxString file = wxFileSelector(_("Save plot to file"), wxEmptyString,
-                                 wxT("plot2d.eps"), wxT("eps"),
-                                 _("Postscript file (*.eps)|*.eps|All|*"),
-                                 wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
+void Plot2DWiz::OnFileBrowse(wxCommandEvent &WXUNUSED(event)) {
+  wxString file =
+    wxFileSelector(_("Save plot to file"), wxEmptyString, wxT("plot2d.eps"),
+		   wxT("eps"), _("Postscript file (*.eps)|*.eps|All|*"),
+		   wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
   if (file.Length() > 0)
     text_ctrl_9->SetValue(file);
 }
 
 wxBEGIN_EVENT_TABLE(Plot2DWiz, wxDialog)
-                EVT_COMBOBOX(combobox, Plot2DWiz::OnCombobox)
-                EVT_BUTTON(special, Plot2DWiz::OnButton)
-                EVT_BUTTON(file_browse_2d, Plot2DWiz::OnFileBrowse)
-                EVT_MENU(parametric_plot, Plot2DWiz::OnPopupMenu)
-                EVT_MENU(discrete_plot, Plot2DWiz::OnPopupMenu)
+EVT_COMBOBOX(combobox, Plot2DWiz::OnCombobox)
+EVT_BUTTON(special, Plot2DWiz::OnButton)
+EVT_BUTTON(file_browse_2d, Plot2DWiz::OnFileBrowse)
+EVT_MENU(parametric_plot, Plot2DWiz::OnPopupMenu)
+EVT_MENU(discrete_plot, Plot2DWiz::OnPopupMenu)
 wxEND_EVENT_TABLE()
 
 ///////////////////////
@@ -523,10 +473,10 @@ wxEND_EVENT_TABLE()
 //
 ///////////////////////
 
-Plot2DPar::Plot2DPar(wxWindow *parent, int id, Configuration *cfg, const wxString &title,
-                     const wxPoint &pos, const wxSize &size, long style) :
-        wxDialog(parent, id, title, pos, size, style)
-{
+Plot2DPar::Plot2DPar(wxWindow *parent, int id, Configuration *cfg,
+		     const wxString &title, const wxPoint &pos,
+		     const wxSize &size, long style)
+: wxDialog(parent, id, title, pos, size, style) {
   label_2 = new wxStaticText(this, -1, wxT("x = "));
   text_ctrl_1 = new BTextCtrl(this, -1, cfg, wxEmptyString, wxDefaultPosition,
                               wxSize(230, -1));
@@ -534,8 +484,8 @@ Plot2DPar::Plot2DPar(wxWindow *parent, int id, Configuration *cfg, const wxStrin
   text_ctrl_2 = new BTextCtrl(this, -1, cfg, wxEmptyString, wxDefaultPosition,
                               wxSize(230, -1));
   label_4 = new wxStaticText(this, -1, _("Variable:"));
-  text_ctrl_3 = new BTextCtrl(this, -1, cfg, wxT("t"), wxDefaultPosition,
-                              wxSize(40, -1));
+  text_ctrl_3 =
+    new BTextCtrl(this, -1, cfg, wxT("t"), wxDefaultPosition, wxSize(40, -1));
   label_5 = new wxStaticText(this, -1, _("From:"));
   text_ctrl_4 = new BTextCtrl(this, -1, cfg, wxEmptyString, wxDefaultPosition,
                               wxSize(70, -1));
@@ -559,8 +509,7 @@ Plot2DPar::Plot2DPar(wxWindow *parent, int id, Configuration *cfg, const wxStrin
   do_layout();
 }
 
-void Plot2DPar::set_properties()
-{
+void Plot2DPar::set_properties() {
   SetTitle(_("Parametric plot"));
   text_ctrl_4->SetValue(wxT("-6"));
   text_ctrl_5->SetValue(wxT("6"));
@@ -573,24 +522,27 @@ void Plot2DPar::set_properties()
   text_ctrl_1->SetFocus();
 }
 
-void Plot2DPar::do_layout()
-{
+void Plot2DPar::do_layout() {
   wxFlexGridSizer *grid_sizer_1 = new wxFlexGridSizer(4, 1, 0, 0);
   wxBoxSizer *sizer_1 = new wxBoxSizer(wxHORIZONTAL);
   wxFlexGridSizer *grid_sizer_2 = new wxFlexGridSizer(4, 2, 0, 0);
   wxBoxSizer *sizer_2 = new wxBoxSizer(wxHORIZONTAL);
-  grid_sizer_2->Add(label_2, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL, 5);
+  grid_sizer_2->Add(label_2, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL,
+                    5);
   grid_sizer_2->Add(text_ctrl_1, 0, wxALL | wxEXPAND, 5);
-  grid_sizer_2->Add(label_3, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL, 5);
+  grid_sizer_2->Add(label_3, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL,
+                    5);
   grid_sizer_2->Add(text_ctrl_2, 0, wxALL | wxEXPAND, 5);
-  grid_sizer_2->Add(label_4, 0, wxALL | wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL, 5);
+  grid_sizer_2->Add(label_4, 0, wxALL | wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL,
+                    5);
   sizer_1->Add(text_ctrl_3, 0, wxALL, 5);
   sizer_1->Add(label_5, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
   sizer_1->Add(text_ctrl_4, 0, wxALL, 5);
   sizer_1->Add(label_6, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
   sizer_1->Add(text_ctrl_5, 0, wxALL, 5);
   grid_sizer_2->Add(sizer_1, 1, 0, 0);
-  grid_sizer_2->Add(label_7, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL, 5);
+  grid_sizer_2->Add(label_7, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL,
+                    5);
   grid_sizer_2->Add(spin_ctrl_1, 0, wxALIGN_CENTER_VERTICAL | wxALL, 5);
   grid_sizer_2->AddGrowableCol(1);
   grid_sizer_1->Add(grid_sizer_2, 1, wxEXPAND, 0);
@@ -605,8 +557,7 @@ void Plot2DPar::do_layout()
   Layout();
 }
 
-wxString Plot2DPar::GetValue()
-{
+wxString Plot2DPar::GetValue() {
   wxString s;
   s = wxT("'parametric, ");
   s += text_ctrl_1->GetValue();
@@ -630,12 +581,10 @@ wxString Plot2DPar::GetValue()
 //
 ///////////////////////
 
-Plot2DDiscrete::Plot2DDiscrete(wxWindow *parent, int id,
-                               Configuration *cfg,
-                               const wxString &title,
-                               const wxPoint &pos, const wxSize &size, long style) :
-        wxDialog(parent, id, title, pos, size, style)
-{
+Plot2DDiscrete::Plot2DDiscrete(wxWindow *parent, int id, Configuration *cfg,
+                               const wxString &title, const wxPoint &pos,
+                               const wxSize &size, long style)
+  : wxDialog(parent, id, title, pos, size, style) {
   label_2 = new wxStaticText(this, -1, wxT("x = "));
   text_ctrl_1 = new BTextCtrl(this, -1, cfg, wxEmptyString, wxDefaultPosition,
                               wxSize(230, -1));
@@ -656,8 +605,7 @@ Plot2DDiscrete::Plot2DDiscrete(wxWindow *parent, int id,
   do_layout();
 }
 
-void Plot2DDiscrete::set_properties()
-{
+void Plot2DDiscrete::set_properties() {
   SetTitle(_("Discrete plot"));
 #if defined __WXMSW__
   button_1->SetDefault();
@@ -671,14 +619,15 @@ void Plot2DDiscrete::set_properties()
   text_ctrl_1->SetFocus();
 }
 
-void Plot2DDiscrete::do_layout()
-{
+void Plot2DDiscrete::do_layout() {
   wxFlexGridSizer *grid_sizer_1 = new wxFlexGridSizer(4, 1, 0, 0);
   wxFlexGridSizer *grid_sizer_2 = new wxFlexGridSizer(2, 2, 0, 0);
   wxBoxSizer *sizer_2 = new wxBoxSizer(wxHORIZONTAL);
-  grid_sizer_2->Add(label_2, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL, 5);
+  grid_sizer_2->Add(label_2, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL,
+                    5);
   grid_sizer_2->Add(text_ctrl_1, 0, wxALL | wxEXPAND, 5);
-  grid_sizer_2->Add(label_3, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL, 5);
+  grid_sizer_2->Add(label_3, 0, wxALIGN_RIGHT | wxALIGN_CENTER_VERTICAL | wxALL,
+                    5);
   grid_sizer_2->Add(text_ctrl_2, 0, wxALL | wxEXPAND, 5);
   grid_sizer_2->AddGrowableCol(1);
   grid_sizer_1->Add(grid_sizer_2, 1, wxEXPAND, 0);
@@ -693,8 +642,7 @@ void Plot2DDiscrete::do_layout()
   Layout();
 }
 
-wxString Plot2DDiscrete::GetValue()
-{
+wxString Plot2DDiscrete::GetValue() {
   wxString s;
   s = wxT("['discrete, [");
   s += text_ctrl_1->GetValue();
