@@ -1,18 +1,18 @@
 ﻿/*
  * MIT License
- * 
+ *
  * Copyright (c) 2017-2019 Mikhail Pilin
- * 
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
  * in the Software without restriction, including without limitation the rights
  * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  * copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- *  
+ *
  * The above copyright notice and this permission notice shall be included in all
  * copies or substantial portions of the Software.
- *  
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -24,7 +24,11 @@
 
 #pragma once
 
-#if defined(_WIN32)
+#if defined(_WIN32) || defined(__CYGWIN__)
+
+#if defined(__CYGWIN__)
+#warning Cygwin is not supported by the ww898 library, this is VERY experimental, not sure, if that works correctly.
+#endif
 
 #include <ww898/cp_utf16.hpp>
 
@@ -33,7 +37,7 @@ namespace utf {
 using utfw = utf16;
 }}
 
-#elif defined(__linux__) || defined(__APPLE__)
+#else
 
 #include <ww898/cp_utf32.hpp>
 
@@ -42,6 +46,4 @@ namespace utf {
 using utfw = utf32;
 }}
 
-#else
-#error Unsupported platform
 #endif
