@@ -1,4 +1,4 @@
-(format t "<suppressOutput>")
+(format t "<suppressOutput>~%")
 ;; wxMaxima xml format (based on David Drysdale MathML printing)
 ;; Andrej Vodopivec,  2004-2014
 ;; Gunter Königsmann, 2014-2020
@@ -35,6 +35,7 @@
 ;(format t "<wxxml-start/>")
 
 (progn
+  (format t "<wxxml-key>~A</wxxml-key>~%" (maxima-getenv "MAXIMA_AUTH_CODE"))
   ;; This is necessary to make file and directory names that contain special characters
   ;; work under windows.
   #+sbcl (setf sb-impl::*default-external-format* :UTF-8)
@@ -85,6 +86,13 @@
  
 
 
+  ;; Tell maxima how to send a list of manual topics to show to us
+  (defun display-frontend-topics (topiclist)
+    (format t "<html-manual-keywords>")
+    (mapcar #'(lambda (&rest x) (format t "<keyword>~a</keyword>" (first (second (first x))))) topiclist)
+    (format t "</html-manual-keywords>~%")
+    )
+  
   ;; Escape all chars that need escaping in XML
   (defun wxxml-fix-string (x)
     (if (stringp x)
@@ -255,14 +263,12 @@
     (dolist (s (cdr x))
       ($put s opt '$wxxml_subscripted))
     opt)
-
+  
   (defun subscriptp (x)
     (unless (symbolp x)
       (return-from subscriptp x))
-    (let* ((name (subseq (maybe-invert-string-case (symbol-name x)) 1))
-	   (pos (search "_" name :from-end t))
-	   #-gcl (*readtable* (copy-readtable nil)))
-      #-gcl (setf (readtable-case *readtable*) :invert)
+    (let* ((name ($sconcat x))
+	   (pos (search "_" name :from-end t)))
       (when pos
 	(let* (
 	       ;; sub is the part of x after the "_"
@@ -274,7 +280,7 @@
 	       ;; sub-int is the part of x after the "_" converted to integer
 	       (sub-int (ignore-errors
 			  (parse-integer sub))))
-	  (when (and (> (length sub-var) 0)
+	  (when (and (and (> (length sub-var) 0) (> (length sub) 0) )
 		     (or
 		      ($get x '$wxxml_subscripted)
 		      (and
@@ -286,18 +292,11 @@
 			   )
 		       (ignore-errors (not
 			 (member '$WXXML_SUBSCRIPTED (cadr (properties x))))))))
-	    (let* ((name-string (mstring x))
-		   (pos-string (search "_" name-string :from-end t))
-		   ;; sub-string is the part of x after the "_"
-		   (sub-string (coerce (subseq name-string (+ pos-string 1)) 'string))
-		   ;; sub-var-string is the part of x in front of the "_"
-		   ;; sub-var lacks the 1st letter in :trace commands
-		   (sub-var-string (coerce (subseq name-string 0 pos-string) 'string))
-		   )
+	    (let* ((name-string (mstring x)))
 	      (format nil  "<munder altCopy=\"~{~a~}\"><mrow>~a</mrow><mrow>~a</mrow></munder>"
 		      (wxxml-fix-string name-string)
-		      (format nil "<mi>~a</mi>" (wxxml-fix-string sub-var-string))
-		      (format nil "<mi>~a</mi>" (wxxml-fix-string sub-string)))))))))
+		      (format nil "<mi>~a</mi>" (wxxml-fix-string sub-var))
+		      (format nil "<mi>~a</mi>" (wxxml-fix-string sub)))))))))
   
   (defun wxxmlescapenum (atom)
     (wxxml-fix-string
@@ -568,9 +567,25 @@
   (wx-defprop mlabbox 10. wxxml-lbp)
 
   (defun wxxml-mbox (x l r)
-    (setq l (wxxml (cadr x) (append l '("<mrow><hl>")) nil 'mparen 'mparen)
-	  r (append '("</hl></mrow>") r))
-    (append l r))
+    (let ((boxname (caddr x)))
+      (setq l (wxxml (cadr x) (append l
+				      (if boxname
+					  (list (format nil "<mrow><hl boxname=\"~a\">"
+							(if (symbolp boxname)
+							    (if (boundp boxname)
+								(wxxml-fix-string(eval var))
+							      (wxxml-fix-string
+							       (stripdollar
+								(maybe-invert-string-case
+								 (symbol-name boxname)))))
+							  (wxxml-fix-string
+							   (format nil "~a" boxname)))))
+					'("<mrow><hl>"))
+				      ) nil 'mparen 'mparen)
+	    r (append '("</hl></mrow>") r))
+      (append l r))
+    )
+  ;; (caddr x) should return the oütional argument
 
   (wx-defprop mqapply wxxml-mqapply wxxml)
 
@@ -2003,8 +2018,8 @@
     (format t "<wxxml-symbols>")
     ;; Function names and rules
     (format t "~{~a~^$~}"
-	    (append (mapcar #'$print_function (cdr ($append $functions $macros)))
-		    (mapcar #'print_value (cdr ($append $values $rules)))))
+	    (append (mapcar #'$print_function (cdr ($append (eval '$functions) (eval '$macros))))
+		    (mapcar #'print_value (cdr ($append (eval '$values) (eval '$rules))))))
     ;; Idea from Robert Dodier:
     ;; Variables defined with mdef don't appear in $values nor do they in $myoptions
     ;; but they appear in *variable-initial-values*
@@ -2014,6 +2029,8 @@
 		   (format t "~a" (print_value key))))
 	     *variable-initial-values*)
 
+;;    (mapcar (lambda(key) (if (eq (char (format nil "~a" key) 0) #\$ ) (symbol-to-xml (make-symbol key)))) (wx-list-all-maxima-vars))
+
     ;; ezunits publishes all known units in a function.
     (if (boundp '$known_units)
     	(no-warning
@@ -2053,15 +2070,16 @@
   (defun wx-print-variables ()
     (finish-output)
     (format t "<variables>")
-    (wx-print-variable '$maxima_userdir)
-    (wx-print-variable '$maxima_tempdir)
-    (wx-print-variable '*maxima-infodir*)
-    (wx-print-variable '*maxima-htmldir*)
 					;  (wx-print-variable '*maxima-topdir*)
     (wx-print-variable '$gnuplot_command)
+    (wx-print-variable '$gentranlang)
     (wx-print-variable '*maxima-demodir*)
     (wx-print-variable '*autoconf-version*) ; Must be queried before maxima-sharedir is
+    (wx-print-variable '$maxima_userdir)
+    (wx-print-variable '$maxima_tempdir)
     (wx-print-variable '*maxima-sharedir*)
+    (wx-print-variable '*maxima-infodir*)
+    (wx-print-variable '*maxima-htmldir*)
     (wx-print-variable '*autoconf-host*)
     (format t "<variable><name>*lisp-name*</name><value>~a</value></variable>"
 	    #+sbcl (ensure-readably-printable-string (lisp-implementation-type))
@@ -2072,12 +2090,25 @@
     (format t "</variables>~%")
     (finish-output)
     )
-  
+
+  ;tttt
+;  (defun wx-list-all-maxima-vars () (let ((lst ())) (do-symbols (s (find-package 'maxima)) (push s lst)) lst))
+; 	       (if (eq (char (format nil "~a" key) 0) #\$ )
+
+  ;  (let ((lst ())) (do-symbols (s (find-package 'maxima)) (push s lst)) lst)
+; 	       (if (eq (char (format nil "~a" key) 0) #\$ )
+
+;    (mapcar (lambda(key) (if (eq (char (format nil "~a" key) 0) #\$ ) (symbol-to-xml (make-symbol key)))) (wx-list-all-maxima-vars))
+
+
   (defun wx-print-gui-variables ()
     (finish-output)
     (format t "<variables>")
+    (wx-print-variable '$output_format_for_help)
     (wx-print-variable '$wxsubscripts)
+    (wx-print-variable '$opsubst)
     (wx-print-variable '$logexpand)
+    (wx-print-variable '$sinnpiflag)
     (wx-print-variable '$lmxchar)
     (wx-print-variable '$numer)
     (wx-print-variable '$stringdisp)
@@ -2191,10 +2222,7 @@
 
   (putprop '$table_form t 'evfun)
 
-  ;; Load the initial functions (from mac-init.mac)
-  (let ((*print-circle* nil))
-    (format t "<wxxml-symbols>~{~a~^$~}</wxxml-symbols>~%"
-	    (mapcar #'$print_function (cdr ($append $functions $macros)))))
+  (wxPrint_autocompletesymbols)
 
   (no-warning
    (defun mredef-check (fnname)
