@@ -25,12 +25,13 @@
 
   The worksheet is defined in the class MathCtrl instead and
   everything surrounding it in wxMaximaFrame.
- */
+*/
 
 
 #ifndef WXMAXIMA_H
 #define WXMAXIMA_H
 
+#include <vector>
 #include "wxMaximaFrame.h"
 #include "MathParser.h"
 #include "MaximaIPC.h"
@@ -54,18 +55,18 @@
 /*! The part of the .wxmx format version number that appears after the dot.
 
   - Updated to version 1.1 after user selectable animation-speeds were introduced:
-    Old wxMaxima versions play them back in the default speed instead but still
-    open the file.
+  Old wxMaxima versions play them back in the default speed instead but still
+  open the file.
   - Bumped to version 1.2 after saving highlighting was introduced: Older versions
-    of wxMaxima will ignore the highlighting on opening .wxmx files.
+  of wxMaxima will ignore the highlighting on opening .wxmx files.
   - Bumped to version 1.3 after sub-subsections were introduced:
-    Old wxMaxima versions interpret them as subsections but still open the file.
+  Old wxMaxima versions interpret them as subsections but still open the file.
   - Bumped to version 1.4 when we started allowing to embed .jpg images in a .wxmx
-    file. wxMaxima versions between 13.04 and 15.08 replace these images by a
-    "image cannot be loaded" marker but will correctly display the rest of the file.
+  file. wxMaxima versions between 13.04 and 15.08 replace these images by a
+  "image cannot be loaded" marker but will correctly display the rest of the file.
   - Bumped to version 1.5 when GroupCells were added an attribute that allows them to
-    be used as an answer to questions.
- */
+  be used as an answer to questions.
+*/
 #define DOCUMENT_VERSION_MINOR 5
 
 //! How many milliseconds should we wait between polling for stdout+cpu power?
@@ -80,7 +81,6 @@ class MaximaEvent;
 class wxMaxima : public wxMaximaFrame
 {
 public:
-
   wxMaxima(wxWindow *parent, int id, wxLocale *locale, const wxString title,
            const wxString &filename = wxEmptyString,
            const wxPoint pos = wxDefaultPosition, const wxSize size = wxDefaultSize);
@@ -88,7 +88,7 @@ public:
   virtual ~wxMaxima();
 
   //! Pipe maxima's output to stdout
-  static void PipeToStdout(){m_pipeToStdout = true;}
+  static void PipeToStdout(){m_pipeToStderr = true;}
   static void ExitOnError(){m_exitOnError = true;}
   static void EnableIPC(){ MaximaIPC::EnableIPC(); }
   static void ExtraMaximaArgs(const wxString &args){m_extraMaximaArgs = args;}
@@ -97,11 +97,11 @@ public:
   enum TimerIDs
   {
     //! The keyboard was inactive long enough that we can attempt an auto-save.
-            KEYBOARD_INACTIVITY_TIMER_ID,
+    KEYBOARD_INACTIVITY_TIMER_ID,
     //! The time between two auto-saves has elapsed.
-            AUTO_SAVE_TIMER_ID,
+    AUTO_SAVE_TIMER_ID,
     //! We look if we got new data from maxima's stdout.
-            MAXIMA_STDOUT_POLL_ID
+    MAXIMA_STDOUT_POLL_ID
   };
 
 #ifdef wxHAS_POWER_EVENTS 
@@ -145,11 +145,11 @@ public:
 
   //! Does this document need saving?
   bool DocumentSaved()
-  { return m_fileSaved; }
+    { return m_fileSaved; }
 
   //! Load an image from a file into the worksheet.
   void LoadImage(wxString file)
-  { m_worksheet->OpenHCaret(file, GC_TYPE_IMAGE); }
+    { m_worksheet->OpenHCaret(file, GC_TYPE_IMAGE); }
 
   //! Query the value of a new maxima variable
   bool QueryVariableValue();
@@ -171,13 +171,15 @@ public:
   };
 
 private:
+  bool m_maximaAuthenticated = false;
+  bool m_discardAllData = false;
+  wxString m_maximaAuthString;
   MaximaIPC m_ipc{this};
   //! wxm data the worksheet is populated from
   wxString m_initialWorkSheetContents;
-  static bool m_pipeToStdout;
+  static bool m_pipeToStderr;
   static bool m_exitOnError;
   static wxString m_extraMaximaArgs;
-  wxLocale *m_locale;
   //! The variable names to query for the variables pane and for internal reasons
   wxArrayString m_varNamesToQuery;
 
@@ -214,7 +216,7 @@ private:
     Each prompt is deemed as but one hint for a working maxima while each crash counts twice
     which hinders us from endlessly restarting in case maxima crashes, outputs something
     seemingly sensible and crashes again.
-   */
+  */
   int m_unsuccessfulConnectionAttempts;
   //! The current working directory maxima's file I/O is relative to.
   wxString m_CWD;
@@ -229,7 +231,7 @@ private:
 
     If text doesn't contain any error this function returns wxEmptyString
   */
-  wxString GetUnmatchedParenthesisState(wxString text,int &index);
+  wxString GetUnmatchedParenthesisState(wxString text, int &index);
   //! The buffer all text from maxima is stored in before converting it to a wxString.
   wxMemoryBuffer m_uncompletedChars;
 
@@ -243,7 +245,7 @@ protected:
                   wxString label3 = {}, wxString defaultval3 = {}, wxString tooltip3 = {},
                   wxString label4 = {}, wxString defaultval4 = {}, wxString tooltip4 = {},
                   wxString label5 = {}, wxString defaultval5 = {}, wxString tooltip5 = {},
-                          wxString label6 = {}, wxString defaultval6 = {}, wxString tooltip6 = {},
+                  wxString label6 = {}, wxString defaultval6 = {}, wxString tooltip6 = {},
                   wxString label7 = {}, wxString defaultval7 = {}, wxString tooltip7 = {},
                   wxString label8 = {}, wxString defaultval8 = {}, wxString tooltip8 = {},
                   wxString label9 = {}, wxString defaultval9 = {}, wxString tooltip9 = {}
@@ -261,8 +263,11 @@ protected:
   wxProcess *m_gnuplotTerminalQueryProcess = NULL;
   //! Is this window active?
   bool m_isActive;
-  //! Called when this window is activated or deactivated.
-  void OnActivate(wxActivateEvent &event);
+  //! Called when this window is focussed or defocussed.
+  void OnFocus(wxFocusEvent &event);
+
+  //! Forwards the keyboard focus to a text control that might need it
+  void PassKeyboardFocus();
   //! Called when this window is minimized.
   void OnMinimize(wxIconizeEvent &event);
   //! Is called on start and whenever the configuration changes
@@ -276,10 +281,11 @@ protected:
   void OnWizardAbort(wxCommandEvent &event);
   void OnWizardOK(wxCommandEvent &event);
   void OnWizardInsert(wxCommandEvent &event);
+  void OnWizardHelpButton(wxCommandEvent &event);
 
   //! Show the help for Maxima
   void ShowMaximaHelp(wxString = {});
-
+  
   //! Show the help for Maxima (without handling of anchors).
   void ShowMaximaHelpWithoutAnchor();
 
@@ -322,9 +328,9 @@ protected:
     We don't interpret this data directly in the idle event since if we
     block somewhere in the idle event we block gnome.
     \return
-      - true, if there was new data
-      - false, if there wasn't any new data.
-   */
+    - true, if there was new data
+    - false, if there wasn't any new data.
+  */
   bool InterpretDataFromMaxima(const wxString &newData);
   bool m_dataFromMaximaIs;
 
@@ -350,7 +356,7 @@ protected:
   void UpdateSlider();       //!< Updates the slider to show the right frame
   /*! Toggle the visibility of a pane
     \param event The event that triggered calling this function.
-   */
+  */
   void ShowPane(wxCommandEvent &event);            //<! Makes a sidebar visible
   void OnProcessEvent(wxProcessEvent &event);      //
   void OnGnuplotClose(wxProcessEvent &event);      //
@@ -386,16 +392,16 @@ protected:
 
     \param cmd The parameter to  add to the draw command
     \param dimensionsOfNewDrawCommand The number of dimensions the new draw command needs to
-                                      have if we need to create one..
-   */
+    have if we need to create one..
+  */
   void AddDrawParameter(wxString cmd, int dimensionsOfNewDrawCommand = 2);
 
   /* Append something to the console. Might be Text or XML maths.
 
-    \return A pointer to the last line of Unicode text that was appended or
-    NULL, if there is no such line (for example if the appended object is
-    maths instead).
-   */
+     \return A pointer to the last line of Unicode text that was appended or
+     NULL, if there is no such line (for example if the appended object is
+     maths instead).
+  */
   TextCell *ConsoleAppend(wxString s, CellType type, const wxString &userLabel = {});        //!< append maxima output to console
 
   enum AppendOpt { NewLine = 1, BigSkip = 2, PromptToolTip = 4, DefaultOpt = NewLine|BigSkip };
@@ -405,7 +411,7 @@ protected:
   /*!Append one or more lines of ordinary unicode text to the console
 
     \return A pointer to the last line that was appended or NULL, if there is no such line
-   */
+  */
   TextCell *DoRawConsoleAppend(wxString s, CellType  type, AppendOpt opts = {});
 
   /*! Spawn the "configure" menu.
@@ -425,6 +431,10 @@ protected:
 
   //! Issued on double click on the network status
   void NetworkDClick(wxCommandEvent &ev);
+  //! Issued on double click on the Maxima status icon
+  void MaximaDClick(wxCommandEvent &ev);
+  //! Issued on double click on the status message in the status bar
+  void StatusMsgDClick(wxCommandEvent &ev);
 
   //! Issued on double click on a history item
   void HistoryDClick(wxCommandEvent &event);
@@ -452,11 +462,11 @@ protected:
   /*! starts maxima (uses getCommand) or restarts it if needed
 
     Normally a restart is only needed if
-      - maxima isn't currently in the process of starting up or
-      - maxima is running and has never evaluated any program
-        so a restart won't change anything
+    - maxima isn't currently in the process of starting up or
+    - maxima is running and has never evaluated any program
+    so a restart won't change anything
     \param force true means to restart maxima unconditionally.
-   */
+  */
   bool StartMaxima(bool force = false);
 
   void OnClose(wxCloseEvent &event);               //!< close wxMaxima window
@@ -469,13 +479,13 @@ protected:
   /*! Determines the process id of maxima from its initial output
 
     This function does several things:
-     - it sets m_pid to the process id of maxima
-     - it discards all data until this point
-     - and it prepares the worksheet for editing.
+    - it sets m_pid to the process id of maxima
+    - it discards all data until this point
+    - and it prepares the worksheet for editing.
 
-     \param data The string ReadFirstPrompt() does read its data from.
-                  After leaving this function data is empty again.
-   */
+    \param data The string ReadFirstPrompt() does read its data from.
+    After leaving this function data is empty again.
+  */
   void ReadFirstPrompt(wxString &data);
 
   /*! Reads an XML tag or a piece of status text from maxima's output
@@ -483,7 +493,7 @@ protected:
     \todo Is there any way to handle the (perhaps, thanks to the flush commands in maxima)
     theoretical case that maxima might stop sending data in the middle of an XML tag
     and then resume sending data with the next XML packet?
-   */
+  */
   bool ParseNextChunkFromMaxima(wxString &data);
 
   //! Find the end of a tag in wxMaxima's output.
@@ -491,40 +501,42 @@ protected:
 
   /*! Reads text that isn't enclosed between xml tags.
 
-     Some commands provide status messages before the math output or the command has finished.
-     This function makes wxMaxima output them directly as they arrive.
+    Some commands provide status messages before the math output or the command has finished.
+    This function makes wxMaxima output them directly as they arrive.
 
-     After processing the lines not enclosed in xml tags they are removed from data.
-   */
+    After processing the lines not enclosed in xml tags they are removed from data.
+  */
   void ReadMiscText(const wxString &data);
 
   /*! Reads the input prompt from Maxima.
 
-     After processing the input prompt it is removed from data.
-   */
+    After processing the input prompt it is removed from data.
+  */
   void ReadPrompt(wxString &data);
 
   /*! Reads the output of wxstatusbar() commands
 
     wxstatusbar allows the user to give and update visual feedback from long-running
     commands and makes sure this feedback is deleted once the command is finished.
-   */
+  */
   void ReadStatusBar(wxString &data);
+  //! Read a manual topic name so we can jump to the right documentation page
+  void ReadManualTopicNames(wxString &data);
 
   /*! Reads the math cell's contents from Maxima.
 
-     Math cells are enclosed between the tags \<mth\> and \</mth\>.
-     This function removes the from data after appending them
-     to the console.
+    Math cells are enclosed between the tags \<mth\> and \</mth\>.
+    This function removes the from data after appending them
+    to the console.
 
-     After processing the status bar marker is removed from data.
-   */
+    After processing the status bar marker is removed from data.
+  */
   void ReadMath(wxString &data);
 
   /*! Reads autocompletion templates we get on definition of a function or variable
 
     After processing the templates they are removed from data.
-   */
+  */
 
   void ReadMaximaIPC(wxString &data){m_ipc.ReadInputData(data);}
   void ReadLoadSymbols(wxString &data);
@@ -539,6 +551,11 @@ protected:
   /*! Reads the "add variable to watch list" tag maxima can send us
    */
   void ReadAddVariables(wxString &data);
+  void VariableActionGentranlang(const wxString &value);
+  void VariableActionHtmlHelp(const wxString &value);
+  void VariableActionOpSubst(const wxString &value);
+  void VariableActionSinnpiflag(const wxString &value);
+  void VariableActionSinnpiflagUndefined();
   void VariableActionLogexpand(const wxString &value);
   void VariableActionUserDir(const wxString &value);
   void VariableActionTempDir(const wxString &value);
@@ -573,20 +590,20 @@ protected:
   /*! How much CPU time has been used by the system until now? Used by GetMaximaCPUPercentage.
 
     \return The CPU time elapsed in the same unit as GetMaximaCpuTime(); -1 means: Unable to determine this value.
-   */
+  */
   long long GetTotalCpuTime();
 
   /*! How much CPU time has maxima used till now? Used by GetMaximaCPUPercentage.
 
     \return The CPU time maxima has used in the same unit as GetTotalCpuTime(); -1 means: Unable to determine this value.
 
-   */
+  */
   long long GetMaximaCpuTime();
 
   /*! How much CPU horsepower is maxima using currently?
 
     \return The percentage of the CPU horsepower maxima is using or -1, if this value is unknown.
-   */
+  */
   double GetMaximaCPUPercentage();
 
   //! Does this file contain anything worth saving?
@@ -599,7 +616,7 @@ protected:
 
     \todo Set pngcairo to be the default terminal as soon as the mac platform
     supports it.
- */
+  */
   void SetupVariables();
 
   void KillMaxima(bool logMessage = true);                 //!< kills the maxima process
@@ -609,13 +626,13 @@ protected:
     changed or force is true.
     \param saved The new "saved" status
     \param force Force update if the "saved" status hasn't changed.
-   */
+  */
   void ResetTitle(bool saved, bool force = false);
 
   /*! Makes this window the debug log target of all windows from this maxima process
 
     Only necessary on the mac where the same process creates loads of windows.
-   */
+  */
   void BecomeLogTarget();
 
   void FirstOutput();
@@ -642,7 +659,7 @@ protected:
   /*! Saves the current file
 
     \param forceSave true means: Always ask for a file name before saving.
-   */
+  */
   bool SaveFile(bool forceSave = false);
 
   //! Try to save the file before closing it - or return false
@@ -650,7 +667,7 @@ protected:
   /*! Save the project in a temp file.
 
     Returns false if a save was necessary, but not possible.
-   */
+  */
   bool AutoSave();
 
   int SaveDocumentP();
@@ -660,29 +677,29 @@ protected:
 
   //! Get the current working directory file I/O from maxima is relative to.
   wxString GetCWD()
-  {
-    return m_CWD;
-  }
+    {
+      return m_CWD;
+    }
 
   std::unique_ptr<Maxima> m_client;
   /*! The Right Way to delete a wxSocketServer
 
     The destructor might delete the server before all pending server events have been
     processed which leads to a crash.
-   */
+  */
   struct ServerDeleter {
-  void operator()(wxSocketServer* server) const {
-    server->Close();
-    wxLogMessage(_("Closing the socket maxima could connect to!"));
-    server->Destroy();
-  }
-};
+    void operator()(wxSocketServer* server) const {
+      server->Close();
+      wxLogMessage(_("Closing the socket maxima could connect to!"));
+      server->Destroy();
+    }
+  };
   /*! The server maxima connects to as client
 
-     The destructor of the server causes 
-     crashes if there are still pending events.
-     Instead we need to call destroy.
- */
+    The destructor of the server causes 
+    crashes if there are still pending events.
+    Instead we need to call destroy.
+  */
   std::unique_ptr<wxSocketServer,  ServerDeleter> m_server;
 
   wxProcess *m_process;
@@ -698,7 +715,7 @@ protected:
 
     wxEmptyString means that the current output isn't long enough to make
     creating this string worthwhile.
-   */
+  */
   wxString m_currentOutputEnd;
   //! All from maxima's current output we still haven't interpreted
   wxString m_currentOutput;
@@ -715,6 +732,10 @@ protected:
 public:
   //! The marker for the end of a input prompt
   const static wxString m_promptSuffix;
+  //! Remove the said window from the list of toplevel windows
+  static void DelistTopLevelWindow(wxMaxima *);
+  //! The list of toplevel windows we currently maintain
+  static std::vector<wxMaxima *> m_topLevelWindows;
 protected:
   //! Sets gnuplot's command name and tries to determine gnuplot's path
   void GnuplotCommandName(wxString gnuplot);
@@ -731,6 +752,10 @@ protected:
   //! The marker for the end of a variables section
   static wxString m_statusbarSuffix;
   //! The marker for the start of a "add variables" section
+  static wxString m_jumpManualPrefix;
+  //! The marker for the end of a variables section
+  static wxString m_jumpManualSuffix;
+  //! The marker for the start of a "add variables" section
   static wxString m_addVariablesPrefix;
   //! The marker for the end of a "add variables" section
   static wxString m_addVariablesSuffix;
@@ -747,13 +772,15 @@ protected:
   //! An empty wxxml symbols section
   static wxString m_emptywxxmlSymbols;
   bool m_dispReadOut;               //!< what is displayed in statusbar
+  int m_gnuplot_process_id;
+  int m_maxima_process_id;
   wxString m_lastPrompt;
   wxString m_lastPath;
   std::unique_ptr<wxPrintData> m_printData;
   /*! Did we tell maxima to close?
 
     If we didn't we respan an unexpectedly-closing maxima.
-   */
+  */
   bool m_closing;
   wxString m_openFile;
   //! The directory with maxima's temp files
@@ -776,6 +803,7 @@ protected:
   MathParser m_parser;
   bool m_maximaBusy;
 private:
+  bool m_fourierLoaded = false;
   //! The value of maxima's logexpand variable
   wxString m_logexpand;
   //! A pointer to a method that handles a text chunk
@@ -783,10 +811,14 @@ private:
   WX_DECLARE_STRING_HASH_MAP(ParseFunction, ParseFunctionHash);
   typedef void (wxMaxima::*VarReadFunction)(const wxString &value);
   WX_DECLARE_STRING_HASH_MAP(VarReadFunction, VarReadFunctionHash);
+  typedef void (wxMaxima::*VarUndefinedFunction)();
+  WX_DECLARE_STRING_HASH_MAP(VarUndefinedFunction, VarUndefinedFunctionHash);
   //! A list of XML tags we know and what we want to do if we encounter them
   static ParseFunctionHash m_knownXMLTags;
   //! A list of actions we want to execute if we are sent the contents of specific variables
   static VarReadFunctionHash m_variableReadActions;
+  //! A list of actions we want to execute if certain variables are undefined;
+  static VarUndefinedFunctionHash m_variableUndefinedActions;
 
 #if wxUSE_DRAG_AND_DROP
 
@@ -804,21 +836,18 @@ private:
     This timer is used in one-shot mode so in the unlikely case that saving needs more
     time than this timer to expire the user still got a chance to do something against
     it between two expirys.
-   */
+  */
   wxTimer m_autoSaveTimer;
 
   /* A timer that delays redraws while maxima evaluates
 
      If we always start a redraw when maxima has nearly finished a command that slows
      down evaluating many simple commands in a row.
-   */
+  */
   wxTimer m_fastResponseTimer;
 
   //! Starts a single-shot of m_autoSaveTimer.
   void StartAutoSaveTimer();
-
-
-
 };
 
 #if wxUSE_DRAG_AND_DROP
@@ -827,7 +856,7 @@ class MyDropTarget : public wxFileDropTarget
 {
 public:
   explicit MyDropTarget(wxMaxima *wxmax)
-  { m_wxmax = wxmax; }
+    { m_wxmax = wxmax; }
 
   bool OnDropFiles(wxCoord x, wxCoord y, const wxArrayString &files);
 
@@ -839,53 +868,5 @@ private:
 
 
 // cppcheck-suppress noConstructor
-class MyApp : public wxApp
-{
-public:
-  virtual bool OnInit();
-  virtual int OnRun();
-  virtual int OnExit();
-  wxLocale m_locale;
-
-  /*! Create a new window
-
-    The mac platform insists in making all windows of an application
-    share the same process. On the other platforms we create a separate
-    process for every wxMaxima session instead which means that each
-    process uses the NewWindow() function only once.
-
-    \param file The file name
-    \param evalOnStartup Do we want to execute the file automatically, but halt on error?
-    \param exitAfterEval Do we want to close the window after the file has been evaluated?
-    \param wxmData A .wxm file containing the initial worksheet contents
-    \param wxmLen  The length of wxmData
-   */
-  void NewWindow(const wxString &file = {}, bool evalOnStartup = false, bool exitAfterEval = false, unsigned char *wxmData = NULL, size_t wxmLen = 0);
-
-  static std::vector<wxMaxima *> m_topLevelWindows;
-  static void DelistTopLevelWindow(wxMaxima *);
-
-  void OnFileMenu(wxCommandEvent &ev);
-
-  virtual void MacNewFile();
-  void BecomeLogTarget();
-
-  virtual void MacOpenFile(const wxString &file);
-
-private:
-  //! The name of the config file. Empty = Use the default one.
-  wxString m_configFileName;
-  Dirstructure m_dirstruct;
-  #if defined __WXOSX__
-  bool m_allWindowsInOneProcess = true;
-  #else
-  bool m_allWindowsInOneProcess = false;
-  #endif
-};
-
-
-
-// cppcheck-suppress unknownMacro
-DECLARE_APP(MyApp)
 
 #endif // WXMAXIMA_H
